<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class About_Left extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_about_left';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'About Left', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'about_left',
			[
				'label' => esc_html__( 'About Left', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style6' => esc_html__( 'Choose Style 6', 'tranzix' ),
						'style7' => esc_html__( 'Choose Style 7', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'number',
			[
				'label'       => __( 'Number', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style14',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style17',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Number', 'rashid' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				 'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style14',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style17',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'rashid' ),
				 'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style13',
						),
					),
				),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'rashid' ),
			]
		);	
		$this->add_control(
			'btnlink',
			[
			  'label' => __( 'Video Url', 'rashid' ),
			  'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style13',
						),
					),
				),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'rashid' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
			  ],
			
		   ]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Image Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'bgimg1',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style8',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style11',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style12',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style13',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style14',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style15',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style16',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style17',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg2',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style8',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style13',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style14',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style15',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style16',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style17',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg3',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'image',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style8',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style11',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style12',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style13',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style14',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style15',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style16',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style17',
								),
							),
						  ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style8',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style11',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style12',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style13',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style14',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style15',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style16',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style17',
								),
							),
						),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'image1',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style13',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style15',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style16',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style17',
								),
							),
						  ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text1',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style13',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style15',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style16',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style17',
								),
							),
						),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'image2',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
							),
						   ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text2',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						 'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
							),
						),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				
				
				
		$this->end_controls_section();	
		
		// New Tab#2

		$this->start_controls_section(
					'content_section2',
					[
						'label' => __( 'Skills Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_column',
									'label'   => esc_html__( 'Column', 'rashid' ),
									'type'    => Controls_Manager::NUMBER,
									'default' => 2,
									'min'     => 1,
									'max'     => 12,
									'step'    => 1,
								],
								[
									'name' => 'block_color',
									'label' => esc_html__('Color Class', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'ff_stop',
									'label' => esc_html__('Counter Stop', 'rashid'),
									'type' => Controls_Manager::TEXT,
									'default' => esc_html__('', 'hekim')
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
		
			
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
		
		<?php  if ( 'style6' === $settings['style'] ) : ?>
		
		<section class="about-eight p_relative pb_150 <?php echo esc_attr($settings['sec_class']);?>">
			<div class="auto-container">
				<div class="row align-items-center clearfix">
					<div class="col-lg-12 col-md-12 col-sm-12 image-column">
						<div class="image_block_eight">
							<div data-animation-box class="image-box p_relative d_block ml_30 pl_140">
								<div class="shape parallax-scene parallax-scene-1">
									<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
									<div data-depth="0.40" class="shape-1 p_absolute t_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
									<?php  if ( esc_url($settings['bgimg2']['id']) ) : ?>
									<div data-depth="0.50" class="shape-2 p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg2']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
									<?php  if ( esc_url($settings['bgimg3']['id']) ) : ?>
									<div data-depth="0.40" class="shape-3 p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg3']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
								</div>
								<figure data-animation-text class="overlay-anim-black-bg image p_relative d_block" data-animation="overlay-animation">
								
								<?php  if ( esc_url($settings['image']['id']) ) : ?>   
								<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
								<?php else :?>
								<div class="noimage"></div>
								<?php endif;?>
								
								</figure>
								<div class="text p_absolute l_0 b_50 pt_25 pr_30 pb_25 pl_30">
									<p class="fs_17 fw_sbold font_family_oxygen lh_28"><?php echo $settings['text'];?></p>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>
		
		<?php endif;?>
		
		<?php  if ( 'style7' === $settings['style'] ) : ?>
		
		<section class="about-nine p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row align-items-center clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 image-column">
                        <div class="image_block_nine">
                            <div class="image-box p_relative d_block mr_50">
                                <div class="shape parallax-scene parallax-scene-1">
									<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                                    <div data-depth="0.40" class="shape-1 p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
									<?php  if ( esc_url($settings['bgimg2']['id']) ) : ?>
                                    <div data-depth="0.50" class="shape-2 p_absolute l_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg2']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
									<?php  if ( esc_url($settings['bgimg3']['id']) ) : ?>
                                    <div data-depth="0.40" class="shape-3 p_absolute l_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg3']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
                                </div>
                                <figure class="image p_absolute l_0 wow slideInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
									<?php  if ( esc_url($settings['image']['id']) ) : ?>   
									<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
								</figure>
                                <div class="text p_absolute r_0 b_0 b_shadow_6 pt_40 pb_35">
                                    <h2 class="d_block fs_45 lh_50 fw_exbold font_family_spartan z_1"><?php echo $settings['number'];?></h2>
                                    <h5 class="d_block fs_18 fw_sbold font_family_spartan z_1"><?php echo $settings['text'];?></h5>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		
		<?php endif;?>
             
		<?php 
	}

}