<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class About_Right extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_about_right';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'About Right', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'about_right',
			[
				'label' => esc_html__( 'About Right', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style6' => esc_html__( 'Choose Style 6', 'tranzix' ),
						'style7' => esc_html__( 'Choose Style 7', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style10',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style12',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style14',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style15',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style16',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style17',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style10',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style12',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style13',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style14',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style15',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style16',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style17',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style10',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style12',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style15',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style16',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style17',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'text1',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style10',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style12',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style10',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style12',
						),
					),
				),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'rashid' ),
			]
		);	
		$this->add_control(
			'btnlink',
			[
			  'label' => __( 'Button Url', 'rashid' ),
			  'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style10',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style12',
						),
					),
				),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'rashid' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
			  ],
			
		   ]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#2

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'List Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_column',
									'label'   => esc_html__( 'Column', 'rashid' ),
									'type'    => Controls_Manager::NUMBER,
									'default' => 2,
									'min'     => 1,
									'max'     => 12,
									'step'    => 1,
								],
								[
									'name' => 'block_icons',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::SELECT,
									'options'  => get_fontawesome_icons(),
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_feature_str',
									'label'       => __( 'Features List', 'rashid' ),
									'type'        => Controls_Manager::TEXTAREA,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Features List', 'rashid' ),
									'default'     => __( '', 'rashid' ),
								],
								[
									'name' => 'block_image',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_alt_text',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_button',
									'label'       => __( 'Button', 'rashid' ),
									'type'        => Controls_Manager::TEXT,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Button Title', 'rashid' ),
								],
								[
									'name' => 'block_btnlink',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									'url' => '',
									'is_external' => true,
									'nof
									ollow' => true,
									],
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
		
			
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
		
		<?php  if ( 'style6' === $settings['style'] ) : ?>
		
		<section class="about-eight p_relative pb_150 <?php echo esc_attr($settings['sec_class']);?>">
			<div class="auto-container">
				<div class="row align-items-center clearfix">
					<div class="col-lg-12 col-md-12 col-sm-12 content-column">
						<div class="content_block_nine">
							<div class="content-box p_relative d_block mr_70">
								<div class="sec-title-three p_relative d_block mb_20 mt_10">
									<h6 class="d_block fs_18 lh_26 fw_sbold uppercase mb_12"><?php echo $settings['subtitle'];?></h6>
									<h2 class="d_block fs_50 fw_bold"><?php echo $settings['title'];?></h2>
								</div>
								<div class="text p_relative d_block mb_25">
									<p class="font_family_poppins"><?php echo $settings['text'];?></p>
								</div>
								<ul class="list-style-two clearfix p_relative d_block mb_30">
									<?php foreach($settings['repeat'] as $item):?>
									<li class="p_relative d_block fs_16 fw_bold font_family_oxygen mb_10 pl_30"><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
									<?php endforeach; ?>
								</ul>
								<div class="video-btn">
									<a href="<?php echo esc_url($settings['btnlink']['url']);?>" class="lightbox-image video-btn p_relative d_iblock fs_17 font_family_oxygen fw_bold pl_90 pr_35 z_1 pt_20 pb_20" data-caption=""><i class="icon-37"></i><?php echo $settings['bttn'];?></a>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>
		
		<?php endif;?>
		
		<?php  if ( 'style7' === $settings['style'] ) : ?>
		
		<section class="about-nine p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row align-items-center clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 content-column">
                        <div class="content_block_nine">
                            <div class="content-box p_relative d_block ml_30">
                                <div class="sec-title p_relative d_block mb_30">
                                    <h2  class="d_block fs_50 lh_55 fw_bold font_family_spartan"><?php echo $settings['title'];?></h2>
                                </div>
                                <div class="text p_relative d_block mb_35">
                                    <p class="font_family_oxygen mb_25"><?php echo $settings['text'];?></p>
                                    <p class="font_family_oxygen"><?php echo $settings['text1'];?></p>
                                </div>
                                <ul class="list-style-two clearfix p_relative d_block mb_30">
									<?php foreach($settings['repeat'] as $item):?>
                                    <li class="p_relative d_block fs_18 fw_bold font_family_oxygen mb_10 pl_30"><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
									<?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
             
		<?php 
	}

}