<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Chooseus_Left extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_chooseus_left';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Chooseus Left', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'chooseus_left',
			[
				'label' => esc_html__( 'Chooseus Left', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Choose Style 1', 'tranzix' ),
						'style2' => esc_html__( 'Choose Style 2', 'tranzix' ),
						'style3' => esc_html__( 'Choose Style 3', 'tranzix' ),
						'style4' => esc_html__( 'Choose Style 4', 'tranzix' ),
						'style5' => esc_html__( 'Choose Style 5', 'tranzix' ),
						'style6' => esc_html__( 'Choose Style 6', 'tranzix' ),
						'style7' => esc_html__( 'Choose Style 7', 'tranzix' ),
						'style8' => esc_html__( 'Choose Style 8', 'tranzix' ),
						'style9' => esc_html__( 'Choose Style 9', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'bgimg',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
					),
				),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'bgimg1',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
					),
				),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'List Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_column',
									'label'   => esc_html__( 'Column', 'rashid' ),
									'type'    => Controls_Manager::NUMBER,
									'default' => 2,
									'min'     => 1,
									'max'     => 12,
									'step'    => 1,
								],
								[
									'name' => 'block_icons',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::SELECT,
									'options'  => get_fontawesome_icons(),
								],
								[
									'name' => 'block_image',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_alt_text',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
		

	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		<?php  if ( 'style1' === $settings['style'] ) : ?>
		
        <section class="chooseus-one p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="inner-container p_relative">
                    <div class="section-line">
                        <div class="line line-1 p_absolute"></div>
                        <div class="line line-2 p_absolute"></div>
                        <div class="line line-3 p_absolute"></div>
                    </div>
                    <div class="clearfix">
                        <div class="content-column">
                            <div class="content_block_two">
                                <div class="content-box p_relative d_block mr_130 z_1">
									<?php if($settings['title']): ?>
                                    <div class="sec-title p_relative d_block mb_20">
                                        <span class="sub-title p_relative d_iblock fs_15 fw_medium g_color mb_19"><?php echo $settings['subtitle'];?></span>
                                        <h2 class="p_relative d_block fs_40 fw_bold mb_0"><?php echo $settings['title'];?></h2>
                                    </div>
                                    <div class="text p_relative d_block mb_25 wow fadeInUp" data-wow-duration="1500ms">
                                        <p class="fs_18"><?php echo $settings['text'];?></p>
                                    </div>
									<?php endif; ?>
                                    <div class="inner-box p_relative d_block wow fadeInUp" data-wow-duration="1500ms">
									
										<?php foreach($settings['repeat'] as $item):?>
									
                                        <div class="single-item p_relative d_block pl_80 mb_16">
                                            <div class="icon-box p_absolute l_0 t_3 w_50 h_50 lh_50 text-center b_radius_50 b_shadow_7">
                                                <div class="icon p_relative d_iblock g_color"><i class="icon-15"></i></div>
                                                <div class="icon-img hidden-icon">
												<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
												<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
												<?php else :?>
												<div class="noimage"></div>
												<?php endif;?>
												</div>
                                            </div>
                                            <h4 class="d_block fs_20 lh_30 mb_4"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                            <p class="mb_0"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                        </div>
										
										<?php endforeach; ?>

										
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<section class="chooseus-two p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="outer-container clearfix">
                <div class="content-inner p_relative d_block pt_150 pr_100 pb_150 pl_100">
                    <div class="pattern-layer">
						<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                        <div class="pattern-1 p_absolute t_0 r_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
						<?php else :?>	
						<div class="noimage">
						<?php endif;?>
						</div>
						<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                        <div class="pattern-2 p_absolute l_0 b_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
						<?php else :?>	
						<div class="noimage">
						<?php endif;?>
						</div>
                    </div>
                    <div class="content-box p_relative d_block pl_15 pr_15">
						<?php if($settings['title']): ?>
                        <div class="sec-title-two p_relative d_block mb_30 light">
                            <span class="p_relative d_iblock font_family_oxygen fs_15 lh_40 pl_30 pr_30 mb_17"><?php echo $settings['subtitle'];?></span>
                            <h2 class="d_block fs_40 fw_bold font_family_oxygen mb_20"><?php echo $settings['title'];?></h2><br />
                            <p class="fs_18 font_family_oxygen mb_0"><?php echo $settings['text'];?></p>
                        </div>
						<?php endif; ?>
                        <div class="inner-box">
                            <div class="row clearfix">
							
								<?php foreach($settings['repeat'] as $item):?>
							
                                <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 single-column">
                                    <div class="single-item p_relative d_block pl_80 mb_19">
                                        <div class="icon-box p_absolute l_0 t_3 w_50 h_50 lh_50 text-center b_radius_50">
                                            <div class="icon p_relative d_iblock g_color_2"><i class="icon-15"></i></div>
                                            <div class="icon-img hidden-icon d_iblock">
											<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
											<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
											<?php else :?>
											<div class="noimage"></div>
											<?php endif;?>
											</div>
                                        </div>
                                        <h4 class="d_block fs_20 lh_30 mb_6 font_family_oxygen"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                        <p class="mb_0 fs_16 font_family_oxygen"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                    </div>
                                </div>
								
								<?php endforeach; ?>
								
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
        <section class="chooseus-three p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="outer-container clearfix">
                <div class="content-inner p_relative d_block pt_140 pr_100 pb_140 pl_100">
                    <div class="pattern-layer">
						<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                        <div class="pattern-3 p_absolute t_0 r_0" data-parallax='{"x": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
						<?php else :?>	
						<div class="noimage">
						<?php endif;?>
						</div>
                    </div>
                    <div class="content-box p_relative d_block pl_15 pr_15">
						<?php if($settings['title']): ?>
                        <div class="sec-title-three p_relative d_block mb_30 light">
                            <h6 class="d_block fs_16 lh_26 fw_bold font_family_oxygen mb_12"><?php echo $settings['subtitle'];?></h6>
                            <h2 class="d_block fs_40 fw_bold font_family_oxygen mb_25"><?php echo $settings['title'];?></h2>
                            <p class="fs_18 font_family_oxygen mb_0"><?php echo $settings['text'];?></p>
                        </div>
						<?php endif; ?>
                        <div class="inner-box">
                            <div class="row clearfix">
							
								<?php foreach($settings['repeat'] as $item):?>
							
                                <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 single-column">
                                    <div class="single-item p_relative d_block pl_80 mb_19">
                                        <div class="icon-box p_absolute l_0 t_3 w_50 h_50 lh_50 text-center b_radius_50">
                                            <div class="icon p_relative d_iblock"><i class="icon-15"></i></div>
                                            <div class="icon-img hidden-icon d_iblock">
											<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
											<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
											<?php else :?>
											<div class="noimage"></div>
											<?php endif;?>
											</div>
                                        </div>
                                        <h4 class="d_block fs_20 lh_30 mb_6 font_family_oxygen"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                        <p class="mb_0 fs_16 font_family_oxygen"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                    </div>
                                </div>
								
								<?php endforeach; ?>
								
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style4' === $settings['style'] ) : ?>
		
		<section class="chooseus-four p_relative pt_150 pb_130  <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 content-column">
                        <div class="content_block_five">
                            <div class="content-box p_relative d_block mr_30">
								<?php if($settings['title']): ?>
                                <div class="sec-title-four p_relative d_block mb_50">
                                    <h6 class="d_iblock fs_14 lh_28 fw_sbold font_family_poppins mb_18 b_radius_5"><?php echo $settings['subtitle'];?></h6>
                                    <h2 class="d_block fs_40 fw_bold font_family_poppins"><?php echo $settings['title'];?></h2>
                                </div>
								<?php endif; ?>
                                <ul class="accordion-box">
								
									<?php foreach($settings['repeat'] as $key=>$item):?>
								
                                    <li class="accordion block <?php if($key == 1) echo 'active-block';?> p_relative d_block">
                                        <div class="acc-btn <?php if($key == 1) echo 'active';?> p_relative d_block tran_5 pt_16 pr_80 pb_16 pl_30">
                                            <div class="icon-outer p_absolute fs_10 tran_5 z_1"><i class="icon-29"></i></div>
                                            <h5 class="p_relative d_block fs_18 lh_28 fw_medium font_family_poppins"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h5>
                                        </div>
                                        <div class="acc-content <?php if($key == 1) echo 'current';?> p_relative pt_25 pr_50 pb_25 pl_30">
                                            <div class="text p_relative d_block">
                                                <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                            </div>
                                        </div>
                                    </li>
									
									<?php endforeach; ?>
									
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style5' === $settings['style'] ) : ?>
		
		<section class="chooseus-seven p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 content-column">
                        <div class="content_block_14">
                            <div class="content-box p_relative d_block mr_120">
								<?php if($settings['title']): ?>
                                <div class="sec-title p_relative d_block mb_35">
                                    <h5 class="d_block fs_17 lh_20 uppercase mb_19 fw_sbold font_family_poppins"><?php echo $settings['subtitle'];?></h5>
                                    <h2 class="d_block fs_50 lh_55 fw_medium font_family_frank"><?php echo $settings['title'];?></h2>
                                </div>
								<?php endif; ?>
                                <div class="inner">
								
									<?php foreach($settings['repeat'] as $item):?>
								
                                    <div class="single-item  p_relative d_block pl_100 mb_30">
                                        <div class="icon-box p_absolute l_0 t_5 d_iblock w_70 h_70 lh_70 centred fs_40 tran_5">
                                            <div class="icon"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']));?>"></i></div>
                                            <div class="icon-img hidden-icon">
												<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
												<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
												<?php else :?>
												<div class="noimage"></div>
												<?php endif;?>
											</div>
                                        </div>
                                        <h3 class="d_block fs_24 lh_30 fw_medium font_family_frank mb_12"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
                                        <p class="d_block fs_16 font_family_oxygen"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                    </div>
									
									<?php endforeach; ?>
									
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style6' === $settings['style'] ) : ?>
		
		<section class="chooseus-eight p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
			<div class="auto-container">
				<div class="row clearfix">
					<div class="col-lg-12 col-md-12 col-sm-12 content-column">
						<div class="content_block_14">
							<div class="content-box p_relative d_block mr_60">
								<?php if($settings['title']): ?>
								<div class="sec-title p_relative d_block mb_40">
									<h5 class="d_block fs_15 lh_20 uppercase mb_15 fw_sbold font_family_jost"><?php echo $settings['subtitle'];?></h5>
									<h2 class="d_block fs_45 lh_50 fw_sbold font_family_jost"><?php echo $settings['title'];?></h2>
								</div>
								<?php endif; ?>
								<div class="inner">
								
									<?php foreach($settings['repeat'] as $item):?>
								
									<div class="single-item  p_relative d_block pl_100 mb_35">
										<div class="icon-box p_absolute l_0 t_8 d_iblock w_70 h_70 lh_70 centred fs_40 tran_5">
											<div class="icon"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']));?>"></i></div>
											<div class="icon-img hidden-icon">
												<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
												<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
												<?php else :?>
												<div class="noimage"></div>
												<?php endif;?>
											</div>
										</div>
										<h3 class="d_block fs_24 lh_30 fw_sbold font_family_jost mb_17"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
										<p class="d_block fs_16 font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
									</div>
									
									<?php endforeach; ?>
									
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>
		
		<?php endif;?>
		
		<?php  if ( 'style7' === $settings['style'] ) : ?>
		
		<section class="chooseus-nine p_relative pt_150 pb_75 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 content-column">
                        <div class="content_block_five">
                            <div class="content-box p_relative d_block mr_30">
								<?php if($settings['title']): ?>
                                <div class="sec-title-nine p_relative d_block mb_25">
                                    <h6 class="d_iblock pl_20 pr_20 fs_14 lh_30 b_radius_5 mb_18 fw_medium font_family_poppins"><?php echo $settings['subtitle'];?></h6>
                                    <h2 class="d_block fs_45 lh_55 fw_bold font_family_jost"><?php echo $settings['title'];?></h2>
                                </div>
								<?php endif; ?>
                                <ul class="accordion-box">
								
									<?php foreach($settings['repeat'] as $key=>$item):?>
								
                                    <li class="accordion block <?php if($key == 1) echo 'active-block';?> p_relative d_block">
                                        <div class="acc-btn <?php if($key == 1) echo 'active';?> p_relative d_block tran_5 pt_16 pr_80 pb_16 pl_30">
                                            <div class="icon-outer p_absolute fs_10 tran_5 z_1"><i class="icon-29"></i></div>
                                            <h5 class="p_relative d_block fs_20 lh_28 fw_medium font_family_jost"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h5>
                                        </div>
                                        <div class="acc-content <?php if($key == 1) echo 'current';?> p_relative pt_25 pr_50 pb_25 pl_30">
                                            <div class="text p_relative d_block">
                                                <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                            </div>
                                        </div>
                                    </li>
									
									<?php endforeach; ?>
									
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style8' === $settings['style'] ) : ?>
		
        <section class="chooseus-11 chooseus-three p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div data-animation-box class="outer-container clearfix">
                <div class="content-inner p_relative d_block pt_140 pr_100 pb_140 pl_100">
                    <div class="pattern-layer">
						<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                        <div class="pattern-4 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
						<?php else :?>	
						<div class="noimage">
						<?php endif;?>
						</div>
                    </div>
                    <div class="content-box p_relative d_block pl_15 pr_15">
						<?php if($settings['title']): ?>
                        <div class="sec-title p_relative d_block mb_30">
                            <h2 class="d_block fs_45 lh_50 fw_bold font_family_frank mb_18"><?php echo $settings['title'];?></h2>
                            <p class="mb_0 fs_16 font_family_poppins"><?php echo $settings['text'];?></p>
                        </div>
						<?php endif; ?>
                        <div class="inner-box">
                            <div class="row clearfix">
							
								<?php foreach($settings['repeat'] as $item):?>
							
                                <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 single-column">
                                    <div class="single-item p_relative d_block pl_80 mb_19">
                                        <div class="icon-box p_absolute l_0 t_3 w_50 h_50 lh_50 text-center b_radius_50">
                                            <div class="icon p_relative d_iblock"><i class="icon-15"></i></div>
                                            <div class="icon-img hidden-icon d_iblock">
												<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
												<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
												<?php else :?>
												<div class="noimage"></div>
												<?php endif;?>
											</div>
                                        </div>
                                        <h3 class="d_block fs_24 lh_30 fw_bold font_family_frank mb_6"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
                                        <p class="mb_0 fs_16 font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                    </div>
                                </div>
								
								<?php endforeach; ?>
								
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style9' === $settings['style'] ) : ?>
		
		<section class="chooseus-12 p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 content-column">
                        <div class="content_block_26">
                            <div class="content-box p_relative d_block mr_70">
								<?php if($settings['title']): ?>
                                <div class="sec-title-13 p_relative d_block mb_50">
                                    <h5 class="p_relative d_iblock fs_17 lh_30 fw_sbold mb_16 uppercase"><?php echo $settings['subtitle'];?></h5>
                                    <h2 class="d_block fs_40 fw_bold lh_50"><?php echo $settings['title'];?></h2>
                                </div>
								<?php endif; ?>
                                <div class="inner-box">
								
									<?php foreach($settings['repeat'] as $key=>$item):?>
								
                                    <div class="single-item p_relative d_block pl_100 mb_25">
                                        <div class="icon-box p_absolute l_0 t_5 w_70 h_70 lh_70 fs_20 centred b_radius_50"><i class="icon-16"></i></div>
                                        <h4 class="d_block fs_20 lh_30 fw_sbold mb_13"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                        <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                    </div>
									
									<?php endforeach; ?>
									
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		
		<?php endif;?>
             
		<?php 
	}

}