<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Chooseus_Right extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_chooseus_right';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Chooseus Right', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'chooseus_right',
			[
				'label' => esc_html__( 'Chooseus Right', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Choose Style 1', 'tranzix' ),
						'style2' => esc_html__( 'Choose Style 2', 'tranzix' ),
						'style3' => esc_html__( 'Choose Style 3', 'tranzix' ),
						'style4' => esc_html__( 'Choose Style 4', 'tranzix' ),
						'style5' => esc_html__( 'Choose Style 5', 'tranzix' ),
						'style6' => esc_html__( 'Choose Style 6', 'tranzix' ),
						'style7' => esc_html__( 'Choose Style 7', 'tranzix' ),
						'style8' => esc_html__( 'Choose Style 8', 'tranzix' ),
						'style9' => esc_html__( 'Choose Style 9', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Image Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'bgimg',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style8',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg1',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg2',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'image',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
							),
						),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
							),
						),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'image2',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
							),
						),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text2',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
							),
						),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				
				
		$this->end_controls_section();	
		
		// New Tab#2

		$this->start_controls_section(
					'content_section2',
					[
						'label' => __( 'Progress Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'coler',
									'label' => esc_html__('Coler', 'rashid'),
									'type' => Controls_Manager::TEXT,
									'default' => esc_html__('', 'hekim')
								],
								[
									'name' => 'ff_stop',
									'label' => esc_html__('Counter Stop', 'rashid'),
									'type' => Controls_Manager::TEXT,
									'default' => esc_html__('', 'hekim')
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
		
		
		<?php  if ( 'style1' === $settings['style'] ) : ?>
        
		<section class="chooseus-one p_relative <?php echo esc_attr($settings['sec_class']);?>">
			<div class="auto-container">
				<div class="inner-container p_relative">
					<div class="section-line">
						<div class="line line-1 p_absolute"></div>
						<div class="line line-2 p_absolute"></div>
						<div class="line line-3 p_absolute"></div>
					</div>
					<div class="clearfix">
						<div class="image-column">
							<div class="image_block_two">
								<div  class="image-box p_relative d_block ml_30 pb_140 mt_20">
									<div class="shape parallax-scene parallax-scene-3">
										<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
										<div data-depth="0.40" class="shape-1 p_absolute w_150 h_150 z_2" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
										<?php else :?>	
										<div class="noimage">
										<?php endif;?>
										</div>
										<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
										<div data-depth="0.50" class="shape-2 p_absolute w_95 h_95" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
										<?php else :?>	
										<div class="noimage">
										<?php endif;?>
										</div>
										<?php  if ( esc_url($settings['bgimg2']['id']) ) : ?>
										<div data-depth="0.30" class="shape-3 p_absolute w_95 h_95" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg2']['id']);?>);">
										<?php else :?>	
										<div class="noimage">
										<?php endif;?>
										</div>
									</div>
									<figure  class=" image image-1 p_relative d_block b_radius_10" data-animation="overlay-animation">
									<?php  if ( esc_url($settings['image']['id']) ) : ?>   
									<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
									</figure>
									<figure  class=" image image-2 p_absolute l_0 b_0 b_radius_10 d_block" data-animation="overlay-animation">
									<?php  if ( esc_url($settings['image2']['id']) ) : ?>   
									<img src="<?php echo wp_get_attachment_url($settings['image2']['id']);?>" alt="<?php echo esc_attr($settings['alt_text2']);?>"/>
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
									</figure>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
        <section class="chooseus-two p_relative  <?php echo esc_attr($settings['sec_class']);?>">
            <div class="outer-container clearfix">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="bg-layer p_absolute l_0 t_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
		<section class="chooseus-three p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="outer-container clearfix">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="bg-layer p_absolute l_0 t_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
                <div class="auto-container">
                    <div class="progress-inner p_relative d_block clearfix wow slideInLeft animated" data-wow-delay="00ms" data-wow-duration="1500ms">
						<?php foreach($settings['repeat'] as $item):?>
                        <div class="single-progress-box">
                            <div class="box">
                                <div class="piechart p_relative mb_5"  data-fg-color="#<?php echo esc_attr($item['coler']);?>" data-value=".<?php echo esc_attr($item['ff_stop']);?>">
                                    <span>.<?php echo esc_attr($item['ff_stop']);?></span>
                                </div>
                                <h6 class="d_block fs_15 lh_20 fw_bold font_family_oxygen"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                            </div>
                        </div>
						<?php endforeach; ?>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style4' === $settings['style'] ) : ?>
		
		<section class="chooseus-four p_relative pt_150 pb_130 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 image-column">
                        <div class="image_block_four">
                            <div class="image-box p_relative d_block ml_20">
                                <div class="shape parallax-scene parallax-scene-3">
                                    <div data-depth="0.50" class="shape-1 p_absolute w_40 h_40"></div>
                                    <div data-depth="0.40" class="shape-2 p_absolute w_40 h_40"></div>
									<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                                    <div data-depth="0.30" class="shape-3 p_absolute w_150 h_150" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
									<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                                    <div data-depth="0.40" class="shape-4 p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
                                </div>
                                <figure class="image p_relative d_block wow slideInRight animated" data-wow-delay="00ms" data-wow-duration="1500ms">
								<?php  if ( esc_url($settings['image']['id']) ) : ?>   
								<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
								<?php else :?>
								<div class="noimage"></div>
								<?php endif;?>
								</figure>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style5' === $settings['style'] ) : ?>
		
		<section class="chooseus-seven p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 image-column">
                        <div data-animation-box class="image-box p_relative d_block pl_30">
                            <div class="shape parallax-scene parallax-scene-2">
								<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                                <div data-depth="0.40" class="shape-1 p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
								<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
								<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                                <div data-depth="0.50" class="shape-2 p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
								<?php else :?>	
								<div class="noimage">
								<?php endif;?>
								</div>
                            </div>
                            <div class="row clearfix">
                                <div class="col-lg-6 col-md-6 col-sm-12 column">
                                    <figure data-animation-text class="overlay-anim-black-bg image p_relative d_block"  data-animation="overlay-animation">
										<?php  if ( esc_url($settings['image']['id']) ) : ?>   
										<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
										<?php else :?>
										<div class="noimage"></div>
										<?php endif;?>
									</figure>
                                </div>
                                <div class="col-lg-6 col-md-6 col-sm-12 column">
                                    <figure data-animation-text class="overlay-anim-black-bg image p_relative d_block"  data-animation="overlay-animation">
										<?php  if ( esc_url($settings['image2']['id']) ) : ?>   
										<img src="<?php echo wp_get_attachment_url($settings['image2']['id']);?>" alt="<?php echo esc_attr($settings['alt_text2']);?>"/>
										<?php else :?>
										<div class="noimage"></div>
										<?php endif;?>
									</figure>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style6' === $settings['style'] ) : ?>
		
		<section class="chooseus-eight p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
			<div class="auto-container">
				<div class="row clearfix">
					<div class="col-lg-12 col-md-12 col-sm-12 image-column">
						<div class="image_block_12">
							<div data-animation-box class="image-box p_relative d_block ml_30 pb_70 pl_170">
								<div class="shape parallax-scene parallax-scene-2">
									<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
									<div data-depth="0.40" class="shape-1 p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
									<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
									<div data-depth="0.50" class="shape-2 p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
								</div>
								
								<figure data-animation-text class="overlay-anim-black-bg image image-1 p_relative d_block paroller"  data-animation="overlay-animation">
									<?php  if ( esc_url($settings['image']['id']) ) : ?>   
									<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
								</figure>
								
								<figure data-animation-text class="overlay-anim-black-bg image image-2 p_absolute l_0 b_0 paroller-2"  data-animation="overlay-animation">
									<?php  if ( esc_url($settings['image2']['id']) ) : ?>   
									<img src="<?php echo wp_get_attachment_url($settings['image2']['id']);?>" alt="<?php echo esc_attr($settings['alt_text2']);?>"/>
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
								</figure>
								
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>
		
		<?php endif;?>
		
		<?php  if ( 'style7' === $settings['style'] ) : ?>
		
		<section class="chooseus-nine p_relative pt_150 pb_75 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 image-column">
                        <div class="image_block_14">
                            <div class="image-box p_relative d_block pr_150 pb_150">
                                <div class="shape">
									<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                                    <div class="shape-1 p_absolute rotate-me" style="background-image:url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
									<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                                    <div class="shape-2 p_absolute rotate-me" style="background-image:url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
                                    <div class="shape-3 p_absolute"></div>
                                    <div class="shape-4 p_absolute"></div>
                                    <div class="shape-5 p_absolute"></div>
                                </div>
                                <figure class="image image-1 p_relative d_block wow slideInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
									<?php  if ( esc_url($settings['image']['id']) ) : ?>   
									<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
								</figure>
                                <figure class="image image-2 p_absolute r_0 b_0 wow slideInRight animated" data-wow-delay="00ms" data-wow-duration="1500ms">
									<?php  if ( esc_url($settings['image2']['id']) ) : ?>   
									<img src="<?php echo wp_get_attachment_url($settings['image2']['id']);?>" alt="<?php echo esc_attr($settings['alt_text2']);?>"/>
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
								</figure>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style8' === $settings['style'] ) : ?>
		
		<section class="chooseus-11 chooseus-three p_relative <?php echo esc_attr($settings['sec_class']);?>">
			<div data-animation-box class="outer-container clearfix">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
				<div data-animation-text class="overlay-anim-black-bg bg-layer p_absolute l_0 t_0" data-animation="overlay-animation" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
			</div>
		</section>
		
		<?php endif;?>
		
		<?php  if ( 'style9' === $settings['style'] ) : ?>
		
		<section class="chooseus-12 p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 image-column">
                        <div class="image_block_22">
                            <div data-animation-box class="image-box p_relative d_block ml_30 pt_160 pr_190">
                                <div class="shape">
									<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                                    <div class="shape-1 p_absolute t_90 rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
									<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                                    <div class="shape-2 p_absolute b_80 float-bob-y" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
                                </div>
                                <figure data-animation-text class="overlay-anim-black-bg image image-1 p_relative d_block z_1 paroller" data-animation="overlay-animation">
									<?php  if ( esc_url($settings['image']['id']) ) : ?>   
									<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
								</figure>
                                <figure data-animation-text class="overlay-anim-black-bg image image-2 p_absolute t_0 r_0 paroller-2" data-animation="overlay-animation">
									<?php  if ( esc_url($settings['image2']['id']) ) : ?>   
									<img src="<?php echo wp_get_attachment_url($settings['image2']['id']);?>" alt="<?php echo esc_attr($settings['alt_text2']);?>"/>
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
								</figure>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
             
		<?php 
	}

}