<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Faq extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_faq';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Faq', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'faq',
			[
				'label' => esc_html__( 'Faq', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Choose Style 1', 'tranzix' ),
						'style2' => esc_html__( 'Choose Style 2', 'tranzix' ),
						'style3' => esc_html__( 'Choose Style 3', 'tranzix' ),
						'style4' => esc_html__( 'Choose Style 4', 'tranzix' ),
						'style5' => esc_html__( 'Choose Style 5', 'tranzix' ),
						'style6' => esc_html__( 'Choose Style 6', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Faq Block One', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section1',
					[
						'label' => __( 'Faq Block Two', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat1', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		<?php  if ( 'style1' === $settings['style'] ) : ?>
		
        <section class="faq-three service-page-4 p_relative pt_140 pb_150 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title p_relative d_block mb_45 centred">
                    <h2 class="d_block fs_40 lh_50 fw_bold font_family_inter"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
                    <div class="col-lg-8 col-md-12 col-sm-12 offset-lg-2 content-column">
                        <div class="content_block_five">
                            <div class="content-box p_relative d_block">
                                <ul class="accordion-box">
								
									<?php foreach($settings['repeat'] as $key=>$item):?>
								
                                    <li class="accordion block <?php if($key == 1) echo 'active-block';?> p_relative d_block mb_30">
                                        <div class="acc-btn <?php if($key == 1) echo 'active';?> p_relative d_block tran_5 pt_16 pr_80 pb_16 pl_30">
                                            <div class="icon-outer p_absolute fs_10 tran_5 z_1"><i class="icon-29"></i></div>
                                            <h4 class="p_relative d_block fs_20 lh_30 fw_medium"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                        </div>
                                        <div class="acc-content <?php if($key == 1) echo 'current';?> p_relative pt_25 pr_50 pl_30">
                                            <div class="text p_relative d_block">
                                                <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                            </div>
                                        </div>
                                    </li>
									
									<?php endforeach; ?>
									
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<section class="faq-three service-page-5 p_relative pt_140 pb_150 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title p_relative d_block mb_45 centred">
                    <h2 class="d_block fs_40 lh_50 fw_bold font_family_inter"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
                    <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                        <div class="content_block_five">
                            <div class="content-box p_relative d_block">
                                <ul class="accordion-box">
								
									<?php foreach($settings['repeat'] as $key=>$item):?>
								
                                    <li class="accordion block <?php if($key == 1) echo 'active-block';?> p_relative d_block mb_30">
                                        <div class="acc-btn <?php if($key == 1) echo 'active';?> p_relative d_block tran_5 pt_16 pr_80 pb_16 pl_30">
                                            <div class="icon-outer p_absolute fs_10 tran_5 z_1"><i class="icon-29"></i></div>
                                            <h4 class="p_relative d_block fs_20 lh_30 fw_medium"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                        </div>
                                        <div class="acc-content <?php if($key == 1) echo 'current';?> p_relative pt_25 pr_50 pl_30">
                                            <div class="text p_relative d_block">
                                                <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                            </div>
                                        </div>
                                    </li>
									
									<?php endforeach; ?>
									
                                </ul>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                        <div class="content_block_five">
                            <div class="content-box p_relative d_block">
                                <ul class="accordion-box">
								
									<?php foreach($settings['repeat1'] as $key=>$item):?>
								
                                    <li class="accordion block p_relative d_block mb_30">
                                        <div class="acc-btn p_relative d_block tran_5 pt_16 pr_80 pb_16 pl_30">
                                            <div class="icon-outer p_absolute fs_10 tran_5 z_1"><i class="icon-29"></i></div>
                                            <h4 class="p_relative d_block fs_20 lh_30 fw_medium"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                        </div>
                                        <div class="acc-content p_relative pt_25 pr_50 pl_30">
                                            <div class="text p_relative d_block">
                                                <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                            </div>
                                        </div>
                                    </li>
									
									<?php endforeach; ?>
									
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
		<section class="faq-page-section p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 content-side">
                        <div class="faq-content">
                            <div class="content-one p_relative d_block mb_90">
								<?php if($settings['title']): ?>
                                <div class="title p_relative d_block mb_30">
                                    <h3 class="d_block fs_30 lh_40 fw_bold"><?php echo $settings['title'];?></h3>
                                </div>
								<?php endif; ?>
                                <div class="content_block_five">
                                    <div class="content-box p_relative d_block">
                                        <ul class="accordion-box">
										
											<?php foreach($settings['repeat'] as $key=>$item):?>
										
                                            <li class="accordion block <?php if($key == 1) echo 'active-block';?> p_relative d_block mb_30">
                                                <div class="acc-btn <?php if($key == 1) echo 'active';?> p_relative d_block tran_5 pt_16 pr_80 pb_16 pl_30">
                                                    <div class="icon-outer p_absolute fs_10 tran_5 z_1"><i class="icon-29"></i></div>
                                                    <h4 class="p_relative d_block fs_20 lh_30 fw_medium"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                                </div>
                                                <div class="acc-content <?php if($key == 1) echo 'current';?> p_relative pt_25 pr_50 pl_30">
                                                    <div class="text p_relative d_block">
                                                        <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                                    </div>
                                                </div>
                                            </li>
											
											<?php endforeach; ?>
											
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style4' === $settings['style'] ) : ?>
		
		<section class="faq-page-section p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 content-side">
                        <div class="faq-content">
                            <div class="content-three p_relative d_block">
								<?php if($settings['title']): ?>
                                <div class="title p_relative d_block mb_30">
                                    <h3 class="d_block fs_30 lh_40 fw_bold"><?php echo $settings['title'];?></h3>
                                </div>
								<?php endif; ?>
                                <div class="content_block_five">
                                    <div class="content-box p_relative d_block">
                                        <ul class="accordion-box">
										
											<?php foreach($settings['repeat'] as $key=>$item):?>
										
                                            <li class="accordion block p_relative d_block mb_30">
                                                <div class="acc-btn p_relative d_block tran_5 pt_16 pr_80 pb_16 pl_30">
                                                    <div class="icon-outer p_absolute fs_10 tran_5 z_1"><i class="icon-29"></i></div>
                                                    <h4 class="p_relative d_block fs_24 lh_30 fw_medium"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                                </div>
                                                <div class="acc-content p_relative pt_25 pr_50 pl_30">
                                                    <div class="text p_relative d_block">
                                                        <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                                    </div>
                                                </div>
                                            </li>
											
											<?php endforeach; ?>
											
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style5' === $settings['style'] ) : ?>
		
		<section class="faq-page-section faq-page-2 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 content-side">
                        <div class="faq-content">
                            <div class="content_block_five">
                                <div class="content-box p_relative d_block">
                                    <ul class="accordion-box">
									
										<?php foreach($settings['repeat'] as $key=>$item):?>
									
                                        <li class="accordion block <?php if($key == 1) echo 'active-block';?> p_relative d_block mb_30">
                                            <div class="acc-btn <?php if($key == 1) echo 'active';?> p_relative d_block tran_5 pt_16 pr_80 pb_16 pl_30">
                                                <div class="icon-outer p_absolute fs_10 tran_5 z_1"><i class="icon-29"></i></div>
                                                <h4 class="p_relative d_block fs_24 lh_30 fw_medium"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                            </div>
                                            <div class="acc-content <?php if($key == 1) echo 'current';?> p_relative pt_25 pr_50 pl_30">
                                                <div class="text p_relative d_block">
                                                    <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                                </div>
                                            </div>
                                        </li>
										
										<?php endforeach; ?>
										
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style6' === $settings['style'] ) : ?>
		
		<section class="faq-page-section faq-page-3 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 faq-column">
                        <div class="faq-content">
                            <div class="content_block_five">
                                <div class="content-box p_relative d_block">
                                    <ul class="accordion-box">
									
										<?php foreach($settings['repeat'] as $key=>$item):?>
									
                                        <li class="accordion block <?php if($key == 0) echo 'active-block';?> p_relative d_block mb_30">
                                            <div class="acc-btn <?php if($key == 0) echo 'active';?> p_relative d_block tran_5 pt_16 pr_80 pb_16 pl_30">
                                                <div class="icon-outer p_absolute fs_10 tran_5 z_1"><i class="icon-29"></i></div>
                                                <h4 class="p_relative d_block fs_24 lh_30 fw_medium"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                            </div>
                                            <div class="acc-content <?php if($key == 0) echo 'current';?> p_relative pt_25 pr_50 pl_30">
                                                <div class="text p_relative d_block">
                                                    <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                                </div>
                                            </div>
                                        </li>
										
										<?php endforeach; ?>
										
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
             
		<?php 
	}

}