<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Footer extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_footer';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Footer', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'footer',
			[
				'label' => esc_html__( 'Footer', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Choose Style 1', 'tranzix' ),
						'style2' => esc_html__( 'Choose Style 2', 'tranzix' ),
						'style3' => esc_html__( 'Choose Style 3', 'tranzix' ),
						'style4' => esc_html__( 'Choose Style 4', 'tranzix' ),
						'style5' => esc_html__( 'Choose Style 5', 'tranzix' ),
						'style6' => esc_html__( 'Choose Style 6', 'tranzix' ),
						'style7' => esc_html__( 'Choose Style 7', 'tranzix' ),
						'style8' => esc_html__( 'Choose Style 8', 'tranzix' ),
						'style9' => esc_html__( 'Choose Style 9', 'tranzix' ),
						'style10' => esc_html__( 'Choose Style 10', 'tranzix' ),
						'style11' => esc_html__( 'Choose Style 11', 'tranzix' ),
						'style12' => esc_html__( 'Choose Style 12', 'tranzix' ),
						'style13' => esc_html__( 'Choose Style 13', 'tranzix' ),
						'style14' => esc_html__( 'Choose Style 14', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Footer Top', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'bgimg',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style11',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style13',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg1',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style13',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg2',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'image',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'conditions' => array(
								'relation' => 'or',
								'terms'    => array(
									array(
										'name'     => 'style',
										'operator' => '==',
										'value'    => 'style1',
									),
									array(
										'name'     => 'style',
										'operator' => '==',
										'value'    => 'style2',
									),
									array(
										'name'     => 'style',
										'operator' => '==',
										'value'    => 'style3',
									),
									array(
										'name'     => 'style',
										'operator' => '==',
										'value'    => 'style10',
									),
									array(
										'name'     => 'style',
										'operator' => '==',
										'value'    => 'style12',
									),
									array(
										'name'     => 'style',
										'operator' => '==',
										'value'    => 'style13',
									),
								),
							),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'conditions' => array(
								'relation' => 'or',
								'terms'    => array(
									array(
										'name'     => 'style',
										'operator' => '==',
										'value'    => 'style1',
									),
									array(
										'name'     => 'style',
										'operator' => '==',
										'value'    => 'style2',
									),
									array(
										'name'     => 'style',
										'operator' => '==',
										'value'    => 'style3',
									),
									array(
										'name'     => 'style',
										'operator' => '==',
										'value'    => 'style10',
									),
									array(
										'name'     => 'style',
										'operator' => '==',
										'value'    => 'style12',
									),
									array(
										'name'     => 'style',
										'operator' => '==',
										'value'    => 'style13',
									),
								),
							),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'btnlink',
					[
					  'label' => __( 'Button Url', 'rashid' ),
					  'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style12',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style13',
								),
							),
						),
					  'type' => Controls_Manager::URL,
					  'placeholder' => __( 'https://your-link.com', 'rashid' ),
					  'show_external' => true,
					  'default' => [
						'url' => '',
						'is_external' => true,
						'nofollow' => true,
					  ],
					
				   ]
				);
				$this->add_control(
					  'repeat', 
						[
							'type' => Controls_Manager::REPEATER,
							'seperator' => 'before',
							'default' => 
								[
									['block_title' => esc_html__('Projects Completed', 'rashid')],
								],
							'fields' => 
								[
									[
										'name' => 'block_icons',
										'label' => esc_html__('Enter The icons', 'inovex'),
										'type' => Controls_Manager::ICONS,
										
									],
									[
										'name' => 'block_btnlink',
										'label' => __( 'Button Url', 'rashid' ),
										'type' => Controls_Manager::URL,
										'placeholder' => __( 'https://your-link.com', 'rashid' ),
										'show_external' => true,
										'default' => [
										'url' => '',
										'is_external' => true,
										'nof
										ollow' => true,
										],
									],

								],
							'title_field' => '{{block_title}}',
						 ]
				);
				$this->add_control(
					  'repeat5', 
						[
							'type' => Controls_Manager::REPEATER,
							'seperator' => 'before',
							'default' => 
								[
									['block_title' => esc_html__('Projects Completed', 'rashid')],
								],
							'fields' => 
								[
									[
										'name' => 'block_title',
										'label' => esc_html__('Title', 'rashid'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'rashid')
									],
									[
										'name' => 'block_btnlink',
										'label' => __( 'Button Url', 'rashid' ),
										'type' => Controls_Manager::URL,
										'placeholder' => __( 'https://your-link.com', 'rashid' ),
										'show_external' => true,
										'default' => [
										'url' => '',
										'is_external' => true,
										'nof
										ollow' => true,
										],
									],

								],
							'title_field' => '{{block_title}}',
						 ]
			);
					
				
				
		$this->end_controls_section();
				
				
		
		// New Tab#1

		$this->start_controls_section(
					'content_section1',
					[
						'label' => __( 'Footer Widget One', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'title',
					[
						'label'       => __( 'Title', 'rashid' ),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
							),
						),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'text',
					[
						'label'       => __( 'Description Text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'news_letter_id',
					[
						'label'       => __( 'FeedBurner ID', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your FeedBurner ID', 'rashid' ),
						'default'     => __( 'themeforest', 'rashid' ),
					]
				);
				$this->add_control(
					'email_title',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				
				
		$this->end_controls_section();
		
		// New Tab#2

		$this->start_controls_section(
					'content_section2',
					[
						'label' => __( 'Footer Widget Two', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'title1',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
				  'repeat1', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_btnlink',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									'url' => '',
									'is_external' => true,
									'nof
									ollow' => true,
									],
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
		$this->end_controls_section();	
		
		// New Tab#3

		$this->start_controls_section(
					'content_section3',
					[
						'label' => __( 'Footer Widget Three', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'title2',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
				  'repeat2', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_btnlink',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									'url' => '',
									'is_external' => true,
									'nof
									ollow' => true,
									],
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
		$this->end_controls_section();	
		
		// New Tab#4

		$this->start_controls_section(
					'content_section4',
					[
						'label' => __( 'Footer Widget Four', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'title3',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
				  'repeat3', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
		$this->end_controls_section();	
		
		// New Tab#5

		$this->start_controls_section(
					'content_section5',
					[
						'label' => __( 'Footer Bottom', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'bttn',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);
				$this->add_control(
					'btnlink1',
					[
					  'label' => __( 'Button Url', 'rashid' ),
					  'type' => Controls_Manager::URL,
					  'placeholder' => __( 'https://your-link.com', 'rashid' ),
					  'show_external' => true,
					  'default' => [
						'url' => '',
						'is_external' => true,
						'nofollow' => true,
					  ],
					
				   ]
				);
				$this->add_control(
					'text1',
					[
						'label'       => __( 'Description Text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
				  'repeat4', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_btnlink',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									'url' => '',
									'is_external' => true,
									'nof
									ollow' => true,
									],
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
		$this->end_controls_section();	
		
		// New Tab#6

		$this->start_controls_section(
					'content_section6',
					[
						'label' => __( 'Subscribe Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'subscribe_title',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'news_letter_id',
					[
						'label'       => __( 'FeedBurner ID', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your FeedBurner ID', 'rashid' ),
						'default'     => __( 'themeforest', 'rashid' ),
					]
				);
				$this->add_control(
					'subscribe_title2',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'subscribe_bttn',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);
				
				
				
		$this->end_controls_section();	
		
		
		
		
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
		
		<?php  if ( 'style1' === $settings['style'] ) : ?>
        
        <footer class="footer-one <?php echo esc_attr($settings['sec_class']);?>">
            <div class="pattern-layer">
                <div class="pattern-1 hero-shape-three"></div>
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="pattern-2" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
                <div class="pattern-3 hero-shape-three"></div>
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                <div class="pattern-4" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
            <div class="footer-top">
                <div class="auto-container">
                    <div class="top-inner clearfix">
                        <figure class="footer-logo pull-left">
                            <a href="<?php echo esc_url($settings['btnlink']['url']);?>">
								<?php  if ( esc_url($settings['image']['id']) ) : ?>   
								<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
								<?php else :?>
								<div class="noimage"></div>
								<?php endif;?>
							</a>
                        </figure>
                        <ul class="social-links pull-right clearfix"> 
							<?php foreach($settings['repeat'] as $item):?>
                            <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></li>
							<?php endforeach; ?>
                        </ul>
                    </div>
                </div>
            </div>
            <div class="footer-widget-section">
                <div class="auto-container">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget about-widget wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title'];?></h4>
                                </div>
                                <div class="text">
                                    <p><?php echo $settings['text'];?></p>
                                </div>
                                <div class="subscribe-inner">
									<form class="subscribe-form" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
										<div class="form-group">
											<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
											<input type="email" name="email" placeholder="<?php echo $settings['email_title'];?>" readonly="">
                                            <button type="submit"><i class="icon-4"></i></button>
										</div>
									</form>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_80 wow fadeInUp animated" data-wow-delay="200ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title1'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
										<?php foreach($settings['repeat1'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-2 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget wow fadeInUp animated" data-wow-delay="400ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title2'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat2'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget contact-widget wow fadeInUp animated" data-wow-delay="600ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title3'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="info-list clearfix">
                                        <?php foreach($settings['repeat3'] as $item):?>
                                        <li><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="footer-bottom">
                <div class="auto-container">
                    <div class="bottom-inner clearfix">
                        <div class="copyright pull-left">
                            <p><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a> <?php echo $settings['text1'];?></p>
                        </div>
                        <ul class="footer-nav clearfix pull-right">
                            <?php foreach($settings['repeat4'] as $item):?>
							<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
							<?php endforeach; ?>
                        </ul>
                    </div>
                </div>
            </div>
        </footer>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<footer class="footer-two <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="footer-top-two clearfix">
                    <figure class="footer-logo pull-left">
                        <a href="<?php echo esc_url($settings['btnlink']['url']);?>">
						<?php  if ( esc_url($settings['image']['id']) ) : ?>   
						<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
						<?php else :?>
						<div class="noimage"></div>
						<?php endif;?>
						</a>
                    </figure>
                    <ul class="footer-menu mt_12 pull-right clearfix">
						<?php foreach($settings['repeat5'] as $item):?>
                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
						<?php endforeach; ?>
                    </ul>
                </div>
                <div class="footer-widget-section">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget about-widget wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title'];?></h4>
                                </div>
                                <div class="text">
                                    <p><?php echo $settings['text'];?></p>
                                </div>
                                <ul class="footer-social-two clearfix">
                                    <?php foreach($settings['repeat'] as $item):?>
									<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></li>
									<?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_80 wow fadeInUp animated" data-wow-delay="200ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title1'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat1'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-2 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget wow fadeInUp animated" data-wow-delay="400ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title2'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat2'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget contact-widget wow fadeInUp animated" data-wow-delay="600ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title3'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="info-list clearfix">
                                        <?php foreach($settings['repeat3'] as $item):?>
                                        <li><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="footer-bottom">
                <div class="auto-container">
                    <div class="bottom-inner clearfix">
                        <div class="copyright pull-left">
                            <p><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a> <?php echo $settings['text1'];?></p>
                        </div>
                        <ul class="footer-nav clearfix pull-right">
                            <?php foreach($settings['repeat4'] as $item):?>
							<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
							<?php endforeach; ?>
                        </ul>
                    </div>
                </div>
            </div>
        </footer>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
		<footer class="footer-three p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="pattern-layer">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="pattern-1 p_absolute b_0"  data-parallax='{"x": 100}'  style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                <div class="pattern-2 p_absolute r_0 b_0"  data-parallax='{"x": 100}'  style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
            <div class="auto-container">
                <div class="footer-widget-section">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget about-widget wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                                <figure class="footer-logo p_relative d_block mb_35">
									<a href="<?php echo esc_url($settings['btnlink']['url']);?>">
										<?php  if ( esc_url($settings['image']['id']) ) : ?>   
										<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
										<?php else :?>
										<div class="noimage"></div>
										<?php endif;?>
									</a>
								</figure>
                                <div class="text">
                                    <p><?php echo $settings['text'];?></p>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_80 wow fadeInUp animated" data-wow-delay="200ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title1'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat1'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-2 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget wow fadeInUp animated" data-wow-delay="400ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title2'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat2'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget contact-widget wow fadeInUp animated" data-wow-delay="600ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title3'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="info-list clearfix">
                                        <?php foreach($settings['repeat3'] as $item):?>
                                        <li><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="footer-bottom">
                <div class="auto-container">
                    <div class="bottom-inner clearfix">
                        <div class="copyright pull-left">
                            <p><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a> <?php echo $settings['text1'];?></p>
                        </div>
                        <ul class="footer-nav clearfix pull-right">
                            <?php foreach($settings['repeat4'] as $item):?>
							<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
							<?php endforeach; ?>
                        </ul>
                    </div>
                </div>
            </div>
        </footer>
		
		<?php endif;?>
		
		<?php  if ( 'style4' === $settings['style'] ) : ?>
		
		<footer class="footer-four p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="pattern-layer">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="pattern-1 p_absolute l_120 b_0 h_170" data-parallax='{"x": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                <div class="pattern-2 p_absolute r_0 t_0" data-parallax='{"x": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
            <div class="auto-container">
                <div class="footer-widget-section">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget about-widget wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                                <div class="text">
                                    <p class="font_family_poppins fs_17"><?php echo $settings['text'];?></p>
                                </div>
                                <ul class="footer-social-two clearfix">
                                    <?php foreach($settings['repeat'] as $item):?>
									<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></li>
									<?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_80 wow fadeInUp animated" data-wow-delay="200ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title1'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat1'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-2 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget wow fadeInUp animated" data-wow-delay="400ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title2'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat2'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget contact-widget wow fadeInUp animated" data-wow-delay="600ms" data-wow-duration="1500ms">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title3'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="info-list clearfix">
                                        <?php foreach($settings['repeat3'] as $item):?>
                                        <li><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="footer-bottom">
                <div class="auto-container">
                    <div class="bottom-inner">
                        <div class="copyright centred">
                            <p><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a> <?php echo $settings['text1'];?></p>
                        </div>
                    </div>
                </div>
            </div>
        </footer>
		
		<?php endif;?>
		
		<?php  if ( 'style5' === $settings['style'] ) : ?>
		
		
		<footer class="footer-five p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="pattern-layer">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="pattern-1 p_absolute l_120 b_0" data-parallax='{"x": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                <div class="pattern-2 p_absolute r_0 t_0" data-parallax='{"x": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg2']['id']) ) : ?>
                <div class="pattern-3 p_absolute l_0 t_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg2']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
            <div class="auto-container">
                <div class="footer-widget-section">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget about-widget">
                                <div class="text">
                                    <p class="font_family_poppins fs_17"><?php echo $settings['text'];?></p>
                                </div>
                                <ul class="footer-social-two clearfix">
                                   <?php foreach($settings['repeat'] as $item):?>
									<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></li>
									<?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_80">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title1'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat1'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-2 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title2'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat2'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget contact-widget">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title3'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="info-list clearfix">
                                        <?php foreach($settings['repeat3'] as $item):?>
                                        <li><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="footer-bottom">
                <div class="auto-container">
                    <div class="bottom-inner">
                        <div class="copyright centred">
                            <p><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a> <?php echo $settings['text1'];?></p>
                        </div>
                    </div>
                </div>
            </div>
        </footer>
		
		<?php endif;?>
		
		<?php  if ( 'style6' === $settings['style'] ) : ?>
		
		<footer class="footer-six p_relative pt_150 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="pattern-layer">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="pattern-1 p_absolute l_120 b_0" data-parallax='{"x": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                <div class="pattern-2 p_absolute t_0 r_0" data-parallax='{"x": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
            <div class="auto-container">
                <div class="footer-widget-section">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget about-widget mr_60">
                                <div class="text">
                                    <p><?php echo $settings['text'];?></p>
                                </div>
                                <ul class="footer-social-three clearfix">
                                    <?php foreach($settings['repeat'] as $item):?>
									<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></li>
									<?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-2 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_40">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title1'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat1'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_70">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title2'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat2'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget contact-widget">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title3'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="info-list clearfix">
                                        <?php foreach($settings['repeat3'] as $item):?>
                                        <li><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="footer-bottom">
                <div class="auto-container">
                    <div class="bottom-inner">
                        <div class="copyright centred">
                            <p><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a> <?php echo $settings['text1'];?></p>
                        </div>
                    </div>
                </div>
            </div>
        </footer>
		
		<?php endif;?>
		
		<?php  if ( 'style7' === $settings['style'] ) : ?>
		
		<footer class="footer-seven p_relative <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
            <div class="pattern-layer p_absolute l_0 t_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
            <div class="auto-container">
                <div class="footer-widget-section">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget about-widget mr_60 wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                                <div class="text">
                                    <p><?php echo $settings['text'];?></p>
                                </div>
                                <ul class="footer-social clearfix">
                                    <?php foreach($settings['repeat'] as $item):?>
									<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></li>
									<?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-2 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_40">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title1'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat1'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_70">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title2'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat2'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget contact-widget">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title3'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="info-list clearfix">
                                        <?php foreach($settings['repeat3'] as $item):?>
                                        <li><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="subscribe-inner">
                    <div class="row clearfix">
                        <div class="col-lg-6 col-md-12 col-sm-12 text-column">
                            <div class="text">
                                <h2><?php echo $settings['subscribe_title'];?></h2>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12 form-column">
                            <div class="form-inner">
							
								<form class="subscribe-form default-form" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
									<div class="form-group">
										<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
										<input type="email" name="email" placeholder="<?php echo $settings['subscribe_title2'];?>" required="">
											<button type="submit" class="theme-btn"><?php echo $settings['subscribe_bttn'];?> <i class="icon-4"></i></button>
									</div>
								</form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="footer-bottom">
                <div class="auto-container">
                    <div class="bottom-inner">
                        <div class="copyright centred">
                            <p><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a> <?php echo $settings['text1'];?></p>
                        </div>
                    </div>
                </div>
            </div>
        </footer>
		
		<?php endif;?>
		
		<?php  if ( 'style8' === $settings['style'] ) : ?>
		
		<footer class="footer-ten p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="outer-container">
                <div class="auto-container">
                    <div class="footer-widget-section">
                        <div class="row clearfix">
                            <div class="col-lg-4 col-md-6 col-sm-12 footer-column">
                                <div class="footer-widget about-widget mr_60">
                                    <div class="text">
                                        <p><?php echo $settings['text'];?></p>
                                    </div>
                                    <ul class="footer-social-three clearfix">
                                        <?php foreach($settings['repeat'] as $item):?>
										<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                            <div class="col-lg-2 col-md-6 col-sm-12 footer-column">
                                <div class="footer-widget links-widget ml_40">
                                    <div class="widget-title">
                                        <h4><?php echo $settings['title1'];?></h4>
                                    </div>
                                    <div class="widget-content">
                                        <ul class="links-list clearfix">
                                            <?php foreach($settings['repeat1'] as $item):?>
											<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
											<?php endforeach; ?>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                            <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                                <div class="footer-widget links-widget ml_70">
                                    <div class="widget-title">
                                        <h4><?php echo $settings['title2'];?></h4>
                                    </div>
                                    <div class="widget-content">
                                        <ul class="links-list clearfix">
                                            <?php foreach($settings['repeat2'] as $item):?>
											<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
											<?php endforeach; ?>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                            <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                                <div class="footer-widget contact-widget">
                                    <div class="widget-title">
                                        <h4><?php echo $settings['title3'];?></h4>
                                    </div>
                                    <div class="widget-content">
                                        <ul class="info-list clearfix">
                                            <?php foreach($settings['repeat3'] as $item):?>
											<li><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
											<?php endforeach; ?>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="footer-bottom">
                    <div class="auto-container">
                        <div class="bottom-inner">
                            <div class="copyright centred">
                                <p><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a> <?php echo $settings['text1'];?></p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </footer>
		
		<?php endif;?>
		
		<?php  if ( 'style9' === $settings['style'] ) : ?>
		
		<footer class="footer-11 p_relative <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
            <div class="image-layer p_absolute l_0 t_90 paroller" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
            <div class="outer-container">
                <div class="auto-container">
                    <div class="footer-widget-section">
                        <div class="row clearfix">
                            <div class="col-lg-4 col-md-6 col-sm-12 footer-column">
                                <div class="footer-widget about-widget mr_60">
                                    <div class="text">
                                        <p><?php echo $settings['text'];?></p>
                                    </div>
                                    <ul class="footer-social-three clearfix">
                                        <?php foreach($settings['repeat'] as $item):?>
										<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                            <div class="col-lg-2 col-md-6 col-sm-12 footer-column">
                                <div class="footer-widget links-widget ml_40">
                                    <div class="widget-title">
                                        <h4><?php echo $settings['title1'];?></h4>
                                    </div>
                                    <div class="widget-content">
                                        <ul class="links-list clearfix">
                                            <?php foreach($settings['repeat1'] as $item):?>
											<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
											<?php endforeach; ?>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                            <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                                <div class="footer-widget links-widget ml_70">
                                    <div class="widget-title">
                                        <h4><?php echo $settings['title2'];?></h4>
                                    </div>
                                    <div class="widget-content">
                                        <ul class="links-list clearfix">
                                            <?php foreach($settings['repeat2'] as $item):?>
											<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
											<?php endforeach; ?>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                            <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                                <div class="footer-widget contact-widget">
                                    <div class="widget-title">
                                        <h4><?php echo $settings['title3'];?></h4>
                                    </div>
                                    <div class="widget-content">
                                        <ul class="info-list clearfix">
                                            <?php foreach($settings['repeat3'] as $item):?>
											<li><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
											<?php endforeach; ?>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="footer-bottom">
                    <div class="auto-container">
                        <div class="bottom-inner">
                            <div class="copyright centred">
                                <p><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a> <?php echo $settings['text1'];?></p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </footer>
		
		<?php endif;?>
		
		<?php  if ( 'style10' === $settings['style'] ) : ?>
		
		<footer class="footer-13 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="shape">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="shape-1" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                <div class="shape-2 p_absolute l_0 t_75" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg2']['id']) ) : ?>
                <div class="shape-3 p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg2']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
            <div class="footer-top-two clearfix">
                <div class="auto-container">
                    <figure class="footer-logo pull-left">
                        <a href="<?php echo esc_url($settings['btnlink']['url']);?>">
							<?php  if ( esc_url($settings['image']['id']) ) : ?>   
							<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
							<?php else :?>
							<div class="noimage"></div>
							<?php endif;?>
						</a>
                    </figure>
                    <ul class="footer-menu mt_12 pull-right clearfix">
                        <?php foreach($settings['repeat5'] as $item):?>
                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
						<?php endforeach; ?>
                    </ul>
                </div>
            </div>
            <div class="auto-container">
                <div class="footer-widget-section">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget about-widget">
                                <div class="text">
                                    <p><?php echo $settings['text'];?></p>
                                </div>
                                <ul class="footer-social-two clearfix">
                                    <?php foreach($settings['repeat'] as $item):?>
									<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></li>
									<?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_80">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title1'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat1'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-2 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title2'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat2'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget contact-widget">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title3'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="info-list clearfix">
                                        <?php foreach($settings['repeat3'] as $item):?>
                                        <li><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="footer-bottom">
                <div class="auto-container">
                    <div class="bottom-inner centred">
                        <div class="copyright">
                            <p><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a> <?php echo $settings['text1'];?></p>
                        </div>
                    </div>
                </div>
            </div>
        </footer>
		
		<?php endif;?>
		
		<?php  if ( 'style11' === $settings['style'] ) : ?>
		
		<footer class="footer-14 p_relative pt_130 <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
            <div class="pattern-layer p_absolute l_0 t_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
            <div class="auto-container">
                <div class="footer-widget-section">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget about-widget mr_60">
                                <div class="text">
                                    <p><?php echo $settings['text'];?></p>
                                </div>
                                <ul class="footer-social-three clearfix">
                                    <?php foreach($settings['repeat'] as $item):?>
									<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></li>
									<?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-2 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_40">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title1'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat1'] as $item):?>
										<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_70">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title2'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat2'] as $item):?>
										<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget contact-widget">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title3'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="info-list clearfix">
                                        <?php foreach($settings['repeat3'] as $item):?>
										<li><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="footer-bottom">
                <div class="auto-container">
                    <div class="bottom-inner">
                        <div class="copyright centred">
                            <p><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a> <?php echo $settings['text1'];?></p>
                        </div>
                    </div>
                </div>
            </div>
        </footer>
		
		<?php endif;?>
		
		<?php  if ( 'style12' === $settings['style'] ) : ?>
		
		<footer class="footer-15 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="footer-top-two clearfix">
                    <figure class="footer-logo pull-left">
                        <a href="<?php echo esc_url($settings['btnlink']['url']);?>">
							<?php  if ( esc_url($settings['image']['id']) ) : ?>   
							<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
							<?php else :?>
							<div class="noimage"></div>
							<?php endif;?>
						</a>
                    </figure>
                    <ul class="footer-menu mt_12 pull-right clearfix">
                        <?php foreach($settings['repeat5'] as $item):?>
                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
						<?php endforeach; ?>
                    </ul>
                </div>
                <div class="footer-widget-section">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget about-widget">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title'];?></h4>
                                </div>
                                <div class="text">
                                    <p><?php echo $settings['text'];?></p>
                                </div>
                                <ul class="footer-social-two clearfix">
                                    <?php foreach($settings['repeat'] as $item):?>
									<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></li>
									<?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_80">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title1'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat1'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-2 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title2'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat2'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget contact-widget">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title3'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="info-list clearfix">
                                        <?php foreach($settings['repeat3'] as $item):?>
                                        <li><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="footer-bottom">
                    <div class="bottom-inner clearfix">
                        <div class="copyright pull-left">
                            <p><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a> <?php echo $settings['text1'];?></p>
                        </div>
                        <ul class="footer-nav clearfix pull-right">
                            <?php foreach($settings['repeat4'] as $item):?>
							<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
							<?php endforeach; ?>
                        </ul>
                    </div>
                </div>
            </div>
        </footer>
		
		<?php endif;?>
		
		<?php  if ( 'style13' === $settings['style'] ) : ?>
		
		<footer class="footer-16 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="shape">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="shape-1 p_absolute l_0 paroller-4" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                <div class="shape-2 p_absolute r_90 paroller" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
            <div class="footer-top">
                <div class="auto-container">
                    <div class="top-inner clearfix">
                        <figure class="footer-logo pull-left">
                            <a href="<?php echo esc_url($settings['btnlink']['url']);?>">
								<?php  if ( esc_url($settings['image']['id']) ) : ?>   
								<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
								<?php else :?>
								<div class="noimage"></div>
								<?php endif;?>
							</a>
                        </figure>
                        <ul class="social-links pull-right clearfix"> 
                            <?php foreach($settings['repeat'] as $item):?>
                            <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a></li>
							<?php endforeach; ?>
                        </ul>
                    </div>
                </div>
            </div>
            <div class="footer-widget-section">
                <div class="auto-container">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget about-widget">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title'];?></h4>
                                </div>
                                <div class="text">
                                    <p><?php echo $settings['text'];?></p>
                                </div>
                                <div class="subscribe-inner">
                                    <form class="subscribe-form" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
										<div class="form-group">
											<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
											<input type="email" name="email" placeholder="<?php echo $settings['email_title'];?>" readonly="">
                                            <button type="submit"><i class="icon-4"></i></button>
										</div>
									</form>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget ml_80">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title1'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat1'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-2 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget links-widget">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title2'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="links-list clearfix">
                                        <?php foreach($settings['repeat2'] as $item):?>
                                        <li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12 footer-column">
                            <div class="footer-widget contact-widget">
                                <div class="widget-title">
                                    <h4><?php echo $settings['title3'];?></h4>
                                </div>
                                <div class="widget-content">
                                    <ul class="info-list clearfix">
                                        <?php foreach($settings['repeat3'] as $item):?>
                                        <li><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
										<?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="footer-bottom">
                <div class="auto-container">
                    <div class="bottom-inner clearfix">
                        <div class="copyright pull-left">
                            <p><a href="<?php echo esc_url($settings['btnlink1']['url']);?>"><?php echo $settings['bttn'];?></a> <?php echo $settings['text1'];?></p>
                        </div>
                        <ul class="footer-nav clearfix pull-right">
                            <?php foreach($settings['repeat4'] as $item):?>
							<li><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></li>
							<?php endforeach; ?>
                        </ul>
                    </div>
                </div>
            </div>
        </footer>
		
		<?php endif;?>
		
		<?php  if ( 'style14' === $settings['style'] ) : ?>
		
		
		<?php endif;?>
             
		<?php 
	}

}