<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Gallery extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_gallery';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Gallery', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'gallery',
			[
				'label' => esc_html__( 'Gallery', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Choose Style 1', 'tranzix' ),
						'style2' => esc_html__( 'Choose Style 2', 'tranzix' ),
						'style3' => esc_html__( 'Choose Style 3', 'tranzix' ),
						'style4' => esc_html__( 'Choose Style 4', 'tranzix' ),
						'style5' => esc_html__( 'Choose Style 5', 'tranzix' ),
						'style6' => esc_html__( 'Choose Style 6', 'tranzix' ),
						'style7' => esc_html__( 'Choose Style 7', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'bgimg',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
					),
				),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'bgimg1',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
					),
				),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
					),
			 	 ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
					),
				 ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Gallery Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_column',
									'label'   => esc_html__( 'Column', 'rashid' ),
									'type'    => Controls_Manager::NUMBER,
									'default' => 2,
									'min'     => 1,
									'max'     => 12,
									'step'    => 1,
								],
								[
									'name' => 'block_image',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_alt_text',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_bgimg',
									'label' => esc_html__('Background image', 'rashid'),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_subtitle',
									'label' => esc_html__('Subtitle', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_btnlink',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									'url' => '',
									'is_external' => true,
									'nof
									ollow' => true,
									],
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>

<?php
      echo '
     <script>
 jQuery(document).ready(function($) {

//put the js code under this line 

	if ($(".four-item-carousel").length) {
		$(".four-item-carousel").owlCarousel({
			loop:true,
			margin:30,
			nav:true,
			smartSpeed: 500,
			autoplay: 1000,
			responsive:{
				0:{
					items:1
				},
				480:{
					items:2
				},
				600:{
					items:2
				},
				800:{
					items:3
				},
				1024:{
					items:4
				}
			}
		});    		
	}

//put the code above the line 

  });
</script>';


?>


<?php
      echo '
     <script>
 jQuery(document).ready(function($) {

//put the js code under this line 

	if ($(".project-carousel").length) {
		$(".project-carousel").owlCarousel({
			loop:true,
			margin:0,
			nav:true,
			smartSpeed: 500,
			autoplay: 1000,
			responsive:{
				0:{
					items:1
				},
				480:{
					items:2
				},
				600:{
					items:2
				},
				800:{
					items:3
				},
				1024:{
					items:4
				}
			}
		});    		
	}

//put the code above the line 

  });
</script>';


?>


<?php
      echo '
     <script>
 jQuery(document).ready(function($) {

//put the js code under this line 

	if ($(".project-carousel-two").length) {
		$(".project-carousel-two").owlCarousel({
			loop:true,
			margin:70,
			nav:true,
			smartSpeed: 500,
			autoplay: 1000,
			responsive:{
				0:{
					items:1
				},
				480:{
					items:1
				},
				600:{
					items:1
				},
				800:{
					items:2
				},
				1024:{
					items:2
				}
			}
		});    		
	}

//put the code above the line 

  });
</script>';


?>
        
		<?php  if ( 'style1' === $settings['style'] ) : ?>
		
		<section class="project-one p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="upper-box p_relative d_block mb_50">
                    <div class="row clearfix">
                        <div class="col-lg-6 col-md-12 col-sm-12 title-column">
                            <div class="sec-title-two p_relative d_block mr_100">
                                <span class="p_relative d_iblock font_family_oxygen fs_15 lh_40 pl_30 pr_30 mb_17"><?php echo $settings['subtitle'];?></span><br />
                                <h2 class="d_block fs_40 fw_bold font_family_oxygen"><?php echo $settings['title'];?></h2>
                            </div>
                        </div>
                        <div class="col-lg-4 col-md-6 col-sm-12 text-column">
                            <div class="text p_relative d_block mr_80 mt_60">
                                <p class="fs_18 font_family_oxygen"><?php echo $settings['text'];?></p>
                            </div>
                        </div>
                    </div>
                </div>
				<?php endif; ?>
                <div class="inner-content p_relative d_block">
                    <div class="four-item-carousel owl-carousel owl-theme owl-dots-none nav-style-two">
					
						<?php foreach($settings['repeat'] as $item):?>
					
                        <div class="project-block-one">
                            <div class="inner-box p_relative d_block b_radius_5">
                                <figure class="image-box">
									<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
									<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
								</figure>
                                <div class="content-box p_absolute l_0 d_block pl_30 pr_30 pb_30">
									<?php if(wp_get_attachment_url($item['block_bgimg']['id'])): ?>
                                    <div class="shape p_absolute l_0 b_0" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
									<?php else :?>
									<div class="noimage">
									<?php endif;?>
									</div>
                                    <h4 class="d_block fs_20 lh_30 font_family_oxygen"><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></h4>
                                    <div class="link p_absolute b_20 r_30"><a href="<?php echo esc_url($item['block_btnlink']['url']);?>" class="p_relative d_iblock w_50 h_50 lh_50 text-center b_radius_50 fs_14"><i class="icon-4"></i></a></div>
                                </div>
                            </div>
                        </div>
						
						<?php endforeach; ?>
						
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<section class="project-three home-8 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="outer-container">
                <div class="project-carousel owl-carousel owl-theme owl-dots-none owl-nav-none">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="project-block-three">
                        <div class="inner-box p_relative d_block">
                            <figure class="image-box p_relative d_block">
								<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
								<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
								<?php else :?>
								<div class="noimage"></div>
								<?php endif;?>
							</figure>
                            <div class="view-btn">
								<a href="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" class="lightbox-image">
								<i class="icon-61"></i>
							</a>
							</div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
		<section class="project-three home-11 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="outer-container">
                <div class="project-carousel owl-carousel owl-theme owl-dots-none owl-nav-none">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="project-block-three">
                        <div class="inner-box p_relative d_block">
                            <figure class="image-box p_relative d_block">
								<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
								<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
								<?php else :?>
								<div class="noimage"></div>
								<?php endif;?>
							</figure>
                            <div class="view-btn">
							<a href="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" class="lightbox-image"><i class="icon-61"></i></a></div>
                            <div class="lower-content p_absolute l_0 b_0 pl_40 tran_5">
                                <h3 class="d_block fs_24 lh_30 fw_sbold font_family_jost mb_6"><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></h3>
                                <p><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></p>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style4' === $settings['style'] ) : ?>
		
		<section class="project-six p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title-nine p_relative d_block mb_50 centred">
                    <h6 class="d_iblock pl_20 pr_20 fs_14 lh_30 b_radius_5 mb_18 fw_medium font_family_poppins"><?php echo $settings['subtitle'];?></h6>
                    <h2 class="d_block fs_45 lh_55 fw_bold font_family_jost"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 project-block">
                        <div class="project-block-five wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                            <div class="inner-box p_relative d_block">
                                <div class="image-box p_relative d_block">
                                    <figure class="image p_relative d_block b_radius_5">
										<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
										<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
										<?php else :?>
										<div class="noimage"></div>
										<?php endif;?>
									</figure>
                                    <div class="link p_absolute tran_5">
										<a href="<?php echo esc_url($item['block_btnlink']['url']);?>" class="w_60 h_60 lh_60 centred color_black p_relative d_iblock fs_16">
											<i class="icon-4"></i>
										</a>
									</div>
                                </div>
                                <div class="lower-content p_relative pt_25 pb_40">
                                    <h4 class="d_block fs_20 lh_30 fw_sbold font_family_jost mb_4"><a href="<?php echo esc_url($item['block_btnlink']['url']);?>" class="d_iblock p_relative color_black"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></h4>
                                    <p class="d_block fs_16 font_family_poppins"><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></p>
                                </div>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style5' === $settings['style'] ) : ?>
		
		<section class="screenshot-section pt_110 pb_110 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row align-items-center clearfix">
					<?php if($settings['title']): ?>
                    <div class="col-xl-4 col-lg-12 content-column">
                        <div class="sec-title-ten p_relative d_block pb_85">
                            <span class="sub-title p_relative d_iblock fs_15 fw_medium font_family_jost lh_30 uppercase pl_20 pr_20 mb_20"><?php echo $settings['subtitle'];?></span>
                            <h2 class="d_block fs_50 lh_55 fw_bold font_family_jost mb_20"><?php echo $settings['title'];?></h2>
                            <p class="d_block fs_16 font_family_poppins"><?php echo $settings['text'];?></p>
                        </div>
                    </div>
					<?php endif; ?>
                    <div class="col-xl-8 col-lg-12 col-sm-12 inner-column">
                        <div class="inner-box p_relative">
							<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                            <div class="screen-mobile p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
							<?php else :?>	
							<div class="noimage">
							<?php endif;?>
							</div>
                            <div class="four-item-carousel owl-carousel owl-theme owl-dots-none">
							
								<?php foreach($settings['repeat'] as $item):?>
							
                                <figure class="screenshot p_relative d_block b_shadow_6 mt_50 mb_50">
									<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
									<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
								</figure>
								
								<?php endforeach; ?>
								
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style6' === $settings['style'] ) : ?>
		
		<section class="project-three home-15 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="outer-container">
                <div class="project-carousel owl-carousel owl-theme owl-dots-none owl-nav-none">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="project-block-three">
                        <div class="inner-box p_relative d_block">
                            <figure class="image-box p_relative d_block">
							<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
							<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
							<?php else :?>
							<div class="noimage"></div>
							<?php endif;?>
							</figure>
                            <div class="view-btn"><a href="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" class="lightbox-image"><i class="icon-61"></i></a></div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style7' === $settings['style'] ) : ?>
		
		<section class="project-three about-page-2 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="shape-layer">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="shape-1 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                <div class="shape-2 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
            <div class="outer-container">
                <div class="project-carousel-two owl-carousel owl-theme owl-dots-none owl-nav-none">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="project-block-three">
                        <div class="inner-box p_relative d_block">
                            <figure class="image-box p_relative d_block">
								<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
								<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
								<?php else :?>
								<div class="noimage"></div>
								<?php endif;?>
							</figure>
                            <div class="view-btn">
								<a href="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" class="lightbox-image">
									<i class="icon-61"></i>
								</a>
							</div>
                            <div class="lower-content p_absolute l_0 b_0 pl_40 tran_5">
                                <h3 class="d_block fs_20 lh_30 fw_sbold mb_6"><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></h3>
                                <p><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></p>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
             
		<?php 
	}

}