<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Pricing_Tab extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_pricing_tab';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Pricing Tab', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'pricing_tab',
			[
				'label' => esc_html__( 'Pricing Tab', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style4' => esc_html__( 'Choose Style 4', 'tranzix' ),
						'style5' => esc_html__( 'Choose Style 5', 'tranzix' ),
						'style12' => esc_html__( 'Choose Style 12', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style10',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style12',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style13',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'bgimg',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
					),
				),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'bgimg1',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
					),
				),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Pricing Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_button',
									'label'       => __( 'Button', 'rashid' ),
									'type'        => Controls_Manager::TEXT,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Button Title', 'rashid' ),
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_price',
									'label' => esc_html__('Price', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'ff_sing',
									'label' => esc_html__('Counter Sing', 'rashid'),
									'type' => Controls_Manager::TEXT,
									'default' => esc_html__('', 'hekim')
								],
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_feature_str',
									'label'       => __( 'Features List', 'rashid' ),
									'type'        => Controls_Manager::TEXTAREA,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Features List', 'rashid' ),
									'default'     => __( '', 'rashid' ),
								],
								[
									'name' => 'block_button1',
									'label'       => __( 'Button', 'rashid' ),
									'type'        => Controls_Manager::TEXT,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Button Title', 'rashid' ),
								],
								[
									'name' => 'block_btnlink1',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									'url' => '',
									'is_external' => true,
									'nof
									ollow' => true,
									],
								],
								[
									'name' => 'block_bgimg',
									'label' => esc_html__('Background image', 'rashid'),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_title2',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_price2',
									'label' => esc_html__('Price', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'ff_sing2',
									'label' => esc_html__('Counter Sing', 'rashid'),
									'type' => Controls_Manager::TEXT,
									'default' => esc_html__('', 'hekim')
								],
								[
									'name' => 'block_text2',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_feature_str2',
									'label'       => __( 'Features List', 'rashid' ),
									'type'        => Controls_Manager::TEXTAREA,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Features List', 'rashid' ),
									'default'     => __( '', 'rashid' ),
								],
								[
									'name' => 'block_button2',
									'label'       => __( 'Button', 'rashid' ),
									'type'        => Controls_Manager::TEXT,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Button Title', 'rashid' ),
								],
								[
									'name' => 'block_btnlink2',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									'url' => '',
									'is_external' => true,
									'nof
									ollow' => true,
									],
								],
								[
									'name' => 'block_title3',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_price3',
									'label' => esc_html__('Price', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'ff_sing3',
									'label' => esc_html__('Counter Sing', 'rashid'),
									'type' => Controls_Manager::TEXT,
									'default' => esc_html__('', 'hekim')
								],
								[
									'name' => 'block_text3',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_feature_str3',
									'label'       => __( 'Features List', 'rashid' ),
									'type'        => Controls_Manager::TEXTAREA,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Features List', 'rashid' ),
									'default'     => __( '', 'rashid' ),
								],
								[
									'name' => 'block_button3',
									'label'       => __( 'Button', 'rashid' ),
									'type'        => Controls_Manager::TEXT,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Button Title', 'rashid' ),
								],
								[
									'name' => 'block_btnlink3',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									'url' => '',
									'is_external' => true,
									'nof
									ollow' => true,
									],
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
		
		<?php  if ( 'style1' === $settings['style'] ) : ?>
        
        <section class="pricing-one p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="inner-container p_relative sec-pad">
                    <div class="section-line">
                        <div class="line line-1 p_absolute"></div>
                        <div class="line line-2 p_absolute"></div>
                        <div class="line line-3 p_absolute"></div>
                    </div>
					<?php if($settings['title']): ?>
                    <div class="sec-title p_relative d_block mb_35 text-center z_1">
                        <span class="sub-title p_relative d_iblock fs_15 fw_medium g_color mb_19"><?php echo $settings['subtitle'];?></span>
                        <h2 class="p_relative d_block fs_40 fw_bold mb_30"><?php echo $settings['title'];?></h2>
                    </div>
					<?php endif; ?>
                    <div class="tabs-box">
                        <div class="tab-btn-box p_relative d_block mb_60 centred">
                            <ul class="tab-btns tab-buttons clearfix p_relative d_iblock">
							
								<?php foreach($settings['repeat'] as $key=>$item):?>
							
                                <li class="tab-btn <?php if($key == 0) echo 'active-btn';?>" data-tab="#id-<?php echo esc_attr($key);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?></li>
								
								<?php endforeach; ?>
								
                            </ul>
                        </div>
                        <div class="tabs-content">
						
							<?php foreach($settings['repeat'] as $key=>$item):?>	
						
                            <div class="tab <?php if($key == 0) echo 'active-tab';?>" id="id-<?php echo esc_attr($key);?>">
                                <div class="row clearfix">
                                    <div class="col-lg-6 col-md-6 col-sm-12 pricing-block">
                                        <div class="pricing-block-one">
                                            <div class="pricing-table p_relative d_block pt_45 pr_50 pb_50 pl_50 b_radius_10">
                                                <div class="table-header p_relative d_block mb_30">
                                                    <h6 class="d_block fs_16 lh_20 fw_medium g_color mb_11"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                                    <h2 class="d_block fs_40 lh_50 fw_bold mb_0"><?php echo esc_attr($item['block_price']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing']);?></span></h2>
                                                    <p class="fs_18"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                                </div>
                                                <div class="table-content p_relative d_block p_relative pt_25 pr_30 pl_30 pb_25 b_radius_10 mb_40">
                                                    <ul class="feature-list clearfix">
                                                        <?php $fearures = explode("\n", ($item['block_feature_str']));?>
														<?php foreach($fearures as $feature):?>
														<?php echo wp_kses($feature, true); ?>
														<?php endforeach; ?>
                                                    </ul>
                                                </div>
												<?php if(wp_kses($item['block_button1'], $allowed_tags)): ?>
                                                <div class="table-footer">
                                                    <a href="<?php echo esc_url($item['block_btnlink1']['url']);?>" class="theme-btn theme-btn-two"><span data-text="Select Plan"><?php echo wp_kses($item['block_button1'], $allowed_tags);?></span></a>
                                                </div>
												<?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-lg-6 col-md-6 col-sm-12 pricing-block">
                                        <div class="pricing-block-one active-block">
                                            <div class="pricing-table p_relative d_block pt_45 pr_50 pb_50 pl_50 b_radius_10">
                                                <div class="shape-1 hero-shape-three p_absolute"></div>
												
												<?php if(wp_get_attachment_url($item['block_bgimg']['id'])): ?>
                                                <div class="shape-2 p_absolute t_0 r_0" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
												<?php else :?>
												<div class="noimage">
												<?php endif;?>
												</div>
                                                <div class="table-header p_relative d_block mb_30">
                                                    <h6 class="d_block fs_16 lh_20 fw_medium g_color mb_11"><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h6>
                                                    <h2 class="d_block fs_40 lh_50 fw_bold mb_0"><?php echo esc_attr($item['block_price2']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing2']);?></span></h2>
                                                    <p class="fs_18"><?php echo wp_kses($item['block_text2'], $allowed_tags);?></p>
                                                </div>
                                                <div class="table-content p_relative d_block p_relative pt_25 pr_30 pl_30 pb_25 b_radius_10 mb_40">
                                                    <ul class="feature-list clearfix">
                                                        <?php $fearures = explode("\n", ($item['block_feature_str2']));?>
														<?php foreach($fearures as $feature):?>
														<?php echo wp_kses($feature, true); ?>
														<?php endforeach; ?>
                                                    </ul>
                                                </div>
												<?php if(wp_kses($item['block_button2'], $allowed_tags)): ?>
                                                <div class="table-footer">
                                                    <a href="<?php echo esc_url($item['block_btnlink2']['url']);?>" class="theme-btn theme-btn-one"><?php echo wp_kses($item['block_button2'], $allowed_tags);?><i class="icon-4"></i></a>
                                                </div>
												<?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
							
							<?php endforeach; ?>
							
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<section class="pricing-two p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="tabs-box">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-12 col-sm-12 content-column">
                            <div class="content-box">
							
								<?php if($settings['title']): ?>
                                <div class="sec-title-four p_relative d_block mb_25">
                                    <h6 class="d_iblock fs_14 lh_28 fw_sbold font_family_poppins mb_18 b_radius_5"><?php echo $settings['subtitle'];?></h6>
                                    <h2 class="d_block fs_40 fw_bold font_family_poppins"><?php echo $settings['title'];?></h2>
                                </div>

                                <div class="text p_relative d_block mb_30">
                                    <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                                </div>
								<?php endif; ?>
                                <div class="tab-btn-box p_relative d_block mb_60">
                                    <ul class="tab-btns tab-buttons clearfix p_relative d_iblock">
									
										<?php foreach($settings['repeat'] as $key=>$item):?>
										
                                        <li class="tab-btn <?php if($key == 0) echo 'active-btn';?>" data-tab="#tab-<?php echo esc_attr($key);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?></li>
										
										<?php endforeach; ?>
										
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-8 col-md-12 col-sm-12 inner-column">
                            <div class="tabs-content p_relative">
                                <div class="shape parallax-scene parallax-scene-5">
									<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                                    <div data-depth="0.30" class="shape-1 p_absolute w_150 h_150" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
									<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                                    <div data-depth="0.40" class="shape-2 p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
                                </div>
								
								
								<?php foreach($settings['repeat'] as $key=>$item):?>	
								
                                <div class="tab <?php if($key == 0) echo 'active-tab';?>" id="tab-<?php echo esc_attr($key);?>">
                                    <div class="row clearfix">
                                        <div class="col-lg-6 col-md-6 col-sm-12 pricing-block">
                                            <div class="pricing-block-one">
                                                <div class="pricing-table p_relative d_block pt_45 pr_50 pb_50 pl_50 b_radius_10">
                                                    <div class="table-header p_relative d_block mb_30">
                                                        <h6 class="d_iblock fs_16 lh_20 fw_medium mb_11"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                                        <h2 class="d_block fs_40 lh_50 fw_bold mb_0"><?php echo esc_attr($item['block_price']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing']);?></span></h2>
                                                        <p class="fs_18"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                                    </div>
                                                    <div class="table-content p_relative d_block p_relative pt_25 pr_30 pl_30 pb_25 b_radius_10 mb_40">
                                                        <ul class="feature-list clearfix">
                                                            <?php $fearures = explode("\n", ($item['block_feature_str']));?>
															<?php foreach($fearures as $feature):?>
															<?php echo wp_kses($feature, true); ?>
															<?php endforeach; ?>
                                                        </ul>
                                                    </div>
													<?php if(wp_kses($item['block_button1'], $allowed_tags)): ?>
                                                    <div class="table-footer">
                                                        <a href="<?php echo esc_url($item['block_btnlink1']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button1'], $allowed_tags);?> <i class="icon-4"></i></a>
                                                    </div>
													<?php endif; ?>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-lg-6 col-md-6 col-sm-12 pricing-block">
                                            <div class="pricing-block-one active-block">
                                                <div class="pricing-table p_relative d_block pt_45 pr_50 pb_50 pl_50 b_radius_10">
                                                    <div class="table-header p_relative d_block mb_30">
                                                        <h6 class="d_iblock fs_16 lh_20 fw_medium mb_11"><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h6>
                                                        <h2 class="d_block fs_40 lh_50 fw_bold mb_0"><?php echo esc_attr($item['block_price2']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing2']);?></span></h2>
                                                        <p class="fs_18"><?php echo wp_kses($item['block_text2'], $allowed_tags);?></p>
                                                    </div>
                                                    <div class="table-content p_relative d_block p_relative pt_25 pr_30 pl_30 pb_25 b_radius_10 mb_40">
                                                        <ul class="feature-list clearfix">
                                                            <?php $fearures = explode("\n", ($item['block_feature_str2']));?>
															<?php foreach($fearures as $feature):?>
															<?php echo wp_kses($feature, true); ?>
															<?php endforeach; ?>
                                                        </ul>
                                                    </div>
													<?php if(wp_kses($item['block_button2'], $allowed_tags)): ?>
                                                    <div class="table-footer">
                                                        <a href="<?php echo esc_url($item['block_btnlink2']['url']);?>" class="theme-btn theme-btn-five"><?php echo wp_kses($item['block_button2'], $allowed_tags);?><i class="icon-4"></i></a>
                                                    </div>
													<?php endif; ?>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
								
								<?php endforeach; ?>
								
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
		<section class="pricing-three p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title-five p_relative d_block mb_50 centred">
                    <h4 class="p_relative d_block fs_20 lh_30 fw_bold font_family_oxygen mb_14"><?php echo $settings['subtitle'];?></h4>
                    <h2 class="d_block fs_50 lh_55 fw_bold font_family_frank"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="tabs-box">
                    <div class="tab-btn-box p_relative d_block mb_60 centred">
                        <ul class="tab-btns tab-buttons clearfix p_relative d_iblock">
						
							<?php foreach($settings['repeat'] as $key=>$item):?>
						
                            <li class="tab-btn <?php if($key == 0) echo 'active-btn';?>" data-tab="#tab-<?php echo esc_attr($key);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?></li>
							
							<?php endforeach; ?>
							
							
                        </ul>
                    </div>
                    <div class="tabs-content">
					
						<?php foreach($settings['repeat'] as $key=>$item):?>
					
                        <div class="tab <?php if($key == 0) echo 'active-tab';?>" id="tab-<?php echo esc_attr($key);?>">
                            <div class="row clearfix">
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                                    <div class="pricing-block-one">
                                       <div class="pricing-table p_relative d_block pt_45 pr_50 pb_50 pl_50 b_radius_10">
											<div class="table-header p_relative d_block mb_30">
												<h6 class="d_block fs_16 lh_20 fw_medium g_color mb_11"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
												<h2 class="d_block fs_40 lh_50 fw_bold mb_0"><?php echo esc_attr($item['block_price']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing']);?></span></h2>
												<p class="fs_18"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
											</div>
											<div class="table-content p_relative d_block p_relative pt_25 pr_30 pl_30 pb_25 b_radius_10 mb_40">
												<ul class="feature-list clearfix">
													<?php $fearures = explode("\n", ($item['block_feature_str']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
												</ul>
											</div>
											<?php if(wp_kses($item['block_button1'], $allowed_tags)): ?>
											<div class="table-footer">
												<a href="<?php echo esc_url($item['block_btnlink1']['url']);?>" class="theme-btn theme-btn-two"><span data-text="Select Plan"><?php echo wp_kses($item['block_button1'], $allowed_tags);?></span></a>
											</div>
											<?php endif; ?>
										</div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                                    <div class="pricing-block-one active-block">
                                        <div class="pricing-table p_relative d_block pt_45 pr_50 pb_50 pl_50 b_radius_10">
											<div class="table-header p_relative d_block mb_30">
												<h6 class="d_block fs_16 lh_20 fw_medium g_color mb_11"><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h6>
												<h2 class="d_block fs_40 lh_50 fw_bold mb_0"><?php echo esc_attr($item['block_price2']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing2']);?></span></h2>
												<p class="fs_18"><?php echo wp_kses($item['block_text2'], $allowed_tags);?></p>
											</div>
											<div class="table-content p_relative d_block p_relative pt_25 pr_30 pl_30 pb_25 b_radius_10 mb_40">
												<ul class="feature-list clearfix">
													<?php $fearures = explode("\n", ($item['block_feature_str2']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
												</ul>
											</div>
											
											<?php if(wp_kses($item['block_button2'], $allowed_tags)): ?>
											<div class="table-footer">
                                                <a href="<?php echo esc_url($item['block_btnlink2']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button2'], $allowed_tags);?><i class="icon-4"></i></a>
                                            </div>
											<?php endif; ?>
											
										</div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                                    <div class="pricing-block-one">
                                        <div class="pricing-table p_relative d_block pt_45 pr_50 pb_50 pl_50 b_radius_10">
											<div class="table-header p_relative d_block mb_30">
												<h6 class="d_block fs_16 lh_20 fw_medium g_color mb_11"><?php echo wp_kses($item['block_title3'], $allowed_tags);?></h6>
												<h2 class="d_block fs_40 lh_50 fw_bold mb_0"><?php echo esc_attr($item['block_price3']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing3']);?></span></h2>
												<p class="fs_18"><?php echo wp_kses($item['block_text3'], $allowed_tags);?></p>
											</div>
											<div class="table-content p_relative d_block p_relative pt_25 pr_30 pl_30 pb_25 b_radius_10 mb_40">
												<ul class="feature-list clearfix">
													<?php $fearures = explode("\n", ($item['block_feature_str3']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
												</ul>
											</div>
											<?php if(wp_kses($item['block_button3'], $allowed_tags)): ?>
											<div class="table-footer">
												<a href="<?php echo esc_url($item['block_btnlink3']['url']);?>" class="theme-btn theme-btn-two"><span data-text="Select Plan"><?php echo wp_kses($item['block_button3'], $allowed_tags);?></span></a>
											</div>
											<?php endif; ?>
										</div>
                                    </div>
                                </div>
                            </div>
                        </div>
						
						<?php endforeach; ?>
						
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style4' === $settings['style'] ) : ?>
		
		<section class="pricing-four pricing-two p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="tabs-box">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-12 col-sm-12 content-column">
                            <div class="content-box">
							
								<?php if($settings['title']): ?>
							
                                <div class="sec-title-eight p_relative d_block mb_50">
                                    <h5 class="p_relative d_iblock fs_18 lh_30 fw_sbold font_family_poppins mb_12"><?php echo $settings['subtitle'];?></h5><br />
                                    <h2 class="d_block fs_50 fw_bold lh_50 fw_bold font_family_pt"><?php echo $settings['title'];?></h2>
                                </div>
                                <div class="text p_relative d_block mb_30">
                                    <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                                </div>
								
								<?php endif; ?>
								
                                <div class="tab-btn-box p_relative d_block mb_60">
                                    <ul class="tab-btns tab-buttons clearfix p_relative d_iblock">
									
										<?php foreach($settings['repeat'] as $key=>$item):?>
									
                                        <li class="tab-btn <?php if($key == 0) echo 'active-btn';?>" data-tab="#id-<?php echo esc_attr($key);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?></li>
										
										<?php endforeach; ?>
										
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-8 col-md-12 col-sm-12 inner-column">
                            <div class="tabs-content p_relative">
							
								<?php foreach($settings['repeat'] as $key=>$item):?>
							
                                <div class="tab <?php if($key == 0) echo 'active-tab';?>" id="id-<?php echo esc_attr($key);?>">
                                    <div class="row clearfix">
                                        <div class="col-lg-6 col-md-6 col-sm-12 pricing-block">
                                            <div class="pricing-block-one">
                                                <div class="pricing-table p_relative d_block pt_45 pr_40 pb_50 pl_40">
                                                    <div class="table-header p_relative d_block mb_30">
                                                        <h6 class="d_iblock fs_18 lh_20 fw_sbold mb_11 font_family_poppins"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                                        <h2 class="d_block fs_50 lh_50 fw_bold mb_0 font_family_pt"><?php echo esc_attr($item['block_price']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing']);?></span></h2>
                                                        <p class="fs_16 font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                                    </div>
                                                    <div class="table-content p_relative d_block p_relative pt_25 pr_30 pl_30 pb_25 mb_40">
                                                        <ul class="feature-list clearfix">
                                                            <?php $fearures = explode("\n", ($item['block_feature_str']));?>
															<?php foreach($fearures as $feature):?>
															<?php echo wp_kses($feature, true); ?>
															<?php endforeach; ?>
                                                        </ul>
                                                    </div>
													<?php if(wp_kses($item['block_button1'], $allowed_tags)): ?>
                                                    <div class="table-footer">
                                                        <a href="<?php echo esc_url($item['block_btnlink1']['url']);?>" class="theme-btn btn-11"><span data-text="Select Plan"><?php echo wp_kses($item['block_button1'], $allowed_tags);?></span></a>
                                                    </div>
													<?php endif; ?>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-lg-6 col-md-6 col-sm-12 pricing-block">
                                            <div class="pricing-block-one active-block">
                                                <div class="pricing-table p_relative d_block pt_45 pr_40 pb_50 pl_40">
                                                    <div class="shape">
                                                        <div class="shape-3 p_absolute"></div>
                                                        <div class="shape-4 p_absolute"></div>
                                                    </div>
                                                    <div class="table-header p_relative d_block mb_30">
                                                        <h6 class="d_iblock fs_18 lh_20 fw_sbold mb_11 font_family_poppins"><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h6>
                                                        <h2 class="d_block fs_50 lh_50 fw_bold mb_0 font_family_pt"><?php echo esc_attr($item['block_price2']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing2']);?></span></h2>
                                                        <p class="fs_16 font_family_poppins"><?php echo wp_kses($item['block_text2'], $allowed_tags);?></p>
                                                    </div>
                                                    <div class="table-content p_relative d_block p_relative pt_25 pr_30 pl_30 pb_25 mb_40">
                                                        <ul class="feature-list clearfix">
                                                            <?php $fearures = explode("\n", ($item['block_feature_str2']));?>
															<?php foreach($fearures as $feature):?>
															<?php echo wp_kses($feature, true); ?>
															<?php endforeach; ?>
                                                        </ul>
                                                    </div>
													<?php if(wp_kses($item['block_button2'], $allowed_tags)): ?>
                                                    <div class="table-footer">
                                                        <a href="<?php echo esc_url($item['block_btnlink2']['url']);?>" class="theme-btn btn-11"><span data-text="Select Plan"><?php echo wp_kses($item['block_button2'], $allowed_tags);?></span></a>
                                                    </div>
													<?php endif; ?>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
								
								<?php endforeach; ?>
								
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style5' === $settings['style'] ) : ?>
		
		<section class="pricing-five pricing-two p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="tabs-box">
                    <div class="row clearfix">
					
						<?php if($settings['title']): ?>
					
                        <div class="col-lg-4 col-md-12 col-sm-12 content-column">
                            <div class="content-box">
                                <div class="sec-title p_relative d_block mb_25">
                                    <h2 class="d_block fs_50 fw_bold lh_55 fw_bold font_family_spartan"><?php echo $settings['title'];?></h2>
                                </div>
                                <div class="text p_relative d_block mb_30">
                                    <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                                </div>
                                <div class="tab-btn-box p_relative d_block mb_60">
                                    <ul class="tab-btns tab-buttons clearfix p_relative d_iblock">
									
										<?php foreach($settings['repeat'] as $key=>$item):?>
									
                                        <li class="tab-btn <?php if($key == 0) echo 'active-btn';?>" data-tab="#tab-<?php echo esc_attr($key);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?></li>
										
										<?php endforeach; ?>
										
                                    </ul>
                                </div>
                            </div>
                        </div>
						
						<?php endif; ?>
						
                        <div class="col-lg-8 col-md-12 col-sm-12 inner-column">
                            <div class="tabs-content p_relative ml_40">
                                <div class="shape parallax-scene parallax-scene-2">
									<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                                    <div data-depth="0.40" class="shape-1 p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
									<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                                    <div data-depth="0.50" class="shape-2 p_absolute l_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
                                </div>
								
								<?php foreach($settings['repeat'] as $key=>$item):?>
								
                                <div class="tab <?php if($key == 0) echo 'active-tab';?>" id="tab-<?php echo esc_attr($key);?>">
                                    <div class="row clearfix">
                                        <div class="col-lg-6 col-md-6 col-sm-12 pricing-block">
                                            <div class="pricing-block-two">
                                                <div class="pricing-table p_relative d_block pt_45 pr_40 pb_50 pl_40 centred b_shadow_6">
                                                    <div class="table-header p_relative d_block mb_35">
                                                        <h5 class="fs_19 fw_medium font_family_spartan lh_25 mb_18"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h5>
                                                        <h2 class="d_block fs_50 lh_45 fw_bold mb_1 font_family_spartan"><?php echo esc_attr($item['block_price']);?></h2>
                                                        <span class="p_relative d_iblock fs_19 lh_20 mb_15 font_family_spartan fw_medium"><?php echo esc_attr($item['ff_sing']);?></span>
                                                        <p class="fs_16 font_family_oxygen"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                                    </div>
                                                    <div class="table-content p_relative d_block p_relative mb_40">
                                                        <ul class="feature-list clearfix">
                                                            <?php $fearures = explode("\n", ($item['block_feature_str']));?>
															<?php foreach($fearures as $feature):?>
															<?php echo wp_kses($feature, true); ?>
															<?php endforeach; ?>
                                                        </ul>
                                                    </div>
													<?php if(wp_kses($item['block_button1'], $allowed_tags)): ?>
                                                    <div class="table-footer">
                                                        <a href="<?php echo esc_url($item['block_btnlink1']['url']);?>" class="theme-btn theme-btn-two"><?php echo wp_kses($item['block_button1'], $allowed_tags);?></a>
                                                    </div>
													<?php endif; ?>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-lg-6 col-md-6 col-sm-12 pricing-block">
                                            <div class="pricing-block-two active-block">
                                                <div class="pricing-table p_relative d_block pt_45 pr_40 pb_50 pl_40 centred b_shadow_6">
                                                    <div class="table-header p_relative d_block mb_35">
                                                        <h5 class="fs_19 fw_medium font_family_spartan lh_25 mb_18"><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h5>
                                                        <h2 class="d_block fs_50 lh_45 fw_bold mb_1 font_family_spartan"><?php echo esc_attr($item['block_price2']);?></h2>
                                                        <span class="p_relative d_iblock fs_19 lh_20 mb_15 font_family_spartan fw_medium"><?php echo esc_attr($item['ff_sing2']);?></span>
                                                        <p class="fs_16 font_family_oxygen"><?php echo wp_kses($item['block_text2'], $allowed_tags);?></p>
                                                    </div>
                                                    <div class="table-content p_relative d_block p_relative mb_40">
                                                        <ul class="feature-list clearfix">
                                                            <?php $fearures = explode("\n", ($item['block_feature_str2']));?>
															<?php foreach($fearures as $feature):?>
															<?php echo wp_kses($feature, true); ?>
															<?php endforeach; ?>
                                                        </ul>
                                                    </div>
													<?php if(wp_kses($item['block_button2'], $allowed_tags)): ?>
                                                    <div class="table-footer">
                                                        <a href="<?php echo esc_url($item['block_btnlink2']['url']);?>" class="theme-btn theme-btn-eight"><?php echo wp_kses($item['block_button2'], $allowed_tags);?></a>
                                                    </div>
													<?php endif; ?>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
								
								<?php endforeach; ?>
								
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		

		
		<?php  if ( 'style7' === $settings['style'] ) : ?>
		
		<section class="pricing-one home-15 pricing-seven p_relative pt_140 pb_150 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title p_relative d_block mb_50 centred">
                    <h2 class="d_block fs_45 lh_50 fw_bold font_family_frank mb_18"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="tabs-box">
                    <div class="tab-btn-box p_relative d_block mb_60 centred">
                        <ul class="tab-btns tab-buttons clearfix p_relative d_iblock">
						
							<?php foreach($settings['repeat'] as $key=>$item):?>
						
                            <li class="tab-btn <?php if($key == 0) echo 'active-btn';?>" data-tab="#tab-<?php echo esc_attr($key);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?></li>
							
							<?php endforeach; ?>
							
                        </ul>
                    </div>
                    <div class="tabs-content">
					
						<?php foreach($settings['repeat'] as $key=>$item):?>
						
                        <div class="tab <?php if($key == 0) echo 'active-tab';?>" id="tab-<?php echo esc_attr($key);?>">
                            <div class="row clearfix">
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                                    <div class="pricing-block-two">
                                        <div class="pricing-table p_relative d_block pt_45 pr_40 pb_50 pl_40 b_shadow_6 b_radius_10">
                                            <div class="table-header p_relative d_block mb_30">
                                                <h6 class="d_block fs_16 lh_20 fw_sbold mb_18"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                                <h2 class="d_block fs_50 lh_50 fw_bold font_family_frank"><?php echo esc_attr($item['block_price']);?> <span class="fs_17 font_family_poppins fw_normal"><?php echo esc_attr($item['ff_sing']);?></span></h2>
                                                <p class="fs_16 font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                            </div>
                                            <div class="table-content p_relative d_block p_relative mb_30">
                                                <ul class="feature-list-two clearfix">
                                                    <?php $fearures = explode("\n", ($item['block_feature_str']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
											<?php if(wp_kses($item['block_button1'], $allowed_tags)): ?>
                                            <div class="table-footer">
                                                <a href="<?php echo esc_url($item['block_btnlink1']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button1'], $allowed_tags);?> <i class="icon-4"></i></a>
                                            </div>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                                    <div class="pricing-block-two active-block">
                                        <div class="pricing-table p_relative d_block pt_45 pr_40 pb_50 pl_40 b_shadow_6 b_radius_10">
                                            <div class="table-header p_relative d_block mb_30">
                                                <h6 class="d_block fs_16 lh_20 fw_sbold mb_18"><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h6>
                                                <h2 class="d_block fs_50 lh_50 fw_bold font_family_frank"><?php echo esc_attr($item['block_price2']);?> <span class="fs_17 font_family_poppins fw_normal"><?php echo esc_attr($item['ff_sing2']);?></span></h2>
                                                <p class="fs_16 font_family_poppins"><?php echo wp_kses($item['block_text2'], $allowed_tags);?></p>
                                            </div>
                                            <div class="table-content p_relative d_block p_relative mb_30">
                                                <ul class="feature-list-two clearfix">
                                                    <?php $fearures = explode("\n", ($item['block_feature_str2']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
											<?php if(wp_kses($item['block_button2'], $allowed_tags)): ?>
                                            <div class="table-footer">
                                                <a href="<?php echo esc_url($item['block_btnlink2']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button2'], $allowed_tags);?> <i class="icon-4"></i></a>
                                            </div>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                                    <div class="pricing-block-two">
                                        <div class="pricing-table p_relative d_block pt_45 pr_40 pb_50 pl_40 b_shadow_6 b_radius_10">
                                            <div class="table-header p_relative d_block mb_30">
                                                <h6 class="d_block fs_16 lh_20 fw_sbold mb_18"><?php echo wp_kses($item['block_title3'], $allowed_tags);?></h6>
                                                <h2 class="d_block fs_50 lh_50 fw_bold font_family_frank"><?php echo esc_attr($item['block_price3']);?> <span class="fs_17 font_family_poppins fw_normal"><?php echo esc_attr($item['ff_sing3']);?></span></h2>
                                                <p class="fs_16 font_family_poppins"><?php echo wp_kses($item['block_text3'], $allowed_tags);?></p>
                                            </div>
                                            <div class="table-content p_relative d_block p_relative mb_30">
                                                <ul class="feature-list-two clearfix">
                                                    <?php $fearures = explode("\n", ($item['block_feature_str3']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
											<?php if(wp_kses($item['block_button3'], $allowed_tags)): ?>
                                            <div class="table-footer">
                                                <a href="<?php echo esc_url($item['block_btnlink3']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button3'], $allowed_tags);?> <i class="icon-4"></i></a>
                                            </div>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
						
						<?php endforeach; ?>
						
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style8' === $settings['style'] ) : ?>
		
		<section class="pricing-one pricing-eight p_relative pt_140 pb_150 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="pattern-layer">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="pattern-1 p_absolute l_100 t_100 float-bob-y" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                <div class="pattern-2 p_absolute r_0 b_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title-11 p_relative d_block centred mb_50">
                    <h5 class="d_block fs_17 fw_medium font_family_inter lh_28 mb_16 uppercase"><?php echo $settings['subtitle'];?></h5><br />
                    <h2 class="d_block fs_40 lh_50 fw_bold font_family_inter"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="tabs-box">
                    <div class="tab-btn-box p_relative d_block mb_60 centred">
                        <ul class="tab-btns tab-buttons clearfix p_relative d_iblock">
						
							<?php foreach($settings['repeat'] as $key=>$item):?>
							
                            <li class="tab-btn <?php if($key == 0) echo 'active-btn';?>" data-tab="#tab-<?php echo esc_attr($key);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?></li>
							
							<?php endforeach; ?>
							
                        </ul>
                    </div>
                    <div class="tabs-content">
					
						<?php foreach($settings['repeat'] as $key=>$item):?>
					
                        <div class="tab <?php if($key == 0) echo 'active-tab';?>" id="tab-<?php echo esc_attr($key);?>">
                            <div class="row clearfix">
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                                    <div class="pricing-block-three">
                                        <div class="pricing-table p_relative d_block pt_45 pr_40 pb_50 pl_40 b_shadow_6 b_radius_10">
                                            <div class="table-header p_relative d_block mb_20">
                                                <h6 class="d_block fs_16 lh_20 fw_sbold mb_15 font_family_poppins"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                                <h2 class="d_block fs_45 lh_50 fw_sbold font_family_inter mb_6"><?php echo esc_attr($item['block_price']);?> <span class="fs_17 font_family_inter fw_medium"><?php echo esc_attr($item['ff_sing']);?></span></h2>
                                                <p class="fs_16 font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                            </div>
                                            <div class="table-content p_relative d_block p_relative mb_30">
                                                <ul class="feature-list clearfix pt_25 pr_30 pb_25 pl_30 b_radius_10">
                                                    <?php $fearures = explode("\n", ($item['block_feature_str']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
											<?php if(wp_kses($item['block_button1'], $allowed_tags)): ?>
                                            <div class="table-footer">
                                                <a href="<?php echo esc_url($item['block_btnlink1']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button1'], $allowed_tags);?> <i class="icon-4"></i></a>
                                            </div>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                                    <div class="pricing-block-three">
                                        <div class="pricing-table p_relative d_block pt_45 pr_40 pb_50 pl_40 b_shadow_6 b_radius_10">
                                            <div class="table-header p_relative d_block mb_20">
                                                <h6 class="d_block fs_16 lh_20 fw_sbold mb_15 font_family_poppins"><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h6>
                                                <h2 class="d_block fs_45 lh_50 fw_sbold font_family_inter mb_6"><?php echo esc_attr($item['block_price2']);?> <span class="fs_17 font_family_inter fw_medium"><?php echo esc_attr($item['ff_sing2']);?></span></h2>
                                                <p class="fs_16 font_family_poppins"><?php echo wp_kses($item['block_text2'], $allowed_tags);?></p>
                                            </div>
                                            <div class="table-content p_relative d_block p_relative mb_30">
                                                <ul class="feature-list clearfix pt_25 pr_30 pb_25 pl_30 b_radius_10">
                                                    <?php $fearures = explode("\n", ($item['block_feature_str2']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
											<?php if(wp_kses($item['block_button2'], $allowed_tags)): ?>
                                            <div class="table-footer">
                                                <a href="<?php echo esc_url($item['block_btnlink2']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button2'], $allowed_tags);?> <i class="icon-4"></i></a>
                                            </div>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                                    <div class="pricing-block-three">
                                        <div class="pricing-table p_relative d_block pt_45 pr_40 pb_50 pl_40 b_shadow_6 b_radius_10">
                                            <div class="table-header p_relative d_block mb_20">
                                                <h6 class="d_block fs_16 lh_20 fw_sbold mb_15 font_family_poppins"><?php echo wp_kses($item['block_title3'], $allowed_tags);?></h6>
                                                <h2 class="d_block fs_45 lh_50 fw_sbold font_family_inter mb_6"><?php echo esc_attr($item['block_price3']);?> <span class="fs_17 font_family_inter fw_medium"><?php echo esc_attr($item['ff_sing3']);?></span></h2>
                                                <p class="fs_16 font_family_poppins"><?php echo wp_kses($item['block_text3'], $allowed_tags);?></p>
                                            </div>
                                            <div class="table-content p_relative d_block p_relative mb_30">
                                                <ul class="feature-list clearfix pt_25 pr_30 pb_25 pl_30 b_radius_10">
                                                    <?php $fearures = explode("\n", ($item['block_feature_str3']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
											<?php if(wp_kses($item['block_button3'], $allowed_tags)): ?>
                                            <div class="table-footer">
                                                <a href="<?php echo esc_url($item['block_btnlink3']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button3'], $allowed_tags);?> <i class="icon-4"></i></a>
                                            </div>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
						
						<?php endforeach; ?>
						
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style9' === $settings['style'] ) : ?>
		
		<section class="pricing-one service-page-1 p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title-12 p_relative d_block mb_50 centred">
                    <h5 class="d_block fs_17 lh_26 fw_sbold font_family_inter uppercase mb_19 g_color"><?php echo $settings['subtitle'];?></h5><br />
                    <h2 class="d_block fs_40 lh_50 fw_bold font_family_inter"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="tabs-box">
                    <div class="tab-btn-box p_relative d_block mb_60 centred">
                        <ul class="tab-btns tab-buttons clearfix p_relative d_iblock">
							<?php foreach($settings['repeat'] as $key=>$item):?>
                            <li class="tab-btn <?php if($key == 0) echo 'active-btn';?>" data-tab="#tab-<?php echo esc_attr($key);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?></li>
							<?php endforeach; ?>
                        </ul>
                    </div>
                    <div class="tabs-content">
					
						<?php foreach($settings['repeat'] as $key=>$item):?>
					
                        <div class="tab <?php if($key == 0) echo 'active-tab';?>" id="tab-<?php echo esc_attr($key);?>">
                            <div class="row clearfix">
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                                    <div class="pricing-block-one">
                                        <div class="pricing-table p_relative d_block pt_50 pr_40 pb_50 pl_40 b_radius_10 b_shadow_6">
                                            <div class="table-header p_relative d_block mb_30 pb_30">
                                                <h6 class="d_block fs_16 lh_20 fw_medium g_color font_family_poppins mb_15"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                                <h2 class="d_block fs_50 lh_50 fw_sbold mb_0"><?php echo esc_attr($item['block_price']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing']);?></span></h2>
                                                <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                            </div>
                                            <div class="table-content-two p_relative d_block mb_30">
                                                <ul class="feature-list clearfix">
                                                    <?php $fearures = explode("\n", ($item['block_feature_str']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
											<?php if(wp_kses($item['block_button1'], $allowed_tags)): ?>
                                            <div class="table-footer">
                                                <a href="<?php echo esc_url($item['block_btnlink1']['url']);?>" class="theme-btn theme-btn-two"><span data-text="Select Plan"><?php echo wp_kses($item['block_button1'], $allowed_tags);?></span></a>
                                            </div>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                                    <div class="pricing-block-one active-block">
                                        <div class="pricing-table p_relative d_block pt_50 pr_40 pb_50 pl_40 b_radius_10 b_shadow_6">
                                            <div class="table-header p_relative d_block mb_30 pb_30">
                                                <h6 class="d_block fs_16 lh_20 fw_medium g_color font_family_poppins mb_15"><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h6>
                                                <h2 class="d_block fs_50 lh_50 fw_sbold mb_0"><?php echo esc_attr($item['block_price2']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing2']);?></span></h2>
                                                <p class="font_family_poppins"><?php echo wp_kses($item['block_text2'], $allowed_tags);?></p>
                                            </div>
                                            <div class="table-content-two p_relative d_block mb_30">
                                                <ul class="feature-list clearfix">
                                                    <?php $fearures = explode("\n", ($item['block_feature_str2']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
											<?php if(wp_kses($item['block_button2'], $allowed_tags)): ?>
                                            <div class="table-footer">
                                                <a href="<?php echo esc_url($item['block_btnlink2']['url']);?>" class="theme-btn theme-btn-one"><?php echo wp_kses($item['block_button2'], $allowed_tags);?><i class="icon-4"></i></a>
                                            </div>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                                    <div class="pricing-block-one">
                                        <div class="pricing-table p_relative d_block pt_50 pr_40 pb_50 pl_40 b_radius_10 b_shadow_6">
                                            <div class="table-header p_relative d_block mb_30 pb_30">
                                                <h6 class="d_block fs_16 lh_20 fw_medium g_color font_family_poppins mb_15"><?php echo wp_kses($item['block_title3'], $allowed_tags);?></h6>
                                                <h2 class="d_block fs_50 lh_50 fw_sbold mb_0"><?php echo esc_attr($item['block_price3']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing3']);?></span></h2>
                                                <p class="font_family_poppins"><?php echo wp_kses($item['block_text3'], $allowed_tags);?></p>
                                            </div>
                                            <div class="table-content-two p_relative d_block mb_30">
                                                <ul class="feature-list clearfix">
                                                    <?php $fearures = explode("\n", ($item['block_feature_str3']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
											<?php if(wp_kses($item['block_button3'], $allowed_tags)): ?>
                                            <div class="table-footer">
                                                <a href="<?php echo esc_url($item['block_btnlink3']['url']);?>" class="theme-btn theme-btn-two"><span data-text="Select Plan"><?php echo wp_kses($item['block_button3'], $allowed_tags);?></span></a>
                                            </div>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
						
						<?php endforeach; ?>
						
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style10' === $settings['style'] ) : ?>
		
		<section class="pricing-one service-page-3 p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title-six p_relative d_block mb_50 centred">
                    <h2 class="d_block fs_40 lh_50 fw_bold"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="tabs-box">
                    <div class="tab-btn-box p_relative d_block mb_60 centred">
                        <ul class="tab-btns tab-buttons clearfix p_relative d_iblock">
						
							<?php foreach($settings['repeat'] as $key=>$item):?>
						
                            <li class="tab-btn <?php if($key == 0) echo 'active-btn';?>" data-tab="#id-<?php echo esc_attr($key);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?></li>
							
							<?php endforeach; ?>
							
                        </ul>
                    </div>
                    <div class="tabs-content">
					
						<?php foreach($settings['repeat'] as $key=>$item):?>
					
                        <div class="tab <?php if($key == 0) echo 'active-tab';?>" id="id-<?php echo esc_attr($key);?>">
                            <div class="row clearfix">
                                <div class="col-lg-6 col-md-12 col-sm-12 pricing-block">
                                    <div class="pricing-block-four">
                                        <div class="pricing-table p_relative d_block b_shadow_6 pl_20 pr_20 pt_20 pb_20">
                                            <div class="table-inner p_relative">
                                                <div class="table-header centred p_absolute l_0 t_0 pt_25 pr_15 pb_30 pl_15">
                                                    <h5 class="d_block fs_17 fw_medium mb_15"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h5>
                                                    <h2 class="d_block fs_40 lh_50 fw_bold mb_2"><?php echo esc_attr($item['block_price']);?></h2>
                                                    <p class="d_block fs_17 fw_medium font_family_inter mb_25"><?php echo esc_attr($item['ff_sing']);?></p>
													<?php if(wp_kses($item['block_button1'], $allowed_tags)): ?>
                                                    <a href="<?php echo esc_url($item['block_btnlink1']['url']);?>" class="theme-btn theme-btn-eight"><?php echo wp_kses($item['block_button1'], $allowed_tags);?></a>
													<?php endif; ?>
                                                </div>
                                                <div class="feature-box p_relative pt_30 pb_25">
                                                    <ul class="list-style-two clearfix p_relative d_block">
                                                        <?php $fearures = explode("\n", ($item['block_feature_str']));?>
														<?php foreach($fearures as $feature):?>
														<?php echo wp_kses($feature, true); ?>
														<?php endforeach; ?>
                                                    </ul>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-6 col-md-12 col-sm-12 pricing-block">
                                    <div class="pricing-block-four active-block">
                                        <div class="pricing-table p_relative d_block b_shadow_6 pl_20 pr_20 pt_20 pb_20">
                                            <div class="table-inner p_relative">
                                                <div class="table-header centred p_absolute l_0 t_0 pt_25 pr_15 pb_30 pl_15">
                                                    <h5 class="d_block fs_17 fw_medium mb_15"><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h5>
                                                    <h2 class="d_block fs_40 lh_50 fw_bold mb_2"><?php echo esc_attr($item['block_price2']);?></h2>
                                                    <p class="d_block fs_17 fw_medium font_family_inter mb_25"><?php echo esc_attr($item['ff_sing2']);?></p>
													<?php if(wp_kses($item['block_button2'], $allowed_tags)): ?>
                                                    <a href="<?php echo esc_url($item['block_btnlink2']['url']);?>" class="theme-btn theme-btn-eight"><?php echo wp_kses($item['block_button2'], $allowed_tags);?></a>
													<?php endif; ?>
                                                </div>
                                                <div class="feature-box p_relative pt_30 pb_25">
                                                    <ul class="list-style-two clearfix p_relative d_block">
                                                        <?php $fearures = explode("\n", ($item['block_feature_str2']));?>
														<?php foreach($fearures as $feature):?>
														<?php echo wp_kses($feature, true); ?>
														<?php endforeach; ?>
                                                    </ul>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
						
						<?php endforeach; ?>
						
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style11' === $settings['style'] ) : ?>
		
		<section class="pricing-nine service-page-4 p_relative bg-color-1 sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="tabs-box">
                    <div class="row clearfix">
                        <div class="col-lg-4 col-md-12 col-sm-12 content-column">
                            <div class="content-box">
								<?php if($settings['title']): ?>
                                <div class="sec-title p_relative d_block mb_30">
                                    <h2 class="d_block fs_40 fw_bold font_family_inter mb_35"><?php echo $settings['title'];?></h2>
                                    <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                                </div>
								<?php endif; ?>
                                <div class="tab-btn-box p_relative d_block mb_60">
                                    <ul class="tab-btns tab-buttons clearfix p_relative d_iblock">
									
										<?php foreach($settings['repeat'] as $key=>$item):?>
									
                                        <li class="tab-btn <?php if($key == 0) echo 'active-btn';?>" data-tab="#tab-<?php echo esc_attr($key);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?></li>
										
										<?php endforeach; ?>
										
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-8 col-md-12 col-sm-12 inner-column">
                            <div class="tabs-content p_relative pl_40">
                                <div class="shape">
									<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                                    <div class="shape-1 p_absolute l_0 b_50 rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
									<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                                    <div class="shape-2 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
									<?php else :?>	
									<div class="noimage">
									<?php endif;?>
									</div>
                                </div>
								<?php foreach($settings['repeat'] as $key=>$item):?>
                                <div class="tab <?php if($key == 0) echo 'active-tab';?>" id="tab-<?php echo esc_attr($key);?>">
                                    <div class="row clearfix">
                                        <div class="col-lg-6 col-md-6 col-sm-12 pricing-block">
                                            <div class="pricing-block-five">
                                                <div class="pricing-table p_relative d_block pt_45 pr_30 pb_50 pl_30 b_radius_10 centred b_shadow_6">
                                                    <div class="table-header p_relative d_block mb_30 pb_40">
                                                        <h5 class="d_block fs_17 fw_medium mb_15"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h5>
                                                        <h2 class="d_block fs_40 lh_50 fw_bold mb_5"><?php echo esc_attr($item['block_price']);?></h2>
                                                        <span class="p_relative d_block fs_17 lh_20 fw_medium font_family_inter mb_20"><?php echo esc_attr($item['ff_sing']);?></span>
                                                        <p class="font_family_poppins mb_25"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
														
														<?php if(wp_kses($item['block_button1'], $allowed_tags)): ?>
                                                        <a href="<?php echo esc_url($item['block_btnlink1']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button1'], $allowed_tags);?></a>
														<?php endif; ?>
														
                                                    </div>
                                                    <div class="table-content">
                                                        <ul class="feature-list clearfix">
                                                            <?php $fearures = explode("\n", ($item['block_feature_str']));?>
															<?php foreach($fearures as $feature):?>
															<?php echo wp_kses($feature, true); ?>
															<?php endforeach; ?>
                                                        </ul>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-lg-6 col-md-6 col-sm-12 pricing-block">
                                            <div class="pricing-block-five">
                                                <div class="pricing-table p_relative d_block pt_45 pr_30 pb_50 pl_30 b_radius_10 centred b_shadow_6">
                                                    <div class="table-header p_relative d_block mb_30 pb_40">
                                                        <h5 class="d_block fs_17 fw_medium mb_15"><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h5>
                                                        <h2 class="d_block fs_40 lh_50 fw_bold mb_5"><?php echo esc_attr($item['block_price2']);?></h2>
                                                        <span class="p_relative d_block fs_17 lh_20 fw_medium font_family_inter mb_20"><?php echo esc_attr($item['ff_sing2']);?></span>
                                                        <p class="font_family_poppins mb_25"><?php echo wp_kses($item['block_text2'], $allowed_tags);?></p>
														<?php if(wp_kses($item['block_button2'], $allowed_tags)): ?>
                                                        <a href="<?php echo esc_url($item['block_btnlink2']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button2'], $allowed_tags);?></a>
														<?php endif; ?>
                                                    </div>
                                                    <div class="table-content">
                                                        <ul class="feature-list clearfix">
                                                            <?php $fearures = explode("\n", ($item['block_feature_str2']));?>
															<?php foreach($fearures as $feature):?>
															<?php echo wp_kses($feature, true); ?>
															<?php endforeach; ?>
                                                        </ul>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
								<?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style12' === $settings['style'] ) : ?>
		
		<section class="pricing-one pricing-page-1 pt_130 pb_150 p_relative  <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title p_relative d_block mb_40 text-center">
                    <h2 class="d_block fs_50 fw_bold"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="tabs-box">
                    <div class="tab-btn-box p_relative d_block mb_60 centred">
                        <ul class="tab-btns tab-buttons clearfix p_relative d_iblock">
						
							<?php foreach($settings['repeat'] as $key=>$item):?>
						
                            <li class="tab-btn <?php if($key == 0) echo 'active-btn';?>" data-tab="#id-<?php echo esc_attr($key);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?></li>
							
							<?php endforeach; ?>
							
                        </ul>
                    </div>
                    <div class="tabs-content">
					
						<?php foreach($settings['repeat'] as $key=>$item):?>
					
                        <div class="tab <?php if($key == 0) echo 'active-tab';?>" id="id-<?php echo esc_attr($key);?>">
                            <div class="row clearfix">
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block centred">
                                    <div class="pricing-block-one">
                                        <div class="pricing-table p_relative d_block pt_50 pr_50 pb_50 pl_50 b_radius_10 b_shadow_6">
                                            <div class="table-header p_relative d_block mb_30">
                                                <h6 class="d_iblock fs_18 lh_28 b_radius_5 pl_19 pr_19 fw_medium mb_15"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                                <h2 class="d_block fs_40 lh_50 fw_bold mb_0"><?php echo esc_attr($item['block_price']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing']);?></span></h2>
                                                <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                            </div>
                                            <div class="table-content p_relative d_block p_relative pt_25 pr_30 pl_30 pb_25 b_radius_10 mb_40">
                                                <ul class="feature-list clearfix">
                                                    <?php $fearures = explode("\n", ($item['block_feature_str']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
											<?php if(wp_kses($item['block_button1'], $allowed_tags)): ?>
                                            <div class="table-footer">
                                                <a href="<?php echo esc_url($item['block_btnlink1']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button1'], $allowed_tags);?> <i class="icon-4"></i></a>
                                            </div>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block centred">
                                    <div class="pricing-block-one active-block">
                                        <div class="pricing-table p_relative d_block pt_50 pr_50 pb_50 pl_50 b_radius_10 b_shadow_6">
                                            <div class="table-header p_relative d_block mb_30">
                                                <h6 class="d_iblock fs_18 lh_28 b_radius_5 pl_19 pr_19 fw_medium mb_15"><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h6>
                                                <h2 class="d_block fs_40 lh_50 fw_bold mb_0"><?php echo esc_attr($item['block_price2']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing2']);?></span></h2>
                                                <p class="font_family_poppins"><?php echo wp_kses($item['block_text2'], $allowed_tags);?></p>
                                            </div>
                                            <div class="table-content p_relative d_block p_relative pt_25 pr_30 pl_30 pb_25 b_radius_10 mb_40">
                                                <ul class="feature-list clearfix">
                                                    <?php $fearures = explode("\n", ($item['block_feature_str2']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
											<?php if(wp_kses($item['block_button2'], $allowed_tags)): ?>
                                            <div class="table-footer">
                                                <a href="<?php echo esc_url($item['block_btnlink2']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button2'], $allowed_tags);?> <i class="icon-4"></i></a>
                                            </div>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-6 col-sm-12 pricing-block centred">
                                    <div class="pricing-block-one">
                                        <div class="pricing-table p_relative d_block pt_50 pr_50 pb_50 pl_50 b_radius_10 b_shadow_6">
                                            <div class="table-header p_relative d_block mb_30">
                                                <h6 class="d_iblock fs_18 lh_28 b_radius_5 pl_19 pr_19 fw_medium mb_15"><?php echo wp_kses($item['block_title3'], $allowed_tags);?></h6>
                                                <h2 class="d_block fs_40 lh_50 fw_bold mb_0"><?php echo esc_attr($item['block_price3']);?> <span class="fs_17"><?php echo esc_attr($item['ff_sing3']);?></span></h2>
                                                <p class="font_family_poppins"><?php echo wp_kses($item['block_text3'], $allowed_tags);?></p>
                                            </div>
                                            <div class="table-content p_relative d_block p_relative pt_25 pr_30 pl_30 pb_25 b_radius_10 mb_40">
                                                <ul class="feature-list clearfix">
                                                    <?php $fearures = explode("\n", ($item['block_feature_str3']));?>
													<?php foreach($fearures as $feature):?>
													<?php echo wp_kses($feature, true); ?>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
											<?php if(wp_kses($item['block_button3'], $allowed_tags)): ?>
                                            <div class="table-footer">
                                                <a href="<?php echo esc_url($item['block_btnlink3']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button3'], $allowed_tags);?> <i class="icon-4"></i></a>
                                            </div>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
						
						<?php endforeach; ?>
						
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style13' === $settings['style'] ) : ?>
		
		<section class="pricing-one pricing-page-3 pricing-seven p_relative pt_130 pb_150 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title p_relative d_block mb_50 centred">
                    <h2 class="d_block fs_40 fw_bold"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
				
				<?php foreach($settings['repeat'] as $key=>$item):?>
				
                <div class="row clearfix">
                    <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                        <div class="pricing-block-two">
                            <div class="pricing-table p_relative d_block pt_45 pr_40 pb_50 pl_40 b_shadow_6 b_radius_10">
                                <div class="table-header p_relative d_block mb_30">
                                    <h6 class="d_block fs_16 lh_20 fw_sbold mb_18 font_family_poppins"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                    <h2 class="d_block fs_50 lh_50 fw_bold font_family_inter"><?php echo esc_attr($item['block_price']);?> <span class="fs_17 font_family_poppins fw_normal"><?php echo esc_attr($item['ff_sing']);?></span></h2>
                                    <p class="fs_16 font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                </div>
                                <div class="table-content p_relative d_block p_relative mb_30">
                                    <ul class="feature-list-two clearfix">
                                        <?php $fearures = explode("\n", ($item['block_feature_str']));?>
										<?php foreach($fearures as $feature):?>
										<?php echo wp_kses($feature, true); ?>
										<?php endforeach; ?>
                                    </ul>
                                </div>
								<?php if(wp_kses($item['block_button1'], $allowed_tags)): ?>
                                <div class="table-footer">
                                    <a href="<?php echo esc_url($item['block_btnlink1']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button1'], $allowed_tags);?> <i class="icon-4"></i></a>
                                </div>
								<?php endif; ?>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                        <div class="pricing-block-two active-block">
                            <div class="pricing-table p_relative d_block pt_45 pr_40 pb_50 pl_40 b_shadow_6 b_radius_10">
                                <div class="table-header p_relative d_block mb_30">
                                    <h6 class="d_block fs_16 lh_20 fw_sbold mb_18 font_family_poppins"><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h6>
                                    <h2 class="d_block fs_50 lh_50 fw_bold font_family_inter"><?php echo esc_attr($item['block_price2']);?> <span class="fs_17 font_family_poppins fw_normal"><?php echo esc_attr($item['ff_sing2']);?></span></h2>
                                    <p class="fs_16 font_family_poppins"><?php echo wp_kses($item['block_text2'], $allowed_tags);?></p>
                                </div>
                                <div class="table-content p_relative d_block p_relative mb_30">
                                    <ul class="feature-list-two clearfix">
                                        <?php $fearures = explode("\n", ($item['block_feature_str2']));?>
										<?php foreach($fearures as $feature):?>
										<?php echo wp_kses($feature, true); ?>
										<?php endforeach; ?>
                                    </ul>
                                </div>
								<?php if(wp_kses($item['block_button2'], $allowed_tags)): ?>
                                <div class="table-footer">
                                    <a href="<?php echo esc_url($item['block_btnlink2']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button2'], $allowed_tags);?> <i class="icon-4"></i></a>
                                </div>
								<?php endif; ?>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-4 col-md-6 col-sm-12 pricing-block">
                        <div class="pricing-block-two">
                            <div class="pricing-table p_relative d_block pt_45 pr_40 pb_50 pl_40 b_shadow_6 b_radius_10">
                                <div class="table-header p_relative d_block mb_30">
                                    <h6 class="d_block fs_16 lh_20 fw_sbold mb_18 font_family_poppins"><?php echo wp_kses($item['block_title3'], $allowed_tags);?></h6>
                                    <h2 class="d_block fs_50 lh_50 fw_bold font_family_inter"><?php echo esc_attr($item['block_price3']);?> <span class="fs_17 font_family_poppins fw_normal"><?php echo esc_attr($item['ff_sing3']);?></span></h2>
                                    <p class="fs_16 font_family_poppins"><?php echo wp_kses($item['block_text3'], $allowed_tags);?></p>
                                </div>
                                <div class="table-content p_relative d_block p_relative mb_30">
                                    <ul class="feature-list-two clearfix">
                                        <?php $fearures = explode("\n", ($item['block_feature_str3']));?>
										<?php foreach($fearures as $feature):?>
										<?php echo wp_kses($feature, true); ?>
										<?php endforeach; ?>
                                    </ul>
                                </div>
								<?php if(wp_kses($item['block_button3'], $allowed_tags)): ?>
                                <div class="table-footer">
                                    <a href="<?php echo esc_url($item['block_btnlink3']['url']);?>" class="theme-btn theme-btn-six"><?php echo wp_kses($item['block_button3'], $allowed_tags);?> <i class="icon-4"></i></a>
                                </div>
								<?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
				
				<?php endforeach; ?>
				
            </div>
        </section>
		
		<?php endif;?>
             
		<?php 
	}

}