<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Process extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_process';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Process', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'process',
			[
				'label' => esc_html__( 'Process', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Choose Style 1', 'tranzix' ),
						'style2' => esc_html__( 'Choose Style 2', 'tranzix' ),
						'style3' => esc_html__( 'Choose Style 3', 'tranzix' ),
						'style4' => esc_html__( 'Choose Style 4', 'tranzix' ),
						'style5' => esc_html__( 'Choose Style 5', 'tranzix' ),
						'style6' => esc_html__( 'Choose Style 6', 'tranzix' ),
						'style7' => esc_html__( 'Choose Style 7', 'tranzix' ),
						'style8' => esc_html__( 'Choose Style 8', 'tranzix' ),
						'style9' => esc_html__( 'Choose Style 9', 'tranzix' ),
						'style10' => esc_html__( 'Choose Style 10', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style10',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Image Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'bgimg',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg1',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg2',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg3',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				
				
		$this->end_controls_section();
		
		// New Tab#2

		$this->start_controls_section(
					'content_section2',
					[
						'label' => __( 'Process Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_column',
									'label'   => esc_html__( 'Column', 'rashid' ),
									'type'    => Controls_Manager::NUMBER,
									'default' => 2,
									'min'     => 1,
									'max'     => 12,
									'step'    => 1,
								],
								[
									'name' => 'block_bgimg',
									'label' => esc_html__('Background image', 'rashid'),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_icons',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::SELECT,
									'options'  => get_fontawesome_icons(),
								],
								[
									'name' => 'block_icons2',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::SELECT,
									'options'  => get_fontawesome_icons(),
								],
								[
									'name' => 'block_image',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_alt_text',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_number',
									'label' => esc_html__('Number', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_column_class',
									'label' => esc_html__('Column Class', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		<?php  if ( 'style1' === $settings['style'] ) : ?>
		
        <section class="process-one p_relative sec-pad text-center bg-color-1 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="pattern-layer">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="pattern-1 p_absolute t_0" data-parallax='{"x": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                <div class="pattern-2 p_absolute t_0" data-parallax='{"x": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg2']['id']) ) : ?>
                <div class="pattern-3 p_absolute r_0 b_0" data-parallax='{"x": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg2']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg3']['id']) ) : ?>
                <div class="pattern-4 p_absolute r_0 b_0" data-parallax='{"x": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg3']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title p_relative d_block mb_60">
                    <span class="sub-title p_relative d_iblock fs_15 fw_medium g_color mb_19"><?php echo $settings['subtitle'];?></span>
                    <h2 class="p_relative d_block fs_40 fw_bold mb_30"><?php echo $settings['title'];?></h2>
                    <p><?php echo $settings['text'];?></p>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 processing-block">
                        <div class="processing-block-one wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                            <div class="inner-box p_relative d_block">
								<?php if(wp_get_attachment_url($item['block_bgimg']['id'])): ?>
                                <div class="shape p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
								<?php else :?>
								<div class="noimage">
								<?php endif;?>
								</div>
                                <div class="icon-box p_relative d_iblock w_170 h_170 lh_170 tran_5 b_radius_50 mb_30 z_1">
                                    <div class="icon p_relative d_iblock tran_5 g_color fs_50"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']));?>"></i></div>
                                    <div class="hov-icon p_absolute l_0 t_0 r_0 w_170 h_170 lh_170 r_0 fs_50 tran_5"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons2']));?>"></i></div>
                                    <div class="icon-img hidden-icon">
									
									<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
									<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
									
									</div>
                                    <span class="count-box p_absolute d_iblock t_5 w_40 h_40 lh_40 b_radius_50 fs_18 fw_sbold z_1"><?php echo esc_attr($item['block_number']);?></span>
                                </div>
                                <h4 class="d_block fs_20 lh_30 mb_15"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                <p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<section class="process-two p_relative pt_150 pb_140 text-center <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title-six p_relative d_block mb_75">
                    <h4 class="p_relative d_block fs_20 lh_30 fw_medium font_family_spartan mb_18"><?php echo $settings['subtitle'];?></h4>
                    <h2 class="d_block fs_50 lh_60 fw_bold font_family_spartan"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 processing-block">
                        <div class="processing-block-two wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                            <div class="inner-box p_relative d_block">
								<?php if(wp_get_attachment_url($item['block_bgimg']['id'])): ?>
                                <div class="shape p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
								<?php else :?>
								<div class="noimage">
								<?php endif;?>
								</div>
                                <div class="icon-box p_relative d_iblock w_170 h_170 lh_170 tran_5 b_radius_50 mb_30 z_1">
                                    <div class="icon p_relative d_iblock tran_5 fs_50"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']));?>"></i></div>
                                    <div class="hov-icon p_absolute l_0 t_0 r_0 w_170 h_170 lh_170 r_0 fs_25 tran_5"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons2']));?>"></i></div>
                                    <div class="icon-img hidden-icon">
									
									<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
									<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
									
									</div>
                                    <span class="count-box p_absolute d_iblock t_5 w_60 h_60 lh_60 b_radius_50 fs_18 fw_sbold z_1 font_family_spartan tran_5"><?php echo esc_attr($item['block_number']);?></span>
                                </div>
                                <h4 class="d_block fs_20 lh_30 fw_sbold font_family_spartan"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
		<section class="process-three p_relative pt_140 pb_160 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="pattern-1 hero-shape-three l_50 b_50 p_absolute"></div>
            <div class="pattern-2 hero-shape-three t_50 r_50 p_absolute"></div>
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
            <div class="pattern-layer p_absolute l_0 t_0 r_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			
			</div>
            <div class="auto-container">
                <div class="row clearfix">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 processing-block <?php echo esc_attr($item['block_column_class'], true );?>">
                        <div class="processing-block-three wow fadeInLeft animated" data-wow-delay="600ms" data-wow-duration="1500ms">
                            <div class="inner-box p_relative d_block pl_140 pr_30 pt_16 pb_20">
								<?php if(wp_get_attachment_url($item['block_bgimg']['id'])): ?>
                                <div class="shape p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
								<?php else :?>
								<div class="noimage">
								<?php endif;?>
								</div>
                                <div class="icon-box p_absolute l_0 t_0 d_iblock w_110 h_100 lh_100 tran_5 fs_40 z_1 centred">
                                    <div><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']));?>"></i></div>
                                    <div class="icon-img hidden-icon">
										<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
										<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
										<?php else :?>
										<div class="noimage"></div>
										<?php endif;?>
									</div>
                                    <span class="count-text p_absolute d_iblock w_50 h_50 lh_50 text-center b_radius_50 fs_18 fw_sbold font_family_spartan"><?php echo esc_attr($item['block_number']);?></span>
                                </div>
                                <h3 class="d_block fw_bold font_family_frank"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style4' === $settings['style'] ) : ?>
		
		<section class="process-five p_relative sec-pad centred <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
            <div class="shape p_absolute l_160 float-bob-y" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title-12 p_relative d_block mb_100">
                    <h5 class="d_block fs_17 lh_26 fw_sbold font_family_inter uppercase mb_19"><?php echo $settings['subtitle'];?></h5>
                    <h2 class="d_block fs_40 lh_50 fw_bold font_family_inter mb_30"><?php echo $settings['title'];?></h2>
                    <p class="fs_17 font_family_poppins lh_28"><?php echo $settings['text'];?></p>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 processing-block">
                        <div class="processing-block-four">
                            <div class="inner-box p_relative d_block pl_30 pr_30">
								<?php if(wp_get_attachment_url($item['block_bgimg']['id'])): ?>
                                <div class="line-shape p_absolute tran_5 t_20" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
								<?php else :?>
								<div class="noimage">
								<?php endif;?>
								</div>
                                <div class="count-box p_relative d_iblock w_70 h_70 lh_70 centred b_radius_50 fs_18 fw_sbold font_family_inter z_1 tran_5 mb_80">
                                    <span class="p_relative tran_5"><?php echo esc_attr($item['block_number']);?></span>
                                    <div class="overlay-icon p_absolute l_0 t_0 r_0 w_70 h_70 lh_70 centred fs_25 tran_5"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']));?>"></i></div>
                                </div>
                                <div class="text">
                                    <h4 class="d_block fs_20 fw_sbold lh_30 mb_16"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                    <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                </div>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style5' === $settings['style'] ) : ?>
		
		<section class="process-six p_relative sec-pad centred <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title-six p_relative d_block mb_100">
                    <h4 class="p_relative d_block fs_17 uppercase lh_30 fw_sbold mb_15"><?php echo $settings['subtitle'];?></h4>
                    <h2 class="d_block fs_40 lh_52 fw_bold"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 processing-block">
                        <div class="processing-block-five">
                            <div class="inner-box p_relative d_block pl_30 pr_30">
								<?php if(wp_get_attachment_url($item['block_bgimg']['id'])): ?>
                                <div class="line-shape p_absolute tran_5 t_35" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
								<?php else :?>
								<div class="noimage">
								<?php endif;?>
								</div>
                                <div class="count-box p_relative d_iblock w_70 h_70 lh_70 centred b_radius_50 fs_18 fw_sbold font_family_inter z_1 tran_5 mb_60">
                                    <span class="p_relative tran_5"><?php echo esc_attr($item['block_number']);?></span>
                                    <div class="overlay-icon p_absolute l_0 t_0 r_0 w_70 h_70 lh_70 centred fs_25 tran_5"><i class="icon-16"></i></div>
                                </div>
                                <div class="text">
                                    <h4 class="d_block fs_20 fw_sbold lh_30 mb_16"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                    <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                </div>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style6' === $settings['style'] ) : ?>
		
		<section class="process-six process-page p_relative pt_130 pb_140 centred <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title p_relative d_block mb_100">
                    <h2 class="d_block fs_40 lh_52 fw_bold"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 processing-block">
                        <div class="processing-block-five">
                            <div class="inner-box p_relative d_block pl_30 pr_30">
								<?php if(wp_get_attachment_url($item['block_bgimg']['id'])): ?>
                                <div class="line-shape p_absolute tran_5 t_35" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
								<?php else :?>
								<div class="noimage">
								<?php endif;?>
								</div>
                                <div class="count-box p_relative d_iblock w_70 h_70 lh_70 centred b_radius_50 fs_18 fw_sbold font_family_inter z_1 tran_5 mb_60">
                                    <span class="p_relative tran_5"><?php echo esc_attr($item['block_number']);?></span>
                                    <div class="overlay-icon p_absolute l_0 t_0 r_0 w_70 h_70 lh_70 centred fs_25 tran_5"><i class="icon-16"></i></div>
                                </div>
                                <div class="text">
                                    <h4 class="d_block fs_20 fw_sbold lh_30 mb_16"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                    <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                </div>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style7' === $settings['style'] ) : ?>
		
		<section class="process-one process-page p_relative sec-pad text-center bg-color-1  <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title p_relative d_block mb_70">
                    <h2 class="d_block fs_40 lh_52 fw_bold"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 processing-block">
                        <div class="processing-block-one wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                            <div class="inner-box p_relative d_block">
								<?php if(wp_get_attachment_url($item['block_bgimg']['id'])): ?>
                                <div class="shape p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
								<?php else :?>
								<div class="noimage">
								<?php endif;?>
								</div>
                                <div class="icon-box p_relative d_iblock w_170 h_170 lh_170 tran_5 b_radius_50 mb_30 z_1">
                                    <div class="icon p_relative d_iblock tran_5 fs_50"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']));?>"></i></div>
                                    <div class="hov-icon p_absolute l_0 t_0 r_0 w_170 h_170 lh_170 r_0 fs_50 tran_5"><i class="icon-16"></i></div>
									
                                    <div class="icon-img hidden-icon">
										<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
										<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
										<?php else :?>
										<div class="noimage"></div>
										<?php endif;?>
									</div>
									
                                    <span class="count-box p_absolute d_iblock t_5 w_40 h_40 lh_40 b_radius_50 fs_18 fw_sbold z_1"><?php echo esc_attr($item['block_number']);?></span>
                                </div>
                                <h4 class="d_block fs_20 lh_30 mb_15"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                <p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style8' === $settings['style'] ) : ?>
		
		<section class="process-seven p_relative pt_140 pb_140 centred <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title p_relative d_block mb_80">
                    <h2 class="d_block fs_40 lh_52 fw_bold"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 processing-block">
                        <div class="processing-block-six wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                            <div class="inner-box p_relative d_block pl_30 pr_30">
                                <div class="count-box p_relative d_iblock w_70 h_70 lh_70 centred b_radius_50 fs_18 fw_sbold font_family_inter z_1 tran_5 mb_45 counted">
                                    <span class="p_relative fs_22 fw_sbold font_family_inter color_black tran_5"><?php echo esc_attr($item['block_number']);?></span>
                                    <div class="overlay-icon p_absolute l_0 t_0 r_0 w_70 h_70 lh_70 centred fs_25 tran_5"><i class="icon-16"></i></div>
                                </div>
                                <h4 class="d_block fs_20 mb_17 fw_sbold"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                <p class="d_block font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style9' === $settings['style'] ) : ?>
		
		<section class="process-three process-page p_relative pt_140 pb_160 <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
            <div class="pattern-layer p_absolute l_0 t_0 r_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title p_relative d_block mb_95 centred">
                    <h2 class="d_block fs_40 lh_52 fw_bold"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 processing-block <?php echo esc_attr($item['block_column_class'], true );?>">
                        <div class="processing-block-three wow fadeInLeft animated" data-wow-delay="600ms" data-wow-duration="1500ms">
                            <div class="inner-box p_relative d_block pl_140 pr_30 pt_16 pb_20">
								<?php if(wp_get_attachment_url($item['block_bgimg']['id'])): ?>
                                <div class="shape p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
								<?php else :?>
								<div class="noimage">
								<?php endif;?>
								</div>
                                <div class="icon-box p_absolute l_0 t_0 d_iblock w_110 h_100 lh_100 tran_5 fs_40 z_1 centred">
                                    <div><i class="icon-57"></i></div>
									
                                    <div class="icon-img hidden-icon">
										<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
										<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
										<?php else :?>
										<div class="noimage"></div>
										<?php endif;?>
									</div>
									
                                    <span class="count-text p_absolute d_iblock w_50 h_50 lh_50 text-center b_radius_50 fs_18 fw_sbold font_family_spartan"><?php echo esc_attr($item['block_number']);?></span>
                                </div>
                                <h3 class="d_block fw_bold font_family_frank"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style10' === $settings['style'] ) : ?>
		
		<section class="process-five process-page p_relative pt_95 pb_140 centred <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title p_relative d_block mb_110 centred">
                    <h2 class="d_block fs_40 lh_52 fw_bold"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 processing-block">
                        <div class="processing-block-four">
                            <div class="inner-box p_relative d_block pl_30 pr_30">
								<?php if(wp_get_attachment_url($item['block_bgimg']['id'])): ?>
                                <div class="line-shape p_absolute tran_5 t_20" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
								<?php else :?>
								<div class="noimage">
								<?php endif;?>
								</div>
								
                                <div class="count-box p_relative d_iblock w_70 h_70 lh_70 centred b_radius_50 fs_18 fw_sbold font_family_inter z_1 tran_5 mb_80">
                                    <span class="p_relative tran_5"><?php echo esc_attr($item['block_number']);?></span>
                                    <div class="overlay-icon p_absolute l_0 t_0 r_0 w_70 h_70 lh_70 centred fs_25 tran_5"><i class="icon-16"></i></div>
                                </div>
                                <div class="text">
                                    <h4 class="d_block fs_20 fw_sbold lh_30 mb_16"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                    <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                </div>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
             
		<?php 
	}

}