<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Project_Details extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_project_details';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Project Details', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'project_details',
			[
				'label' => esc_html__( 'Project Details', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style2' => esc_html__( 'Choose Style 2', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'List Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_column',
									'label'   => esc_html__( 'Column', 'rashid' ),
									'type'    => Controls_Manager::NUMBER,
									'default' => 2,
									'min'     => 1,
									'max'     => 12,
									'step'    => 1,
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
		
		// New Tab#2

		$this->start_controls_section(
					'content_section2',
					[
						'label' => __( 'Social Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'title1',
					[
						'label'       => __( 'Title', 'rashid' ),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
							),
						),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
				  'repeat1', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_icons',
									'label' => esc_html__('Enter The icons', 'inovex'),
									'type' => Controls_Manager::ICONS,
									
								],
								[
									'name' => 'block_btnlink',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									'url' => '',
									'is_external' => true,
									'nof
									ollow' => true,
									],
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		<?php  if ( 'style1' === $settings['style'] ) : ?>
		
        <section class="project-details p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="project-info p_relative d_block mb_110">
                    <div class="row clearfix">
                        <div class="col-lg-8 col-md-12 col-sm-12 text-column">
                            <div class="text p_relative d_block mr_40">
                                <h3 class="d_block fs_30 lh_40 fw_sbold mb_15"><?php echo $settings['title'];?></h3>
                                <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                            </div>
                        </div>
                        <div class="col-lg-4 col-md-12 col-sm-12 info-column">
                            <div class="info p_relative d_block pl_100 pt_20 pb_20 mt_15">
                                <ul class="info-list clearfix">
								
									<?php foreach($settings['repeat'] as $item):?>
								
                                    <li class="p_relative d_block fs_18 font_family_inter mb_12"><span class="d_iblock fw_medium color_black"><?php echo wp_kses($item['block_title'], $allowed_tags);?></span><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
									
									<?php endforeach; ?>
									
									
									
                                    <li class="social-links p_relative d_block fs_18 font_family_inter">
									
									<span class="d_iblock fw_medium color_black"><?php echo $settings['title1'];?></span>
									
									
									<?php foreach($settings['repeat1'] as $item):?>
									
									<a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="fab <?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a>
									
									<?php endforeach; ?>
									
									</li>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<section class="project-details p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="project-info p_relative d_block mb_110">
                    <div class="row clearfix">
                        <div class="col-lg-8 col-md-12 col-sm-12 text-column">
                            <div class="text p_relative d_block mr_40">
                                <h3 class="d_block fs_30 lh_40 fw_sbold mb_15"><?php echo $settings['title'];?></h3>
                                <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                            </div>
                        </div>
                        <div class="col-lg-4 col-md-12 col-sm-12 info-column">
                            <div class="info p_relative d_block pl_100 pt_20 pb_20 mt_15">
                                <ul class="info-list clearfix">
								
									<?php foreach($settings['repeat'] as $item):?>
								
                                    <li class="p_relative d_block fs_18 font_family_inter mb_12"><span class="d_iblock fw_medium color_black"><?php echo wp_kses($item['block_title'], $allowed_tags);?></span><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
									
									<?php endforeach; ?>
									
                                    <li class="social-links p_relative d_block fs_18 font_family_inter">
									
									<span class="d_iblock fw_medium color_black"><?php echo $settings['title1'];?></span>
									
									<?php foreach($settings['repeat1'] as $item):?>
									
									<a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="fab <?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a>
									
									<?php endforeach; ?>
									
									</li>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
		<section class="project-details project-details-3 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 sidebar-side">
                        <div class="project-sidebar">
                            <div class="text p_relative d_block mb_25">
                                <h3 class="d_block fs_30 lh_40 fw_sbold mb_25"><?php echo $settings['title'];?></h3>
                                <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                            </div>
                            <div class="project-info p_relative d_block mb_110">
                                <div class="info p_relative d_block">
                                    <ul class="info-list clearfix">
									
                                        <?php foreach($settings['repeat'] as $item):?>
								
										<li class="p_relative d_block fs_18 font_family_inter mb_12"><span class="d_iblock fw_medium color_black"><?php echo wp_kses($item['block_title'], $allowed_tags);?></span><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
										
										<?php endforeach; ?>
										
										<li class="social-links p_relative d_block fs_18 font_family_inter">
										
										<span class="d_iblock fw_medium color_black"><?php echo $settings['title1'];?></span>
										
										<?php foreach($settings['repeat1'] as $item):?>
										
										<a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><i class="fab <?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></a>
										
										<?php endforeach; ?>
										
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style4' === $settings['style'] ) : ?>
		
		<section class="project-details project-details-4 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="project-details-content p_relative d_block mb_110">
                    <div class="text centred ml_100 mr_100 mb_60">
                        <p class="font_family_poppins lh_28"><?php echo $settings['text'];?></p>
                    </div>
                    <div class="porject-info p_relative d_block">
                        <div class="info-list clearfix ml_100 mb_110">
                            <div class="row clearfix">
							
								<?php foreach($settings['repeat'] as $item):?>
							
                                <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 single-column">
                                    <div class="single-item p_relative d_block pull-left">
                                        <h6 class="d_block fs_16 fw_medium mb_8"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                        <p class="font_family_inter"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                    </div>
                                </div>
								
								<?php endforeach; ?>
								
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
             
		<?php 
	}

}