<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Project_Details2 extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_project_details2';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Project Details 2', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'project_details2',
			[
				'label' => esc_html__( 'Project Details 2', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style2' => esc_html__( 'Choose Style 2', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'text1',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'text2',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
					),
				),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'rashid' ),
			]
		);	
		$this->add_control(
			'btnlink',
			[
			  'label' => __( 'Button Url', 'rashid' ),
			  'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
					),
				),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'rashid' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
			  ],
			
		   ]
		);
		$this->add_control(
			'bttn1',
			[
				'label'       => __( 'Button', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
					),
				),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'rashid' ),
			]
		);	
		$this->add_control(
			'btnlink1',
			[
			  'label' => __( 'Button Url', 'rashid' ),
			  'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
					),
				),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'rashid' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
			  ],
			
		   ]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'List Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_column',
									'label'   => esc_html__( 'Column', 'rashid' ),
									'type'    => Controls_Manager::NUMBER,
									'default' => 2,
									'min'     => 1,
									'max'     => 12,
									'step'    => 1,
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_text1',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
				);
				
				
		$this->end_controls_section();	
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		<?php  if ( 'style1' === $settings['style'] ) : ?>
		
        <section class="project-details p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="lower-box p_relative d_block mb_100">
                    <div class="row clearfix">
                        <div class="col-lg-6 col-md-12 col-sm-12 text-column">
                            <div class="text mr_30">
                                <p class="font_family_poppins"><?php echo $settings['text1'];?></p>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12 text-column">
                            <div class="text ml_30">
                                <p class="font_family_poppins"><?php echo $settings['text2'];?></p>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="nav-btn clearfix">
					<?php if($settings['bttn']): ?>
                    <div class="single-btn prev-btn pull-left">
                        <a href="<?php echo esc_url($settings['btnlink']['url']);?>" class="p_relative d_iblock fs_18 fw_sbold font_family_inter color_black"><i class="far fa-long-arrow-left"></i><?php echo $settings['bttn'];?></a>
                    </div>
					<?php endif; ?>
					<?php if($settings['bttn1']): ?>
                    <div class="single-btn next-btn pull-right">
                        <a href="<?php echo esc_url($settings['btnlink1']['url']);?>" class="p_relative d_iblock fs_18 fw_sbold font_family_inter color_black"><?php echo $settings['bttn1'];?><i class="far fa-long-arrow-right"></i></a>
                    </div>
					<?php endif; ?>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<section class="project-details p_relative pb_110 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="lower-box p_relative d_block mb_100">
                    <div class="text">
                        <p class="font_family_poppins mb_25"><?php echo $settings['text1'];?></p>
                        <p class="font_family_poppins"><?php echo $settings['text2'];?></p>
                    </div>
                </div>
                <div class="nav-btn clearfix">
					<?php if($settings['bttn']): ?>
                    <div class="single-btn prev-btn pull-left">
                        <a href="<?php echo esc_url($settings['btnlink']['url']);?>" class="p_relative d_iblock fs_18 fw_sbold font_family_inter color_black"><i class="far fa-long-arrow-left"></i><?php echo $settings['bttn'];?></a>
                    </div>
					<?php endif; ?>
					<?php if($settings['bttn1']): ?>
                    <div class="single-btn next-btn pull-right">
                        <a href="<?php echo esc_url($settings['btnlink1']['url']);?>" class="p_relative d_iblock fs_18 fw_sbold font_family_inter color_black"><?php echo $settings['bttn1'];?><i class="far fa-long-arrow-right"></i></a>
                    </div>
					<?php endif; ?>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
		<section class="project-details project-details-3 p_relative pb_110 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="nav-btn clearfix">
					<?php if($settings['bttn']): ?>
                    <div class="single-btn prev-btn pull-left">
                        <a href="<?php echo esc_url($settings['btnlink']['url']);?>" class="p_relative d_iblock fs_18 fw_sbold font_family_inter color_black"><i class="far fa-long-arrow-left"></i><?php echo $settings['bttn'];?></a>
                    </div>
					<?php endif; ?>
					<?php if($settings['bttn1']): ?>
                    <div class="single-btn next-btn pull-right">
                        <a href="<?php echo esc_url($settings['btnlink1']['url']);?>" class="p_relative d_iblock fs_18 fw_sbold font_family_inter color_black"><?php echo $settings['bttn1'];?><i class="far fa-long-arrow-right"></i></a>
                    </div>
					<?php endif; ?>
                </div>
            </div>
        </section>
		
		<?php endif;?>		
		
		<?php  if ( 'style4' === $settings['style'] ) : ?>
		
		<section class="project-details project-details-4 p_relative pb_110 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="nav-btn clearfix">
					<?php if($settings['bttn']): ?>
                    <div class="single-btn prev-btn pull-left">
                        <a href="<?php echo esc_url($settings['btnlink']['url']);?>" class="p_relative d_iblock fs_18 fw_sbold font_family_inter color_black"><i class="far fa-long-arrow-left"></i><?php echo $settings['bttn'];?></a>
                    </div>
					<?php endif; ?>
					<?php if($settings['bttn1']): ?>
                    <div class="single-btn next-btn pull-right">
                        <a href="<?php echo esc_url($settings['btnlink1']['url']);?>" class="p_relative d_iblock fs_18 fw_sbold font_family_inter color_black"><?php echo $settings['bttn1'];?><i class="far fa-long-arrow-right"></i></a>
                    </div>
					<?php endif; ?>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style5' === $settings['style'] ) : ?>
		
        <section class="project-details project-details-4 project-details-5 p_relative pb_140 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="project-details-content p_relative d_block">
                <div class="auto-container">
                    <div class="text-box p_relative d_block mb_100">
                        <div class="row clearfix">
						
							<?php foreach($settings['repeat'] as $item):?>
						
                            <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-12 col-sm-12 text-column">
                                <div class="text mr_30">
                                    <h3 class="d_block fs_24 lh_30 fw_bold mb_17"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
                                    <p class="font_family_poppins mb_25"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                    <p><?php echo wp_kses($item['block_text1'], $allowed_tags);?></p>
                                </div>
                            </div>
							
							<?php endforeach; ?>
							
                        </div>
                    </div>
                    <div class="nav-btn clearfix">
					
						
						<?php if($settings['bttn']): ?>
                        <div class="single-btn prev-btn pull-left">
                            <a href="<?php echo esc_url($settings['btnlink']['url']);?>" class="p_relative d_iblock fs_18 fw_sbold font_family_inter color_black"><i class="far fa-long-arrow-left"></i><?php echo $settings['bttn'];?></a>
                        </div>
						<?php endif; ?>
						<?php if($settings['bttn1']): ?>
                        <div class="single-btn next-btn pull-right">
                            <a href="<?php echo esc_url($settings['btnlink1']['url']);?>" class="p_relative d_iblock fs_18 fw_sbold font_family_inter color_black"><?php echo $settings['bttn1'];?><i class="far fa-long-arrow-right"></i></a>
                        </div>
						<?php endif; ?>
						
						
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
             
		<?php 
	}

}