<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Service extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_service';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'service',
			[
				'label' => esc_html__( 'Service', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'return_value' => 'style1',
                    'default'      => 'style1',
					'options' => array(
						'style10' => esc_html__( 'Choose Style 10', 'tranzix' ),
						'style17' => esc_html__( 'Choose Style 17', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style10',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style12',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style13',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style14',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style15',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style17',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style10',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style12',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style13',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style14',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style15',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style16',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style17',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style19',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style17',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style19',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'text1',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style17',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'text2',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style17',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'text3',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style17',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style10',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style12',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style16',
						),
					),
				),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'rashid' ),
			]
		);	
		$this->add_control(
			'btnlink',
			[
			  'label' => __( 'Button Url', 'rashid' ),
			  'conditions' => array(
				'relation' => 'or',
				'terms'    => array(
					array(
						'name'     => 'style',
						'operator' => '==',
						'value'    => 'style5',
					),
					array(
						'name'     => 'style',
						'operator' => '==',
						'value'    => 'style7',
					),
					array(
						'name'     => 'style',
						'operator' => '==',
						'value'    => 'style8',
					),
					array(
						'name'     => 'style',
						'operator' => '==',
						'value'    => 'style10',
					),
					array(
						'name'     => 'style',
						'operator' => '==',
						'value'    => 'style11',
					),
					array(
						'name'     => 'style',
						'operator' => '==',
						'value'    => 'style12',
					),
					array(
						'name'     => 'style',
						'operator' => '==',
						'value'    => 'style16',
					),
				),
			),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'rashid' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
			  ],
			
		   ]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
				'content_section',
				[
					'label' => __( 'Image Block', 'rashid' ),
					'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				]
			);
			$this->add_control(
				'bgimg',
				[
					'label' => esc_html__('Background image', 'rashid'),
					'conditions' => array(
						'relation' => 'or',
						'terms'    => array(
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style1',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style2',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style3',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style4',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style5',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style7',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style8',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style11',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style12',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style16',
							),
						),
					),
					'type' => Controls_Manager::MEDIA,
					'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
			);
			$this->add_control(
				'bgimg1',
				[
					'label' => esc_html__('Background image', 'rashid'),
					'conditions' => array(
						'relation' => 'or',
						'terms'    => array(
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style1',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style2',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style3',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style7',
							),
						),
					),
					'type' => Controls_Manager::MEDIA,
					'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
			);
			$this->add_control(
				'bgimg2',
				[
					'label' => esc_html__('Background image', 'rashid'),
					'conditions' => array(
						'relation' => 'or',
						'terms'    => array(
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style1',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style3',
							),
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style7',
							),
						),
					),
					'type' => Controls_Manager::MEDIA,
					'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
			);
			$this->add_control(
				'bgimg3',
				[
					'label' => esc_html__('Background image', 'rashid'),
					'conditions' => array(
						'relation' => 'or',
						'terms'    => array(
							array(
								'name'     => 'style',
								'operator' => '==',
								'value'    => 'style1',
							),
						),
					),
					'type' => Controls_Manager::MEDIA,
					'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
			);
				
				
		$this->end_controls_section();	
		
		// New Tab#2

		$this->start_controls_section(
					'content_section2',
					[
						'label' => __( 'Service Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_column',
									'label'   => esc_html__( 'Column', 'rashid' ),
									'type'    => Controls_Manager::NUMBER,
									'default' => 2,
									'min'     => 1,
									'max'     => 12,
									'step'    => 1,
								],
								[
									'name' => 'block_icons',
									'label' => esc_html__('Enter The icons', 'inovex'),
									'type' => Controls_Manager::ICONS,
									
								],
								[
									'name' => 'block_image',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_alt_text',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_bgimg',
									'label' => esc_html__('Background image', 'rashid'),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_image1',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_alt_text1',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_button',
									'label'       => __( 'Button', 'rashid' ),
									'type'        => Controls_Manager::TEXT,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Button Title', 'rashid' ),
								],
								[
									'name' => 'block_btnlink',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									'url' => '',
									'is_external' => true,
									'nof
									ollow' => true,
									],
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
		
			
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
		
		<?php  if ( 'style10' === $settings['style'] ) : ?>
		
		<section class="service-nine p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title p_relative d_block mb_45 centred">
                    <h2 class="d_block fs_50 fw_bold lh_55 fw_bold font_family_spartan"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 service-block">
                        <div class="service-block-eight wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                            <div class="inner-box p_relative d_block b_shadow_6">
                                <figure class="image-box p_relative d_block">
									<a href="<?php echo esc_url($item['block_btnlink']['url']);?>">
										<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
										<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
										<?php else :?>
										<div class="noimage"></div>
										<?php endif;?>
									</a>
								</figure>
                                <div class="lower-content p_relative d_block pl_40 pr_30 pb_40 pt_65">
                                    <div class="icon-box p_absolute l_40 fs_45 mb_25 w_80 h_80 lh_80 text-center">
                                        <div class="icon"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></div>
                                        <div class="icon-img hidden-icon">
											<?php if(wp_get_attachment_url($item['block_image1']['id'])): ?>
											<img src="<?php echo wp_get_attachment_url($item['block_image1']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text1'], $allowed_tags);?>">
											<?php else :?>
											<div class="noimage"></div>
											<?php endif;?>
										</div>
                                    </div>
                                    <h4 class="d_block fs_24 lh_28 fw_bold font_family_spartan mb_16"><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></h4>
                                    <p class="d_block font_family_oxygen"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                </div>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
				<?php if($settings['bttn']): ?>
                <div class="more-btn centred mt_60">
                    <a href="<?php echo esc_url($settings['btnlink']['url']);?>" class="theme-btn theme-btn-eight"><?php echo $settings['bttn'];?></a>
                </div>
				<?php endif; ?>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style17' === $settings['style'] ) : ?>
		
		<section class="about-three about-page-1 p_relative pt_140 pb_150 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="upper-box p_relative d_block mb_60 centred">
                    <div class="row clearfix">
                        <div class="col-lg-12 col-md-12 col-sm-12 title-column">
                            <div class="sec-title-three p_relative d_block mr_100 mt_10">
                                <h6 class="d_block fs_18 lh_26 fw_sbold uppercase mb_12"><?php echo $settings['subtitle'];?></h6>
                                <h2 class="d_block fs_50 fw_bold"><?php echo $settings['title'];?></h2>
                            </div>
                        </div>
                    </div>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
				
					<?php foreach($settings['repeat'] as $item):?>
				
                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 feature-block">
                        <div class="feature-block-three wow fadeInUp animated animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                            <div class="inner-box p_relative d_block b_radius_10 b_shadow_6 pl_40 pt_70 pr_40 pb_70 centred">
                                <div class="icon-box p_relative d_iblock w_80 h_80 lh_85 fs_45 centred b_radius_50 mb_20"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></div>
                                <h4 class="d_block fs_24 lh_30 fw_sbold mb_15 tran_5"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                <p class="font_family_poppins tran_5"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                            </div>
                        </div>
                    </div>
					
					<?php endforeach; ?>
					
                </div>
            </div>
        </section>
		
		<?php endif;?>
             
		<?php 
	}

}