<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Service_Details3 extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_service_details3';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service Details 3', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'service_details3',
			[
				'label' => esc_html__( 'Service Details 3', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style3' => esc_html__( 'Choose Style 3', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Accordion Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
		
		<?php  if ( 'style1' === $settings['style'] ) : ?>
        
        <section class="service-details service-details-1 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 content-side">
                        <div class="service-details-content">
                            <div class="content-three">
								<?php if($settings['title']): ?>
                                <div class="text p_relative d_block mb_30">
                                    <h3 class="d_block fs_30 lh_40 fw_sbold mb_25"><?php echo $settings['title'];?></h3>
                                    <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                                </div>
								<?php endif; ?>
                                <ul class="accordion-box">
								
									<?php foreach($settings['repeat'] as $key=>$item):?>
								
                                    <li class="accordion block <?php if($key == 1) echo 'active-block';?> p_relative d_block mb_30">
                                        <div class="acc-btn <?php if($key == 1) echo 'active';?> p_relative d_block tran_5 pt_16 pr_80 pb_16 pl_30">
                                            <div class="icon-outer p_absolute fs_10 tran_5 z_1"><i class="icon-29"></i></div>
                                            <h5 class="p_relative d_block fs_18 lh_30 fw_sbold"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h5>
                                        </div>
                                        <div class="acc-content <?php if($key == 1) echo 'current';?> p_relative pt_25 pr_50 pl_30">
                                            <div class="text p_relative d_block">
                                                <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                            </div>
                                        </div>
                                    </li>
									
									<?php endforeach; ?>
									
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<section class="service-details service-details-2 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 content-side">
                        <div class="service-details-content">
                            <div class="content-three">
								<?php if($settings['title']): ?>
                                <div class="text p_relative d_block mb_30">
                                    <h3 class="d_block fs_30 lh_40 fw_sbold mb_25"><?php echo $settings['title'];?></h3>
                                    <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                                </div>
								<?php endif; ?>
                                <ul class="accordion-box">
								
									<?php foreach($settings['repeat'] as $key=>$item):?>
								
                                    <li class="accordion block <?php if($key == 1) echo 'active-block';?> p_relative d_block mb_30">
                                        <div class="acc-btn <?php if($key == 1) echo 'active';?> p_relative d_block tran_5 pt_16 pr_80 pb_16 pl_30">
                                            <div class="icon-outer p_absolute fs_10 tran_5 z_1"><i class="icon-29"></i></div>
                                            <h5 class="p_relative d_block fs_18 lh_30 fw_sbold"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h5>
                                        </div>
                                        <div class="acc-content <?php if($key == 1) echo 'current';?> p_relative pt_25 pr_50 pl_30">
                                            <div class="text p_relative d_block">
                                                <p class="font_family_poppins"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                            </div>
                                        </div>
                                    </li>
									
									<?php endforeach; ?>
									
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
		<section class="service-details service-details-3 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 content-side">
                        <div class="service-details-content">
                            <div class="content-three">
                                <div class="text">
                                    <h3 class="d_block fs_30 lh_40 fw_sbold mb_25"><?php echo $settings['title'];?></h3>
                                    <p class="font_family_poppins mb_25"><?php echo $settings['text'];?></p>
                                    <ul class="list clearfix">
									
										<?php foreach($settings['repeat'] as $item):?>
									
                                        <li class="p_relative pl_30 d_block fs_18 font_family_inter fw_sbold color_black mb_8"><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
										
										<?php endforeach; ?>
										
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
             
		<?php 
	}

}