<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Service_Tab extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_service_tab';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service Tab', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'service_tab',
			[
				'label' => esc_html__( 'Service Tab', 'tranzix' ),
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title5',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Tab Block One', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'tab_bttn',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);	
				$this->add_control(
					'bgimg',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg1',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'image',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'title',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'text',
					[
						'label'       => __( 'Description Text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'text1',
					[
						'label'       => __( 'Description Text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'bttn',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);	
				$this->add_control(
					'btnlink',
					[
					  'label' => __( 'Button Url', 'rashid' ),
					  'type' => Controls_Manager::URL,
					  'placeholder' => __( 'https://your-link.com', 'rashid' ),
					  'show_external' => true,
					  'default' => [
						'url' => '',
						'is_external' => true,
						'nofollow' => true,
					  ],
					
				   ]
				);
				
				
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section1',
					[
						'label' => __( 'Tab Block Two', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'tab_bttn1',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);
				$this->add_control(
					'title1',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'text2',
					[
						'label'       => __( 'Description Text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'bttn1',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);	
				$this->add_control(
					'btnlink1',
					[
					  'label' => __( 'Button Url', 'rashid' ),
					  'type' => Controls_Manager::URL,
					  'placeholder' => __( 'https://your-link.com', 'rashid' ),
					  'show_external' => true,
					  'default' => [
						'url' => '',
						'is_external' => true,
						'nofollow' => true,
					  ],
					
				   ]
				);
				$this->add_control(
					'bgimg2',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg3',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'image1',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text1',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					  'repeat', 
						[
							'type' => Controls_Manager::REPEATER,
							'seperator' => 'before',
							'default' => 
								[
									['block_title' => esc_html__('Projects Completed', 'rashid')],
								],
							'fields' => 
								[
									[
										'name' => 'block_title',
										'label' => esc_html__('Title', 'rashid'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'rashid')
									],
								],
							'title_field' => '{{block_title}}',
						 ]
				);
				
				
		$this->end_controls_section();
		
		// New Tab#2

		$this->start_controls_section(
					'content_section2',
					[
						'label' => __( 'Tab Block Three', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'tab_bttn2',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);
				$this->add_control(
					'bgimg4',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg5',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'image2',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text2',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'image3',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text3',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'image4',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text4',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'title2',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'text3',
					[
						'label'       => __( 'Description Text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'bttn2',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);	
				$this->add_control(
					'btnlink2',
					[
					  'label' => __( 'Button Url', 'rashid' ),
					  'type' => Controls_Manager::URL,
					  'placeholder' => __( 'https://your-link.com', 'rashid' ),
					  'show_external' => true,
					  'default' => [
						'url' => '',
						'is_external' => true,
						'nofollow' => true,
					  ],
					
				   ]
				);
				$this->add_control(
					  'repeat1', 
						[
							'type' => Controls_Manager::REPEATER,
							'seperator' => 'before',
							'default' => 
								[
									['block_title' => esc_html__('Projects Completed', 'rashid')],
								],
							'fields' => 
								[
									[
										'name' => 'block_title',
										'label' => esc_html__('Title', 'rashid'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'rashid')
									],
								],
							'title_field' => '{{block_title}}',
						 ]
				);
				
				
		$this->end_controls_section();
		
		// New Tab#3

		$this->start_controls_section(
					'content_section3',
					[
						'label' => __( 'Tab Block Four', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'tab_bttn3',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);
				$this->add_control(
					'title3',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'text4',
					[
						'label'       => __( 'Description Text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'bgimg6',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg7',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'image5',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text5',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'image6',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text6',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					  'repeat2', 
						[
							'type' => Controls_Manager::REPEATER,
							'seperator' => 'before',
							'default' => 
								[
									['block_title' => esc_html__('Projects Completed', 'rashid')],
								],
							'fields' => 
								[
									[
										'name' => 'block_title',
										'label' => esc_html__('Title', 'rashid'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'rashid')
									],
								],
							'title_field' => '{{block_title}}',
						 ]
				);
				
				
		$this->end_controls_section();
		
		// New Tab#4

		$this->start_controls_section(
					'content_section4',
					[
						'label' => __( 'Tab Block Five', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'tab_bttn4',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);
				$this->add_control(
					'bgimg8',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg9',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'image7',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text7',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'image8',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text8',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'title4',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'text5',
					[
						'label'       => __( 'Description Text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'bttn3',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);	
				$this->add_control(
					'btnlink3',
					[
					  'label' => __( 'Button Url', 'rashid' ),
					  'type' => Controls_Manager::URL,
					  'placeholder' => __( 'https://your-link.com', 'rashid' ),
					  'show_external' => true,
					  'default' => [
						'url' => '',
						'is_external' => true,
						'nofollow' => true,
					  ],
					
				   ]
				);
				$this->add_control(
					  'repeat3', 
						[
							'type' => Controls_Manager::REPEATER,
							'seperator' => 'before',
							'default' => 
								[
									['block_title' => esc_html__('Projects Completed', 'rashid')],
								],
							'fields' => 
								[
									[
										'name' => 'block_title',
										'label' => esc_html__('Title', 'rashid'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'rashid')
									],
								],
							'title_field' => '{{block_title}}',
						 ]
				);
				
				
		$this->end_controls_section();
		
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		
        <section class="service-eight p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title-eight p_relative d_block mb_55 centred">
                    <h5 class="p_relative d_iblock fs_18 lh_30 fw_sbold font_family_poppins mb_12"><?php echo $settings['subtitle'];?></h5><br />
                    <h2 class="d_block fs_50 fw_bold lh_50 fw_bold font_family_pt"><?php echo $settings['title5'];?></h2>
                </div>
				<?php endif; ?>
                <div class="tabs-box">
                    <div class="tab-btn-box p_relative d_block mb_40 centred">
                        <ul class="tab-btns tab-buttons clearfix p_relative d_iblock">
                            <li class="tab-btn" data-tab="#tab-1"><?php echo $settings['tab_bttn'];?></li>
                            <li class="tab-btn" data-tab="#tab-2"><?php echo $settings['tab_bttn1'];?></li>
                            <li class="tab-btn active-btn" data-tab="#tab-3"><?php echo $settings['tab_bttn2'];?></li>
                            <li class="tab-btn" data-tab="#tab-4"><?php echo $settings['tab_bttn3'];?></li>
                            <li class="tab-btn" data-tab="#tab-5"><?php echo $settings['tab_bttn4'];?></li>
                        </ul>
                    </div>
                    <div class="tabs-content">
                        <div class="tab" id="tab-1">
                            <div class="row align-items-center clearfix">
                                <div class="col-lg-6 col-md-12 col-sm-12 image-column">
                                    <div class="image-box-one p_relative d_block pr_30">
                                        <div class="shape">
											<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                                            <div class="shape-1 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
											<?php else :?>	
											<div class="noimage">
											<?php endif;?>
											</div>
											<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                                            <div class="shape-2 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
											<?php else :?>	
											<div class="noimage">
											<?php endif;?>
											</div>
                                        </div>
                                        <figure class="image p_relative d_block">
											<?php  if ( esc_url($settings['image']['id']) ) : ?>   
											<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
											<?php else :?>
											<div class="noimage"></div>
											<?php endif;?>
										</figure>
                                    </div>
                                </div>
                                <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                                    <div class="content-box p_relative d_block pl_30">
                                        <h2 class="d_block fs_35 lh_45 fw_bold font_family_pt mb_20"><?php echo $settings['title'];?></h2>
                                        <p class="font_family_poppins mb_25"><?php echo $settings['text'];?></p>
                                        <p class="font_family_poppins mb_35"><?php echo $settings['text1'];?></p>
										<?php if($settings['bttn']): ?>
                                        <a href="<?php echo esc_url($settings['btnlink']['url']);?>" class="theme-btn"><?php echo $settings['bttn'];?></a>
										<?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="tab" id="tab-2">
                            <div class="row align-items-center clearfix">
                                <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                                    <div class="content_block_13">
                                        <div class="content-box p_relative d_block pr_70">
                                            <h2 class="d_block fs_35 lh_45 fw_bold font_family_pt mb_25"><?php echo $settings['title1'];?></h2>
                                            <p class="font_family_poppins mb_15"><?php echo $settings['text2'];?></p>
                                            <ul class="list clearfix p_relative d_block mb_30">
												<?php foreach($settings['repeat'] as $item):?>
                                                <li class="p_relative fs_18 fw_medium font_family_spartan pull-left pl_25 mb_5"><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
												<?php endforeach; ?>
                                            </ul>
											<?php if($settings['bttn1']): ?>
                                            <a href="<?php echo esc_url($settings['btnlink1']['url']);?>" class="theme-btn"><?php echo $settings['bttn1'];?></a>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-6 col-md-12 col-sm-12 image-column">
                                    <div class="image-box-one p_relative d_block ml_30">
                                        <div class="shape">
											<?php  if ( esc_url($settings['bgimg2']['id']) ) : ?>
                                            <div class="shape-1 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg2']['id']);?>);">
											<?php else :?>	
											<div class="noimage">
											<?php endif;?>
											</div>
											<?php  if ( esc_url($settings['bgimg3']['id']) ) : ?>
                                            <div class="shape-2 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg3']['id']);?>);">
											<?php else :?>	
											<div class="noimage">
											<?php endif;?>
											</div>
                                        </div>
                                        <figure class="image p_relative d_block">
											<?php  if ( esc_url($settings['image1']['id']) ) : ?>   
											<img src="<?php echo wp_get_attachment_url($settings['image1']['id']);?>" alt="<?php echo esc_attr($settings['alt_text1']);?>"/>
											<?php else :?>
											<div class="noimage"></div>
											<?php endif;?>
										</figure>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="tab active-tab" id="tab-3">
                            <div class="row align-items-center clearfix">
                                <div class="col-lg-6 col-md-12 col-sm-12 image-column">
                                    <div class="image-box-one p_relative d_block pr_35">
                                        <div class="shape">
											<?php  if ( esc_url($settings['bgimg4']['id']) ) : ?>
                                            <div class="shape-1 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg4']['id']);?>);">
											<?php else :?>	
											<div class="noimage">
											<?php endif;?>
											</div>
											<?php  if ( esc_url($settings['bgimg5']['id']) ) : ?>
                                            <div class="shape-2 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg5']['id']);?>);">
											<?php else :?>	
											<div class="noimage">
											<?php endif;?>
											</div>
                                        </div>
                                        <div class="row clearfix">
                                            <div class="col-lg-8 col-md-12 col-sm-12 single-image">
                                                <figure class="image p_relative d_block">
													<?php  if ( esc_url($settings['image2']['id']) ) : ?>   
													<img src="<?php echo wp_get_attachment_url($settings['image2']['id']);?>" alt="<?php echo esc_attr($settings['alt_text2']);?>"/>
													<?php else :?>
													<div class="noimage"></div>
													<?php endif;?>
												</figure>
                                            </div>
                                            <div class="col-lg-4 col-md-12 col-sm-12 single-image">
                                                <figure class="image p_relative d_block mb_30">
													<?php  if ( esc_url($settings['image3']['id']) ) : ?>   
													<img src="<?php echo wp_get_attachment_url($settings['image3']['id']);?>" alt="<?php echo esc_attr($settings['alt_text3']);?>"/>
													<?php else :?>
													<div class="noimage"></div>
													<?php endif;?>
												</figure>
												
                                                <figure class="image p_relative d_block">
													<?php  if ( esc_url($settings['image4']['id']) ) : ?>   
													<img src="<?php echo wp_get_attachment_url($settings['image4']['id']);?>" alt="<?php echo esc_attr($settings['alt_text4']);?>"/>
													<?php else :?>
													<div class="noimage"></div>
													<?php endif;?>
												</figure>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                                    <div class="content-box p_relative d_block pl_30">
                                        <h2 class="d_block fs_35 lh_45 fw_bold font_family_pt mb_20"><?php echo $settings['title2'];?></h2>
                                        <p class="font_family_poppins mb_25"><?php echo $settings['text3'];?></p>
                                        <ul class="list clearfix p_relative d_block mb_30">
										
											<?php foreach($settings['repeat1'] as $item):?>
										
                                            <li class="p_relative d_block fs_18 fw_medium font_family_spartan pl_25 mb_5"><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
											
											<?php endforeach; ?>
											
                                        </ul>
										<?php if($settings['bttn2']): ?>
                                        <a href="<?php echo esc_url($settings['btnlink2']['url']);?>" class="theme-btn"><?php echo $settings['bttn2'];?></a>
										<?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="tab" id="tab-4">
                            <div class="row align-items-center clearfix">
                                <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                                    <div class="content-box p_relative d_block pr_30">
                                        <h2 class="d_block fs_35 lh_45 fw_bold font_family_pt mb_20"><?php echo $settings['title3'];?></h2>
                                        <p class="font_family_poppins mb_25"><?php echo $settings['text4'];?></p>
                                        <ul class="list clearfix p_relative d_block">
										
											<?php foreach($settings['repeat2'] as $item):?>
										
                                            <li class="p_relative d_block fs_16 fw_medium font_family_spartan pl_25 mb_5"><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
											
											<?php endforeach; ?>
											
                                        </ul>
                                    </div>
                                </div>
                                <div class="col-lg-6 col-md-12 col-sm-12 image-column">
                                    <div class="image-box-one p_relative d_block ml_30">
                                        <div class="shape">
											<?php  if ( esc_url($settings['bgimg6']['id']) ) : ?>
                                            <div class="shape-1 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg6']['id']);?>);">
											<?php else :?>	
											<div class="noimage">
											<?php endif;?>
											</div>
											<?php  if ( esc_url($settings['bgimg7']['id']) ) : ?>
                                            <div class="shape-2 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg7']['id']);?>);">
											<?php else :?>	
											<div class="noimage">
											<?php endif;?>
											</div>
                                        </div>
                                        <div class="row clearfix">
                                            <div class="col-lg-8 col-md-12 col-sm-12 single-image">
                                                <figure class="image p_relative d_block">
													<?php  if ( esc_url($settings['image5']['id']) ) : ?>   
													<img src="<?php echo wp_get_attachment_url($settings['image5']['id']);?>" alt="<?php echo esc_attr($settings['alt_text5']);?>"/>
													<?php else :?>
													<div class="noimage"></div>
													<?php endif;?>
												</figure>
                                            </div>
                                            <div class="col-lg-4 col-md-12 col-sm-12 single-image">
                                                <figure class="image p_relative d_block">
													<?php  if ( esc_url($settings['image6']['id']) ) : ?>   
													<img src="<?php echo wp_get_attachment_url($settings['image6']['id']);?>" alt="<?php echo esc_attr($settings['alt_text6']);?>"/>
													<?php else :?>
													<div class="noimage"></div>
													<?php endif;?>
												</figure>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="tab" id="tab-5">
                            <div class="row align-items-center clearfix">
                                <div class="col-lg-6 col-md-12 col-sm-12 image-column">
                                    <div class="image-box-one p_relative d_block mr_30 pr_110 pb_60">
                                        <div class="shape">
											<?php  if ( esc_url($settings['bgimg8']['id']) ) : ?>
                                            <div class="shape-1 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg8']['id']);?>);">
											<?php else :?>	
											<div class="noimage">
											<?php endif;?>
											</div>
											<?php  if ( esc_url($settings['bgimg9']['id']) ) : ?>
                                            <div class="shape-2 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg9']['id']);?>);">
											<?php else :?>	
											<div class="noimage">
											<?php endif;?>
											</div>
                                        </div>
										
                                        <figure class="image p_relative d_block">
											<?php  if ( esc_url($settings['image7']['id']) ) : ?>   
											<img src="<?php echo wp_get_attachment_url($settings['image7']['id']);?>" alt="<?php echo esc_attr($settings['alt_text7']);?>"/>
											<?php else :?>
											<div class="noimage"></div>
											<?php endif;?>
										</figure>
										
                                        <figure class="image p_absolute r_0 b_0">
											<?php  if ( esc_url($settings['image8']['id']) ) : ?>   
											<img src="<?php echo wp_get_attachment_url($settings['image8']['id']);?>" alt="<?php echo esc_attr($settings['alt_text8']);?>"/>
											<?php else :?>
											<div class="noimage"></div>
											<?php endif;?>
										</figure>
										
                                    </div>
                                </div>
                                <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                                    <div class="content_block_13">
                                        <div class="content-box p_relative d_block pr_70">
                                            <h2 class="d_block fs_35 lh_45 fw_bold font_family_pt mb_25"><?php echo $settings['title4'];?></h2>
                                            <p class="font_family_poppins mb_15"><?php echo $settings['text5'];?></p>
                                            <ul class="list clearfix p_relative d_block mb_30">
											
												<?php foreach($settings['repeat3'] as $item):?>
												
                                                <li class="p_relative fs_18 fw_medium font_family_spartan pull-left pl_25 mb_5"><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
												
												<?php endforeach; ?>
												
                                            </ul>
											<?php if($settings['bttn3']): ?>
                                            <a href="<?php echo esc_url($settings['btnlink3']['url']);?>" class="theme-btn"><?php echo $settings['bttn3'];?></a>
											<?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		

             
		<?php 
	}

}