<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Service_Tab2 extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_service_tab2';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service Tab 2', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'service_tab2',
			[
				'label' => esc_html__( 'Service Tab 2', 'tranzix' ),
			]
		);
		$this->add_control(
			'bgimg',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();

		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Tab Block One', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'bttn',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);	
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_column',
									'label'   => esc_html__( 'Column', 'rashid' ),
									'type'    => Controls_Manager::NUMBER,
									'default' => 2,
									'min'     => 1,
									'max'     => 12,
									'step'    => 1,
								],
								[
									'name' => 'block_image',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_alt_text',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_icons',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::SELECT,
									'options'  => get_fontawesome_icons(),
								],
								[
									'name' => 'block_image1',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_alt_text1',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_button',
									'label'       => __( 'Button', 'rashid' ),
									'type'        => Controls_Manager::TEXT,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Button Title', 'rashid' ),
								],
								[
									'name' => 'block_btnlink',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									'url' => '',
									'is_external' => true,
									'nof
									ollow' => true,
									],
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();			
		
		$this->start_controls_section(
					'content_section1',
					[
						'label' => __( 'Tab Block Two', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'bttn1',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);	
				$this->add_control(
				  'repeat1', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_column',
									'label'   => esc_html__( 'Column', 'rashid' ),
									'type'    => Controls_Manager::NUMBER,
									'default' => 2,
									'min'     => 1,
									'max'     => 12,
									'step'    => 1,
								],
								[
									'name' => 'block_image',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_alt_text',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_icons',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::SELECT,
									'options'  => get_fontawesome_icons(),
								],
								[
									'name' => 'block_image1',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_alt_text1',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_button',
									'label'       => __( 'Button', 'rashid' ),
									'type'        => Controls_Manager::TEXT,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Button Title', 'rashid' ),
								],
								[
									'name' => 'block_btnlink',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									'url' => '',
									'is_external' => true,
									'nof
									ollow' => true,
									],
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		
		<section class="service-16 p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
            <div class="bg-layer" data-parallax='{"y": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title-11 p_relative d_block mb_40 centred">
                    <h5 class="d_block fs_17 fw_medium font_family_inter lh_28 mb_8 uppercase"><?php echo $settings['subtitle'];?></h5>
                    <h2 class="d_block fs_40 lh_50 fw_bold font_family_inter"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="tabs-box">
                    <div class="tab-btn-box p_relative d_block mb_50">
                        <ul class="tab-btns tab-buttons clearfix p_relative">
							<?php if($settings['bttn']): ?>
                            <li class="tab-btn active-btn" data-tab="#tab-4"><?php echo $settings['bttn'];?></li>
							<?php endif; ?>
							<?php if($settings['bttn1']): ?>
                            <li class="tab-btn" data-tab="#tab-5"><?php echo $settings['bttn1'];?></li>
							<?php endif; ?>
                        </ul>
                    </div>
                    <div class="tabs-content">
                        <div class="tab active-tab" id="tab-4">
                            <div class="content-inner">
                                <div class="row clearfix">
								
									<?php foreach($settings['repeat'] as $item):?>
								
                                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 service-block">
                                        <div class="service-block-13">
                                            <div class="inner-box p_relative d_block b_shadow_6 b_radius_10">
                                                <figure class="image-box p_relative d_block">
													<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
													<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
													<?php else :?>
													<div class="noimage"></div>
													<?php endif;?>
												</figure>
                                                <div class="lower-content p_relative pl_40 pr_30 pb_35 pt_35">
                                                    <div class="icon-box p_absolute l_40 d_iblock w_80 h_80 lh_80 d_iblock fs_40 centred b_radius_50 z_1 tran_5">
                                                        <div class="icon"><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']));?>"></i></div>
                                                        <div class="icon-img hidden-icon">
															<?php if(wp_get_attachment_url($item['block_image1']['id'])): ?>
															<img src="<?php echo wp_get_attachment_url($item['block_image1']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text1'], $allowed_tags);?>">
															<?php else :?>
															<div class="noimage"></div>
															<?php endif;?>
														</div>
                                                    </div>
                                                    <h3 class="d_block fs_24 lh_30 fw_sbold font_family_inter mb_16">
													<a href="<?php echo esc_url($item['block_btnlink']['url']);?>" class="d_iblock color_black"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a>
													</h3>
                                                    <p class="fs_16 font_family_poppins mb_12"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
													<?php if(wp_kses($item['block_button'], $allowed_tags)): ?>
                                                    <div class="link"><a href="<?php echo esc_url($item['block_btnlink']['url']);?>" class="d_iblock fs_15 fw_sbold font_family_poppins color_black"><?php echo wp_kses($item['block_button'], $allowed_tags);?><i class="icon-4"></i></a></div>
													<?php endif; ?>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
									
									<?php endforeach; ?>
									
                                </div>
                            </div>
                        </div>
                        <div class="tab" id="tab-5">
                            <div class="content-inner">
                                <div class="row clearfix">
								
                                    <?php foreach($settings['repeat1'] as $item):?>
								
                                    <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 service-block">
                                        <div class="service-block-13">
                                            <div class="inner-box p_relative d_block b_shadow_6 b_radius_10">
                                                <figure class="image-box p_relative d_block">
													<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
													<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
													<?php else :?>
													<div class="noimage"></div>
													<?php endif;?>
												</figure>
                                                <div class="lower-content p_relative pl_40 pr_30 pb_35 pt_35">
                                                    <div class="icon-box p_absolute l_40 d_iblock w_80 h_80 lh_80 d_iblock fs_40 centred b_radius_50 z_1 tran_5">
                                                        <div class="icon"><i class="icon-124"></i></div>
                                                        <div class="icon-img hidden-icon">
															<?php if(wp_get_attachment_url($item['block_image1']['id'])): ?>
															<img src="<?php echo wp_get_attachment_url($item['block_image1']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text1'], $allowed_tags);?>">
															<?php else :?>
															<div class="noimage"></div>
															<?php endif;?>
														</div>
                                                    </div>
                                                    <h3 class="d_block fs_24 lh_30 fw_sbold font_family_inter mb_16">
													<a href="<?php echo esc_url($item['block_btnlink']['url']);?>" class="d_iblock color_black"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a>
													</h3>
                                                    <p class="fs_16 font_family_poppins mb_12"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
													<?php if(wp_kses($item['block_button'], $allowed_tags)): ?>
                                                    <div class="link"><a href="<?php echo esc_url($item['block_btnlink']['url']);?>" class="d_iblock fs_15 fw_sbold font_family_poppins color_black"><?php echo wp_kses($item['block_button'], $allowed_tags);?><i class="icon-4"></i></a></div>
													<?php endif; ?>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
									
									<?php endforeach; ?>
									
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>

             
		<?php 
	}

}