<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Service_Tab3 extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_service_tab3';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service Tab 3', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'service_tab3',
			[
				'label' => esc_html__( 'Service Tab 3', 'tranzix' ),
			]
		);
		$this->add_control(
			'bgimg',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'bgimg1',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'bgimg2',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();

		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Tab Block One', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'bttn',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);	
				$this->add_control(
					'image',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'title1',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'text1',
					[
						'label'       => __( 'Description Text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();			
		
		$this->start_controls_section(
					'content_section1',
					[
						'label' => __( 'Tab Block Two', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'bttn1',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);	
				$this->add_control(
					'title2',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'text2',
					[
						'label'       => __( 'Description Text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'text3',
					[
						'label'       => __( 'Description Text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
				  'repeat1', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
				);
				$this->add_control(
				  'repeat2', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
				);
				
				
		$this->end_controls_section();	
		
		$this->start_controls_section(
					'content_section2',
					[
						'label' => __( 'Tab Block Three', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'bttn2',
					[
						'label'       => __( 'Button', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);	
				$this->add_control(
					'title3',
					[
						'label'       => __( 'Title', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'text4',
					[
						'label'       => __( 'Description Text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'bgimg3',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg4',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'image1',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text1',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'image2',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text2',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
				  'repeat3', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
				);
				
				
		$this->end_controls_section();	
		
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
        <section class="service-17 p_relative <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
            <div class="bg-layer" data-parallax='{"y": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
            <div class="image-shape">
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                <div class="shape-1 p_absolute l_80 t_80 float-bob-y" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg2']['id']) ) : ?>
                <div class="shape-2 p_absolute b_0 float-bob-y" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg2']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title-11 p_relative d_block mb_50 centred">
                    <h5 class="d_block fs_17 fw_medium font_family_inter lh_28 mb_8 uppercase"><?php echo $settings['subtitle'];?></h5><br />
                    <h2 class="d_block fs_40 lh_50 fw_bold font_family_inter"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="tabs-box">
                    <div class="tab-btn-box p_relative d_block mb_70">
                        <ul class="tab-btns tab-buttons clearfix p_relative">
                            <li class="tab-btn active-btn" data-tab="#tab-6"><i class="icon-127"></i><?php echo $settings['bttn'];?></li>
                            <li class="tab-btn" data-tab="#tab-7"><i class="icon-128"></i><?php echo $settings['bttn1'];?></li>
                            <li class="tab-btn" data-tab="#tab-8"><i class="icon-129"></i><?php echo $settings['bttn2'];?></li>
                        </ul>
                    </div>
                    <div class="tabs-content">
                        <div class="tab active-tab" id="tab-6">
                            <div class="content-inner">
                                <div class="row clearfix">
                                    <div class="col-lg-6 col-md-12 col-sm-12 image-column">
                                        <div class="image-box p_relative d_block mr_30">
                                            <figure class="image image-1 p_relative d_block">
												<?php  if ( esc_url($settings['image']['id']) ) : ?>   
												<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
												<?php else :?>
												<div class="noimage"></div>
												<?php endif;?>
											</figure>
                                        </div>
                                    </div>
                                    <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                                        <div class="content_block_20">
                                            <div class="content-box p_relative d_block ml_30">
                                                <h3 class="fs_24 fw_sbold font_family_inter lh_30 mb_20"><?php echo $settings['title1'];?></h3>
                                                <p class="fs_16 font_family_poppins mb_25"><?php echo $settings['text1'];?></p>
                                                <ul class="list clearfix">
													<?php foreach($settings['repeat'] as $item):?>
                                                    <li class="p_relative d_block fs_15 fw_medium font_family_inter pl_25 pull-left mb_10"><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="tab" id="tab-7">
                            <div class="content-inner">
                                <div class="content_block_20">
                                    <div class="content-box">
                                        <div class="row clearfix">
                                            <div class="col-lg-6 col-md-12 col-sm-12 text-column">
                                                <div class="text">
                                                    <h3 class="fs_24 fw_sbold font_family_inter lh_30 mb_20"><?php echo $settings['title2'];?></h3>
                                                    <p class="fs_16 font_family_poppins mb_25"><?php echo $settings['text2'];?></p>
                                                    <p class="fs_16 font_family_poppins"><?php echo $settings['text3'];?></p>
                                                </div>
                                            </div>
                                            <div class="col-lg-3 col-md-6 col-sm-12 list-column">
                                                <ul class="list clearfix">
													<?php foreach($settings['repeat1'] as $item):?>
                                                    <li class="p_relative d_block fs_15 fw_medium font_family_inter pl_25 mb_10"><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
                                            <div class="col-lg-3 col-md-6 col-sm-12 list-column">
                                                <ul class="list clearfix">
													<?php foreach($settings['repeat2'] as $item):?>
                                                    <li class="p_relative d_block fs_15 fw_medium font_family_inter pl_25 mb_10"><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="tab" id="tab-8">
                            <div class="content-inner">
                                <div class="row clearfix">
                                    <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                                        <div class="content_block_20">
                                            <div class="content-box">
                                                <h3 class="fs_24 fw_sbold font_family_inter lh_30 mb_20"><?php echo $settings['title3'];?></h3>
                                                <p class="fs_16 font_family_poppins mb_25"><?php echo $settings['text4'];?></p>
                                                <ul class="list clearfix">
                                                    <?php foreach($settings['repeat3'] as $item):?>
                                                    <li class="p_relative d_block fs_15 fw_medium font_family_inter pl_25 pull-left mb_10"><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
													<?php endforeach; ?>
                                                </ul>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-lg-6 col-md-12 col-sm-12 image-column">
                                        <div class="image-box p_relative d_block ml_40 pl_180 pb_70">
                                            <div class="shape">
												<?php  if ( esc_url($settings['bgimg3']['id']) ) : ?>
                                                <div class="shape-1 rotate-me p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg3']['id']);?>);">
												<?php else :?>	
												<div class="noimage">
												<?php endif;?>
												</div>
												<?php  if ( esc_url($settings['bgimg4']['id']) ) : ?>
                                                <div class="shape-2 rotate-me p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg4']['id']);?>);">
												<?php else :?>	
												<div class="noimage">
												<?php endif;?>
												</div>
                                            </div>
                                            <figure class="image image-2 p_relative d_block b_radius_10">
												<?php  if ( esc_url($settings['image1']['id']) ) : ?>   
												<img src="<?php echo wp_get_attachment_url($settings['image1']['id']);?>" alt="<?php echo esc_attr($settings['alt_text1']);?>"/>
												<?php else :?>
												<div class="noimage"></div>
												<?php endif;?>
											</figure>
                                            <figure class="image image-3 p_absolute l_0 b_0 b_radius_10">
												<?php  if ( esc_url($settings['image2']['id']) ) : ?>   
												<img src="<?php echo wp_get_attachment_url($settings['image2']['id']);?>" alt="<?php echo esc_attr($settings['alt_text2']);?>"/>
												<?php else :?>
												<div class="noimage"></div>
												<?php endif;?>
											</figure>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>

             
		<?php 
	}

}