<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Skills extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_skills';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Skills', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'skills',
			[
				'label' => esc_html__( 'Skills', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Choose Style 1', 'tranzix' ),
						'style2' => esc_html__( 'Choose Style 2', 'tranzix' ),
						'style3' => esc_html__( 'Choose Style 3', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'bgimg',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
					),
				),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'bgimg1',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
					),
				),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Skill Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'ff_stop',
									'label' => esc_html__('Counter Stop', 'rashid'),
									'type' => Controls_Manager::TEXT,
									'default' => esc_html__('', 'hekim')
								],
								[
									'name' => 'ff_sing',
									'label' => esc_html__('Counter Sing', 'rashid'),
									'type' => Controls_Manager::TEXT,
									'default' => esc_html__('', 'hekim')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		<?php  if ( 'style1' === $settings['style'] ) : ?>
		
        <section class="skills-three p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="outer-container p_relative pt_140 pb_150">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="pattern-layer p_absolute l_0 t_0 r_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
                <div class="auto-container">
                    <div class="row clearfix">
						<?php if($settings['title']): ?>
                        <div class="col-lg-6 col-md-12 col-sm-12 title-column">
                            <div class="sec-title p_relative d_block mr_30 wow slideInLeft animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                                <h5 class="d_block fs_18 lh_20 uppercase mb_12 fw_sbold font_family_poppins"><?php echo $settings['subtitle'];?></h5>
                                <h2 class="d_block fs_50 lh_55 fw_medium font_family_frank mb_20"><?php echo $settings['title'];?></h2>
                                <p class="font_family_oxygen lh_30"><?php echo $settings['text'];?></p>
                            </div>
                        </div>
						<?php endif; ?>
                        <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                            <div class="content_block_three wow slideInRight animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                                <div class="content-box p_relative d_block ml_30">
                                    <div class="progress-inner p_relative d_block">
									
										<?php foreach($settings['repeat'] as $item):?>
									
                                        <div class="progress-box p_relative d_block mb_30">
                                            <h6 class="d_block fs_18 lh_20 mb_7 font_family_oxygen"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                            <div class="bar">
                                                <div class="bar-inner count-bar" data-percent="<?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?>"></div>
                                                <div class="count-text p_absolute r_0 b_10 fs_16 font_family_oxygen"><?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?></div>
                                            </div>
                                        </div>
										
										<?php endforeach; ?>
										
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<section class="skills-two about-page-1 p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
            <div class="pattern-layer p_absolute l_60 rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
            <div class="auto-container">
                <div class="row align-items-center clearfix">
                    <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                        <div class="content_block_24">
                            <div class="content-box">
                                <div class="sec-title-three p_relative d_block">
                                    <h6 class="d_block fs_18 lh_26 fw_sbold font_family_inter uppercase mb_12"><?php echo $settings['subtitle'];?></h6>
                                    <h2 class="d_block fs_50 fw_bold font_family_inter mb_20"><?php echo $settings['title'];?></h2>
                                    <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                        <div class="content_block_three">
                            <div class="content-box p_relative d_block">
                                <div class="progress-inner p_relative d_block">
								
									<?php foreach($settings['repeat'] as $item):?>
								
                                    <div class="progress-box p_relative d_block mb_30">
                                        <h6 class="d_block fs_18 lh_20 mb_7 font_family_poppins"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                        <div class="bar">
                                            <div class="bar-inner count-bar" data-percent="<?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?>"></div>
                                            <div class="count-text p_absolute r_0 b_10 fs_16 font_family_poppins"><?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?></div>
                                        </div>
                                    </div>
									
									<?php endforeach; ?>
									
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
		<section class="skills-two about-page-2 p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="pattern-layer">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div class="pattern-1 p_absolute b_0" data-parallax='{"x": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                <div class="pattern-2 p_absolute t_0 r_0" data-parallax='{"x": 100}' style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
            <div class="auto-container">
                <div class="row align-items-center clearfix">
                    <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                        <div class="content_block_24">
                            <div class="content-box">
                                <div class="sec-title-12 p_relative d_block">
                                    <h5 class="d_block fs_18 lh_26 fw_sbold font_family_inter uppercase mb_12"><?php echo $settings['subtitle'];?></h5>
                                    <h2 class="d_block fs_50 lh_50 fw_bold font_family_inter mb_25"><?php echo $settings['title'];?></h2>
                                    <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6 col-md-12 col-sm-12 content-column">
                        <div class="content_block_three">
                            <div class="content-box p_relative d_block">
                                <div class="progress-inner p_relative d_block">
								
									<?php foreach($settings['repeat'] as $item):?>
								
                                    <div class="progress-box p_relative d_block mb_25">
                                        <h6 class="d_block fs_18 lh_20 mb_12 font_family_poppins"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                        <div class="bar">
                                            <div class="bar-inner count-bar" data-percent="<?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?>"><div class="count-text p_absolute r_0 b_15 fs_16 font_family_poppins"><?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?></div></div>
                                        </div>
                                    </div>
									
									<?php endforeach; ?>
									
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
             
		<?php 
	}

}