<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Subscribe extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_subscribe';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Subscribe', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'subscribe',
			[
				'label' => esc_html__( 'Subscribe', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Choose Style 1', 'tranzix' ),
						'style2' => esc_html__( 'Choose Style 2', 'tranzix' ),
						'style3' => esc_html__( 'Choose Style 3', 'tranzix' ),
						'style4' => esc_html__( 'Choose Style 4', 'tranzix' ),
						'style5' => esc_html__( 'Choose Style 5', 'tranzix' ),
						'style6' => esc_html__( 'Choose Style 6', 'tranzix' ),
						'style7' => esc_html__( 'Choose Style 7', 'tranzix' ),
						'style8' => esc_html__( 'Choose Style 8', 'tranzix' ),
						'style9' => esc_html__( 'Choose Style 9', 'tranzix' ),
						'style10' => esc_html__( 'Choose Style 10', 'tranzix' ),
						'style11' => esc_html__( 'Choose Style 11', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Subscribe Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'bgimg',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style8',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style11',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg1',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'image',
						[
						  'label' => __( 'Image', 'rashid' ),
						  'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
							),
						 ),
						  'type' => Controls_Manager::MEDIA,
						  'default' => ['url' => Utils::get_placeholder_image_src(),],
						]
				);
				$this->add_control(
					'alt_text',
					[
						'label'       => __( 'Alt text', 'rashid' ),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
							),
						),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Description', 'rashid' ),
					]
				);
				$this->add_control(
					'title',
					[
						'label'       => __( 'Title', 'rashid' ),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style8',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style11',
								),
							),
						),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'news_letter_id',
					[
						'label'       => __( 'FeedBurner ID', 'rashid' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your FeedBurner ID', 'rashid' ),
						'default'     => __( 'themeforest', 'rashid' ),
					]
				);
				$this->add_control(
					'email_title',
					[
						'label'       => __( 'Title', 'rashid' ),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style8',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style11',
								),
							),
						),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your title', 'rashid' ),
					]
				);
				$this->add_control(
					'bttn',
					[
						'label'       => __( 'Button', 'rashid' ),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style8',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style9',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style11',
								),
							),
						),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Button Title', 'rashid' ),
					]
				);	
				
				
		$this->end_controls_section();	
		

	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		<?php  if ( 'style1' === $settings['style'] ) : ?>
		
        <section class="subscribe-one p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div>
                <svg class="waves" viewBox="0 24 150 28" preserveAspectRatio="none" shape-rendering="auto">
                    <defs>
                        <path id="gentle-wave" d="M-160 44c30 0 58-18 88-18s 58 18 88 18 58-18 88-18 58 18 88 18 v44h-352z" />
                    </defs>
                    <g class="parallax">
                    <use xlink:href="#gentle-wave" x="48" y="0" fill="rgba(247,247,247,0.7" />
                    <use xlink:href="#gentle-wave" x="48" y="3" fill="rgba(247,247,247,0.5)" />
                    <use xlink:href="#gentle-wave" x="48" y="5" fill="rgba(247,247,247,0.3)" />
                    <use xlink:href="#gentle-wave" x="48" y="7" fill="#f7f7f7" />
                    </g>
                </svg>
            </div>
            <div class="auto-container">
                <div class="inner-container p_relative d_block pl_100 pt_60 pr_100 pb_60 b_radius_5">
                    <div class="pattern-layer">
						<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                        <div class="pattern-1 p_absolute l_0 b_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
						<?php else :?>	
						<div class="noimage">
						<?php endif;?>
						</div>
						<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                        <div class="pattern-2 p_absolute t_0 r_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
						<?php else :?>	
						<div class="noimage">
						<?php endif;?>
						</div>
                    </div>
                    <div class="row clearfix">
                        <div class="col-lg-6 col-md-12 col-sm-12 text-column">
                            <div class="text p_relative d_block mr_30">
                                <h2 class="d_block fs_30 lh_40 fw_bold font_family_oxygen"><?php echo $settings['title'];?></h2>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12 form-column">
                            <div class="form-inner p_relative d_block mt_18">
								<form class="subscribe-form default-form" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
									<div class="form-group">
										<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
										
										<?php if($settings['email_title']): ?>
										<input type="email" name="email" placeholder="<?php echo $settings['email_title'];?>" required="">
										<?php endif; ?>
										<?php if($settings['bttn']): ?>
                                        <button type="submit" class="theme-btn"><?php echo $settings['bttn'];?><span><?php echo $settings['bttn'];?></span></button>
										<?php endif; ?>
									</div>
								</form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<section class="subscribe-two p_relative bg-color-2 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="inner-container p_relative d_block pl_100 pt_85 pr_100 pb_85 b_radius_10 z_1">
					<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                    <div class="pattern-layer p_absolute l_0 t_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
					<?php else :?>	
					<div class="noimage">
					<?php endif;?>
					</div>
                    <div class="row clearfix">
                        <div class="col-lg-6 col-md-12 col-sm-12 text-column">
                            <div class="text p_relative d_block mr_30">
                                <h2 class="d_block fs_30 lh_40 fw_bold font_family_spartan"><?php echo $settings['title'];?></h2>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12 form-column">
                            <div class="form-inner p_relative d_block mt_15">
							
								<form class="subscribe-form default-form" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
                                    <div class="form-group">
										<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
										<?php if($settings['email_title']): ?>
                                        <input type="email" name="email" placeholder="<?php echo $settings['email_title'];?>" required="">
										<?php endif; ?>
										<?php if($settings['bttn']): ?>
                                        <button type="submit" class="theme-btn theme-btn-seven"><?php echo $settings['bttn'];?></button>
										<?php endif; ?>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
		<section class="subscribe-three p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="inner-container p_relative d_block pl_100 pt_60 pr_100 pb_60 z_1">
					<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                    <div class="pattern-layer p_absolute l_0 t_0 r_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
					<?php else :?>	
					<div class="noimage">
					<?php endif;?>
					</div>
                    <div class="row clearfix">
                        <div class="col-lg-6 col-md-12 col-sm-12 text-column">
                            <div class="text p_relative d_block mr_30">
                                <h2 class="d_block fs_40 lh_40 fw_medium font_family_frank"><?php echo $settings['title'];?></h2>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12 form-column">
                            <div class="form-inner p_relative d_block mt_10">
								<form class="subscribe-form default-form" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
                                    <div class="form-group">
										<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
										<?php if($settings['email_title']): ?>
                                        <input type="email" name="email" placeholder="<?php echo $settings['email_title'];?>" required="">
										<?php endif; ?>
										<?php if($settings['bttn']): ?>
                                        <button type="submit" class="theme-btn theme-btn-five"><?php echo $settings['bttn'];?></button>
										<?php endif; ?>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style4' === $settings['style'] ) : ?>
		
		<section class="subscribe-four p_relative pt_35 pb_35 <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
            <div class="pattern-layer p_absolute l_0 t_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-6 col-md-12 col-sm-12 text-column">
                        <div class="text p_relative d_block mr_30 pl_100">
                            <div class="icon p_absolute l_0 t_0">
								<?php  if ( esc_url($settings['image']['id']) ) : ?>   
								<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
								<?php else :?>
								<div class="noimage"></div>
								<?php endif;?>
							</div>
                            <h2 class="d_block fs_30 lh_35 fw_sbold font_family_jost"><?php echo $settings['title'];?></h2>
                        </div>
                    </div>
                    <div class="col-lg-6 col-md-12 col-sm-12 form-column">
                        <div class="form-inner p_relative d_block mt_5">
							<form class="subscribe-form default-form" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
                                <div class="form-group">
									<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
									<?php if($settings['email_title']): ?>
                                    <input type="email" name="email" placeholder="<?php echo $settings['email_title'];?>" required="">
									<?php endif; ?>
									<?php if($settings['bttn']): ?>
                                    <button type="submit" class="theme-btn theme-btn-eight"><?php echo $settings['bttn'];?></button>
									<?php endif; ?>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style5' === $settings['style'] ) : ?>
		
		<section class="subscribe-one home-14 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="inner-container p_relative d_block pl_100 pt_55 pr_100 pb_55 z_1">
                    <div class="row clearfix">
                        <div class="col-lg-6 col-md-12 col-sm-12 text-column">
                            <div class="text p_relative d_block mr_30">
                                <h2 class="d_block fs_30 lh_60 fw_bold font_family_jost"><?php echo $settings['title'];?></h2>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12 form-column">
                            <div class="form-inner p_relative d_block">
							
							
								<form class="subscribe-form default-form" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
                                    <div class="form-group">
										<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
										
										<?php if($settings['email_title']): ?>
                                        <input type="email" name="email" placeholder="<?php echo $settings['email_title'];?>" required="">
										<?php endif; ?>
										<?php if($settings['bttn']): ?>
                                        <button type="submit" class="theme-btn"><?php echo $settings['bttn'];?></button>
										<?php endif; ?>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style6' === $settings['style'] ) : ?>
		
		<section class="subscribe-one home-15 p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="inner-container p_relative d_block pl_100 pt_60 pr_100 pb_60 z_1 b_radius_10">
					<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                    <div class="shape p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
					<?php else :?>	
					<div class="noimage">
					<?php endif;?>
					</div>
                    <div class="row clearfix">
                        <div class="col-lg-6 col-md-12 col-sm-12 text-column">
                            <div class="text p_relative d_block mr_30">
                                <h2 class="d_block fs_30 lh_40 fw_bold font_family_frank"><?php echo $settings['title'];?></h2>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12 form-column">
                            <div class="form-inner p_relative d_block mt_10">
								<form class="subscribe-form default-form" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
                                    <div class="form-group">
										<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
										<?php if($settings['email_title']): ?>
                                        <input type="email" name="email" placeholder="<?php echo $settings['email_title'];?>" required="">
										<?php endif; ?>
										<?php if($settings['bttn']): ?>
                                        <button type="submit" class="theme-btn theme-btn-seven"><?php echo $settings['bttn'];?> <i class="icon-4"></i></button>
										<?php endif; ?>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style7' === $settings['style'] ) : ?>
		
		<section class="subscribe-one home-16 p_relative pt_30 pb_35 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="inner-container p_relative">
                    <div class="row clearfix">
                        <div class="col-lg-6 col-md-12 col-sm-12 text-column">
                            <div class="text p_relative d_block">
                                <h2 class="d_block fs_30 lh_40 fw_sbold font_family_inter"><?php echo $settings['title'];?></h2>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12 form-column">
                            <div class="form-inner p_relative d_block mt_12">
								<form class="subscribe-form default-form" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
                                    <div class="form-group">
										<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
										<?php if($settings['email_title']): ?>
                                        <input type="email" name="email" placeholder="<?php echo $settings['email_title'];?>" required="">
										<?php endif; ?>
										<?php if($settings['bttn']): ?>
                                        <button type="submit" class="theme-btn theme-btn-eight"><?php echo $settings['bttn'];?> <i class="icon-4"></i></button>
										<?php endif; ?>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style8' === $settings['style'] ) : ?>
		
		<section class="subscribe-five about-page-1 p_relative sec-pad <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
            <div class="shape p_absolute l_0 t_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-8 col-md-12 col-sm-12 inner-column offset-lg-2">
                        <div class="inner-box">
                            <div class="text p_relative d_block mb_40 centred">
                                <h2 class="d_block fs_50 lh_55 fw_bold"><?php echo $settings['title'];?></h2>
                            </div>
                            <div class="form-inner p_relative d_block mt_5">
							
								<form class="subscribe-form default-form p_relative" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
									<?php if($settings['email_title']): ?>
                                    <div class="form-group">
										<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
                                        <input type="email" name="email" placeholder="<?php echo $settings['email_title'];?>" required="">
                                    </div>
									<?php endif; ?>
									<?php if($settings['bttn']): ?>
                                    <div class="message-btn">
                                        <button type="submit" class="theme-btn theme-btn-five"><?php echo $settings['bttn'];?> <i class="icon-4"></i></button>
                                    </div>
									<?php endif; ?>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style9' === $settings['style'] ) : ?>
		
		<section class="subscribe-one home-16 p_relative pt_30 pb_35 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="inner-container p_relative">
                    <div class="row clearfix">
                        <div class="col-lg-6 col-md-12 col-sm-12 text-column">
                            <div data-animation-box class="text p_relative d_block">
                                <h2 data-animation-text class="overlay-anim-white-bg d_block fs_30 lh_40 fw_sbold font_family_inter" data-animation="overlay-animation"><?php echo $settings['title'];?></h2>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12 form-column">
                            <div class="form-inner p_relative d_block mt_12">
								<form class="subscribe-form default-form" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
                                    <div class="form-group">
										<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
										<?php if($settings['email_title']): ?>
                                        <input type="email" name="email" placeholder="<?php echo $settings['email_title'];?>" required="">
										<?php endif; ?>
										<?php if($settings['bttn']): ?>
                                        <button type="submit" class="theme-btn theme-btn-eight"><?php echo $settings['bttn'];?> <i class="icon-4"></i></button>
										<?php endif; ?>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style10' === $settings['style'] ) : ?>
		
		<section class="subscribe-five service-page-1 p_relative sec-pad bg-color-1 <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
            <div class="shape p_absolute l_0 t_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-8 col-md-12 col-sm-12 inner-column offset-lg-2">
                        <div class="inner-box">
                            <div class="text p_relative d_block mb_40 centred">
                                <h2 class="d_block fs_30 lh_40 fw_bold font_family_inter"><?php echo $settings['title'];?></h2>
                            </div>
                            <div class="form-inner p_relative d_block mt_5">
								<form class="subscribe-form default-form p_relative" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
									<?php if($settings['email_title']): ?>
                                    <div class="form-group">
										<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
                                        <input type="email" name="email" placeholder="<?php echo $settings['email_title'];?>" required="">
                                    </div>
									<?php endif; ?>
									<?php if($settings['bttn']): ?>
                                    <div class="message-btn">
                                        <button type="submit" class="theme-btn theme-btn-one"><?php echo $settings['bttn'];?> <i class="icon-4"></i></button>
                                    </div>
									<?php endif; ?>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style11' === $settings['style'] ) : ?>
		
		<section class="subscribe-five service-page-1 service-page-4 p_relative sec-pad bg-color-1 <?php echo esc_attr($settings['sec_class']);?>">
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
            <div class="shape p_absolute l_0 t_0" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
			<?php else :?>	
			<div class="noimage">
			<?php endif;?>
			</div>
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-8 col-md-12 col-sm-12 inner-column offset-lg-2">
                        <div class="inner-box">
                            <div class="text p_relative d_block mb_40 centred">
                                <h2 class="d_block fs_30 lh_40 fw_bold font_family_inter"><?php echo $settings['title'];?></h2>
                            </div>
                            <div class="form-inner p_relative d_block mt_5">
								<form class="subscribe-form default-form p_relative" method="post" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
									<?php if($settings['email_title']): ?>
                                    <div class="form-group">
										<input type="hidden" id="uri2" name="uri" value="<?php echo $settings['news_letter_id'];?>">
                                        <input type="email" name="email" placeholder="<?php echo $settings['email_title'];?>" required="">
                                    </div>
									<?php endif; ?>
									<?php if($settings['bttn']): ?>
                                    <div class="message-btn">
                                        <button type="submit" class="theme-btn theme-btn-one"><?php echo $settings['bttn'];?> <i class="icon-4"></i></button>
                                    </div>
									<?php endif; ?>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
             
		<?php 
	}

}