<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Team_Details3 extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_team_details3';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Team Details 3', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'team_details3',
			[
				'label' => esc_html__( 'Team Details 3', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style2' => esc_html__( 'Choose Style 2', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'title1',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'contact_us_form',
			[
				'label'       => __( 'Contact Form 7 Url', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Contact Form 7 Url', 'rashid' ),
				'default'     => __( '', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Skill Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_column',
									'label'   => esc_html__( 'Column', 'rashid' ),
									'type'    => Controls_Manager::NUMBER,
									'default' => 2,
									'min'     => 1,
									'max'     => 12,
									'step'    => 1,
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'ff_stop',
									'label' => esc_html__('Counter Stop', 'rashid'),
									'type' => Controls_Manager::TEXT,
									'default' => esc_html__('', 'hekim')
								],
								[
									'name' => 'ff_sing',
									'label' => esc_html__('Counter Sing', 'rashid'),
									'type' => Controls_Manager::TEXT,
									'default' => esc_html__('', 'hekim')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();



		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
		<?php  if ( 'style1' === $settings['style'] ) : ?>
		
        <section class="team-details-one p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-sm-12 content-column">
                        <div class="team-details-content p_relative d_block ml_30">
                            <div class="content-two p_relative d_block mb_95">
								<?php if($settings['title']): ?>
                                <div class="text p_relative d_block mb_20">
                                    <h3 class="d_block fs_24 lh_30 fw_sbold mb_16"><?php echo $settings['title'];?></h3>
                                    <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                                </div>
								<?php endif; ?>
                                <div class="progress-inner p_relative d_block">
								
									<?php foreach($settings['repeat'] as $item):?>
								
                                    <div class="progress-box p_relative d_block mb_30">
                                        <h6 class="d_block fs_16 lh_20 mb_6 font_family_poppins color_black"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                        <div class="bar">
                                            <div class="bar-inner count-bar" data-percent="<?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?>"><div class="count-text p_absolute r_0 b_10 fs_16 font_family_poppins color_black"><?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?></div></div>
                                        </div>
                                    </div>
									
									<?php endforeach; ?>
									
                                </div>
                            </div>
                            <div class="content-three p_relative d_block">
                                <div class="text p_relative d_block mb_25">
                                    <h3 class="d_block fs_24 lh_30 fw_sbold"><?php echo $settings['title1'];?></h3>
                                </div>
                                <div class="form-inner">
								
									<?php echo do_shortcode( $settings['contact_us_form'] );?>
								
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<section class="experience-section team-details-2 p_relative bg-color-1 pt_140 pb_150 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-6 col-md-6 col-sm-12 experience-column">
                        <div class="experience-content p_relative d_block mr_30">
							<?php if($settings['title']): ?>
                            <div class="text p_relative d_block mb_20">
                                <h3 class="d_block fs_24 lh_30 mb_16"><?php echo $settings['title'];?></h3>
                                <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                            </div>
							<?php endif; ?>
                            <div class="progress-inner p_relative d_block">
							
								<?php foreach($settings['repeat'] as $item):?>
							
                                <div class="progress-box p_relative d_block mb_30">
                                    <h6 class="d_block fs_16 lh_20 mb_6 font_family_poppins color_black"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h6>
                                    <div class="bar">
                                        <div class="bar-inner count-bar" data-percent="<?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?>"><div class="count-text p_absolute r_0 b_10 fs_16 font_family_poppins color_black"><?php echo esc_attr($item['ff_stop']);?><?php echo esc_attr($item['ff_sing']);?></div></div>
                                    </div>
                                </div>
								
								<?php endforeach; ?>
								
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6 col-md-6 col-sm-12 contact-column">
                        <div class="contact-inner p_relative d_block ml_30">
                            <div class="text p_relative d_block mb_20">
                                <h3 class="d_block fs_24 lh_30"><?php echo $settings['title1'];?></h3>
                            </div>
                            <div class="form-inner">
                                <?php echo do_shortcode( $settings['contact_us_form'] );?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
		<section class="team-details-three p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 content-column">
                        <div class="team-details-content">
                            <div class="content-three">
								<?php if($settings['title']): ?>
                                <div class="text p_relative d_block mb_25">
                                    <h3 class="d_block fs_24 lh_30 mb_16"><?php echo $settings['title'];?></h3>
                                    <p class="font_family_poppins"><?php echo $settings['text'];?></p>
                                </div>
								<?php endif; ?>
                                <div class="image_block_one">
                                    <div class="image-box p_relative d_block">
                                        <div class="skills-box text-center">
                                            <div class="row clearfix">
											
												<?php foreach($settings['repeat'] as $item):?>
											
                                                <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 progress-block">
                                                    <div class="single-progress-box p_relative d_block pt_30 pr_30 pb_30 pl_30 b_shadow_6 b_radius_10">
                                                        <div class="box">
                                                            <div class="piechart_2 p_relative mb_15"  data-fg-color="#6a36ff" data-value=".<?php echo esc_attr($item['ff_stop']);?>">
                                                                <span>.<?php echo esc_attr($item['ff_stop']);?></span>
                                                            </div>
                                                            <h5 class="d_block fs_17 lh_20 fw_sbold mb_0"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h5>
                                                        </div>
                                                    </div>
                                                </div>
												
												<?php endforeach; ?>
												
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
             
		<?php 
	}

}