<?php

namespace TRANZIXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Testimonials extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tranzix_testimonials';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Testimonials', 'tranzix' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tranzix' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'testimonials',
			[
				'label' => esc_html__( 'Testimonials', 'tranzix' ),
			]
		);
		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'tranzix' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Choose Style 1', 'tranzix' ),
						'style2' => esc_html__( 'Choose Style 2', 'tranzix' ),
						'style3' => esc_html__( 'Choose Style 3', 'tranzix' ),
						'style4' => esc_html__( 'Choose Style4', 'tranzix' ),
					),
				]
		);
		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style10',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style12',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style13',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style15',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style16',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style17',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style3',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style4',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style5',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style6',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style7',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style8',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style9',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style10',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style11',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style12',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style13',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style14',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style15',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style16',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style17',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'conditions' => array(
					'relation' => 'or',
					'terms'    => array(
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style1',
						),
						array(
							'name'     => 'style',
							'operator' => '==',
							'value'    => 'style2',
						),
					),
				),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
		
				// New Tab#2

		$this->start_controls_section(
					'content_section2',
					[
						'label' => __( 'Image Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
					'bgimg',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style5',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style6',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style7',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style8',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style11',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style15',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style16',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style17',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg1',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style1',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style2',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style3',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style4',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style8',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style10',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style14',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style15',
								),
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style16',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				$this->add_control(
					'bgimg2',
					[
						'label' => esc_html__('Background image', 'rashid'),
						'conditions' => array(
							'relation' => 'or',
							'terms'    => array(
								array(
									'name'     => 'style',
									'operator' => '==',
									'value'    => 'style15',
								),
							),
						),
						'type' => Controls_Manager::MEDIA,
						'default' => ['url' => Utils::get_placeholder_image_src(),],
					]
				);
				
				
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Testimonials Block', 'rashid' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'rashid')],
							],
						'fields' => 
							[
								[
									'name' => 'block_rating',
									'label'   => esc_html__( 'Select Rating', 'rashid' ),
									'type'    => Controls_Manager::SELECT,
									'default' => '1',
									'options' => array(
										'rat1'   => esc_html__( 'Rating One', 'rashid' ),
										'rat2'   => esc_html__( 'Rating Two', 'rashid' ),
										'rat3'   => esc_html__( 'Rating Three', 'rashid' ),
										'rat4'   => esc_html__( 'Rating Four', 'rashid' ),
										'rat5'   => esc_html__( 'Rating Five', 'rashid' ),
									),
								],
								[
									'name' => 'block_column',
									'label'   => esc_html__( 'Column', 'rashid' ),
									'type'    => Controls_Manager::NUMBER,
									'default' => 2,
									'min'     => 1,
									'max'     => 12,
									'step'    => 1,
								],
								[
									'name' => 'block_bgimg',
									'label' => esc_html__('Background image', 'rashid'),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_bgimg1',
									'label' => esc_html__('Background image', 'rashid'),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_image',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_alt_text',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_image1',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_alt_text1',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_image2',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],
								[
									'name' => 'block_alt_text2',
									'label' => esc_html__('Alt Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								[
									'name' => 'block_subtitle',
									'label' => esc_html__('Subtitle', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
		

	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        
<?php
      echo '
     <script>
 jQuery(document).ready(function($) {

//put the js code under this line 

	if ($(".three-item-carousel").length) {
		$(".three-item-carousel").owlCarousel({
			loop:true,
			margin:30,
			nav:true,
			smartSpeed: 500,
			autoplay: 1000,
			responsive:{
				0:{
					items:1
				},
				480:{
					items:1
				},
				600:{
					items:2
				},
				800:{
					items:2
				},
				1024:{
					items:3
				}
			}
		});    		
	}

//put the code above the line 

  });
</script>';


?>

<?php
      echo '
     <script>
 jQuery(document).ready(function($) {

//put the js code under this line 

	if ($(".two-column-carousel").length) {
		$(".two-column-carousel").owlCarousel({
			loop:true,
			margin:30,
			nav:true,
			smartSpeed: 500,
			autoplay: 1000,
			responsive:{
				0:{
					items:1
				},
				480:{
					items:1
				},
				600:{
					items:1
				},
				800:{
					items:2
				},
				1024:{
					items:2
				}
			}
		});    		
	}

//put the code above the line 

  });
</script>';


?>

<?php
      echo '
     <script>
 jQuery(document).ready(function($) {

//put the js code under this line 

	if ($(".single-item-carousel").length) {
		$(".single-item-carousel").owlCarousel({
			loop:true,
			margin:30,
			nav:true,
			smartSpeed: 500,
			autoplay: 1000,
			responsive:{
				0:{
					items:1
				},
				480:{
					items:1
				},
				600:{
					items:1
				},
				800:{
					items:1
				},			
				1200:{
					items:1
				}

			}
		});    		
	}

//put the code above the line 

  });
</script>';


?>

		<?php  if ( 'style1' === $settings['style'] ) : ?>
		
		
        <section class="testimonial-seven p_relative sec-pad centred <?php echo esc_attr($settings['sec_class']);?>">
            <div class="pattern-layer">
                <div class="pattern-1 p_absolute"></div>
                <div class="pattern-2 p_absolute"></div>
            </div>
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title-eight p_relative d_block mb_50">
                    <h5 class="p_relative d_iblock fs_18 lh_30 fw_sbold font_family_poppins mb_12"><?php echo $settings['subtitle'];?></h5><br />
                    <h2 class="d_block fs_50 fw_bold lh_50 fw_bold font_family_pt"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="inner-content p_relative">
                    <div class="shape">
						<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                        <div class="shape-1 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
						<?php else :?>	
						<div class="noimage">
						<?php endif;?>
						</div>
						<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                        <div class="shape-2 p_absolute rotate-me" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
						<?php else :?>	
						<div class="noimage">
						<?php endif;?>
						</div>
                    </div>
                    
					
						
					
                        <div class="testimonial-block-two p_relative d_block b_shadow_6 pt_65 pr_100 pb_60 pl_100">
						
						<div class="single-item-carousel owl-carousel owl-theme owl-dots-none">
						
							<?php foreach($settings['repeat'] as $item):?>
						
                            <div class="inner-box">
                                <ul class="rating clearfix p_relative d_block mb_25">
									<?php  if ( 'rat1' === $item['block_rating'] ) : ?>      
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
									<?php endif ;?>	         
									<?php  if ( 'rat2' === $item['block_rating'] ) : ?>      
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
									<?php endif ;?>
									<?php  if ( 'rat3' === $item['block_rating'] ) : ?>      
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
									<?php endif ;?>	   
									<?php  if ( 'rat4' === $item['block_rating'] ) : ?>      
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
									<?php endif ;?>	
									<?php  if ( 'rat5' === $item['block_rating'] ) : ?>      
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
									<?php endif ;?>
                                </ul>
                                <p class="fs_17 fw_sbold font_family_poppins mb_25"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                <div class="author p_relative d_block">
                                    <h3 class="d_block lh_30 font_family_pt fw_bold"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
                                    <span class="designation p_relative d_block fs_16"><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
                                </div>
                            </div>
							
							<?php endforeach; ?>
							
							
                        </div>
						
						
						
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style2' === $settings['style'] ) : ?>
		
		<section class="testimonial-three p_relative pt_120 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
				<?php if($settings['title']): ?>
                <div class="sec-title p_relative d_block mb_50 centred">
                    <h2 class="d_block fs_50 fw_bold lh_55 fw_bold font_family_spartan"><?php echo $settings['title'];?></h2>
                </div>
				<?php endif; ?>
                <div class="row clearfix">
                    <div class="two-column-carousel owl-carousel owl-theme dots-style-one nav-style-one">
					
						<?php foreach($settings['repeat'] as $item):?>
					
                        <div class="testimonial-block-one">
                            <div class="inner-box p_relative d_block">
                                <div class="text p_relative d_block b_radius_10 pt_35 pr_40 pb_40 pl_40 mb_30">
                                    <ul class="rating clearfix p_relative d_block mb_15">
                                        <?php  if ( 'rat1' === $item['block_rating'] ) : ?>      
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<?php endif ;?>	         
										<?php  if ( 'rat2' === $item['block_rating'] ) : ?>      
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<?php endif ;?>
										<?php  if ( 'rat3' === $item['block_rating'] ) : ?>      
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<?php endif ;?>	   
										<?php  if ( 'rat4' === $item['block_rating'] ) : ?>      
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<?php endif ;?>	
										<?php  if ( 'rat5' === $item['block_rating'] ) : ?>      
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
											<li class="p_relative d_iblock fs_16"><i class="icon-20"></i></li>
										<?php endif ;?>
                                    </ul>
                                    <p class="font_family_oxygen fs_18 lh_30"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                </div>
                                <div class="author p_relative d_block pl_90 pt_7 pb_11 ml_20">
                                    <figure class="thumb-box p_absolute l_0 t_0 w_70 h_70 b_radius_50">
										<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
										<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
										<?php else :?>
										<div class="noimage"></div>
										<?php endif;?>
									</figure>
                                    <h4 class="d_block fs_24 lh_30 mb_2 font_family_spartan"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                    <span class="designation p_relative d_block fs_16 lh_20"><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
                                </div>
                            </div>
                        </div>
						
						<?php endforeach; ?>
						
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style3' === $settings['style'] ) : ?>
		
				<section class="testimonial-three p_relative pb_150 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="shape parallax-scene parallax-scene-5">
				<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
                <div data-depth="0.50" class="shape-1 p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
				<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
                <div data-depth="0.40" class="shape-2 p_absolute" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);">
				<?php else :?>	
				<div class="noimage">
				<?php endif;?>
				</div>
            </div>
            <div class="auto-container">
                <div class="row clearfix">
					<?php if($settings['title']): ?>
                    <div class="col-lg-4 col-md-12 col-sm-12 title-column">
                        <div class="sec-title-three p_relative d_block mb_40">
                            <h6 class="d_block fs_18 lh_26 fw_bold font_family_oxygen mb_12"><?php echo $settings['subtitle'];?></h6>
                            <h2 class="d_block fs_50 fw_bold"><?php echo $settings['title'];?></h2>
                        </div>
                    </div>
					<?php endif; ?>
                    <div class="col-lg-8 col-md-12 col-sm-12 inner-column">
                        <div class="inner-content">
                            <div class="two-column-carousel owl-carousel owl-theme owl-dots-none nav-style-two">
							
								<?php foreach($settings['repeat'] as $item):?>
							
                                <div class="testimonial-block-one">
                                    <div class="inner-box p_relative d_block">
                                        <div class="text p_relative d_block b_radius_10 pt_35 pr_30 pb_40 pl_40 mb_30">
                                            <ul class="rating clearfix p_relative d_block mb_15">
                                                <?php  if ( 'rat1' === $item['block_rating'] ) : ?>      
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<?php endif ;?>	         
												<?php  if ( 'rat2' === $item['block_rating'] ) : ?>      
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<?php endif ;?>
												<?php  if ( 'rat3' === $item['block_rating'] ) : ?>      
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<?php endif ;?>	   
												<?php  if ( 'rat4' === $item['block_rating'] ) : ?>      
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<?php endif ;?>	
												<?php  if ( 'rat5' === $item['block_rating'] ) : ?>      
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
													<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<?php endif ;?>
                                            </ul>
                                            <p class="font_family_oxygen"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                        </div>
                                        <div class="author p_relative d_block pl_90 pt_7 pb_11 ml_20">
                                            <figure class="thumb-box p_absolute l_0 t_0 w_70 h_70 b_radius_50">
												<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
												<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
												<?php else :?>
												<div class="noimage"></div>
												<?php endif;?>
											</figure>
                                            <h4 class="d_block fs_24 lh_30 mb_2"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                            <span class="designation p_relative d_block fs_16 lh_20"><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
                                        </div>
                                    </div>
                                </div>
								
								<?php endforeach; ?>
								
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		<?php  if ( 'style4' === $settings['style'] ) : ?>
		
		<section class="testimonial-one p_relative pt_140 pb_100 testimonial-page-3 <?php echo esc_attr($settings['sec_class']);?>">
            <div class="auto-container">
                <div class="sortable-masonry">
                    <div class="items-container row clearfix">
					
						<?php foreach($settings['repeat'] as $item):?>
					
                        <div class="col-lg-<?php echo esc_attr($item['block_column'], true );?> col-md-6 col-sm-12 testimonial-block masonry-item small-column">
                            <div class="testimonial-block-one wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                                <div class="inner-box p_relative d_block mb_50">
                                    <div class="text p_relative d_block b_radius_10 pt_35 pr_40 pb_40 pl_40 mb_30">
                                        <ul class="rating clearfix p_relative d_block mb_15">
                                            <?php  if ( 'rat1' === $item['block_rating'] ) : ?>      
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
											<?php endif ;?>	         
											<?php  if ( 'rat2' === $item['block_rating'] ) : ?>      
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
											<?php endif ;?>
											<?php  if ( 'rat3' === $item['block_rating'] ) : ?>      
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
											<?php endif ;?>	   
											<?php  if ( 'rat4' === $item['block_rating'] ) : ?>      
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
											<?php endif ;?>	
											<?php  if ( 'rat5' === $item['block_rating'] ) : ?>      
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
												<li class="p_relative d_iblock pull-left fs_16 mr_5"><i class="icon-20"></i></li>
											<?php endif ;?>
                                        </ul>
                                        <p class="font_family_poppins color_black"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                    </div>
                                    <div class="author p_relative d_block pl_90 pt_7 pb_11 ml_20">
                                        <figure class="thumb-box p_absolute l_0 t_0 w_70 h_70 b_radius_50">
											<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
											<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
											<?php else :?>
											<div class="noimage"></div>
											<?php endif;?>
										</figure>
                                        <h4 class="d_block fs_24 lh_30 mb_2"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
                                        <span class="designation p_relative d_block fs_16 lh_20"><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
                                    </div>
                                </div>
                            </div>
                        </div>
						
						<?php endforeach; ?>
						
                    </div>
                </div>
            </div>
        </section>
		
		<?php endif;?>
		
		
		<?php 
	}

}